(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    261907,       6475]
NotebookOptionsPosition[    257315,       6334]
NotebookOutlinePosition[    257650,       6349]
CellTagsIndexPosition[    257607,       6346]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData["\[AliasDelimiter]"], "Input",
 CellChangeTimes->{3.5722437394565697`*^9}],

Cell[CellGroupData[{

Cell[TextData[{
 "Proca quasi-bound states of a Kerr BHs in GR to second order in the spin \
via the Breit-Wigner resonance method ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
    "includes", " ", "couplings", " ", "with", " ", "different", " ", 
     "harmonic", " ", "indices"}], "]"}], TraditionalForm]], "Subsubtitle",
  FormatType->"TraditionalForm"],
 " \n",
 StyleBox["Reference: Paolo Pani, \[OpenCurlyDoubleQuote]Advanced methods in \
Black-Hole Perturbation Theory\[CloseCurlyDoubleQuote] (2013)",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{
  3.5701092341113586`*^9, {3.570117652780466*^9, 3.5701176573116493`*^9}, {
   3.570118625235464*^9, 3.5701186769267683`*^9}, {3.570227375137948*^9, 
   3.570227401005803*^9}, {3.571072184950651*^9, 3.571072199211156*^9}, {
   3.571072309951724*^9, 3.571072360711537*^9}, 3.5710725997199793`*^9, {
   3.571072634393869*^9, 3.571072695533065*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"m", "\[LessEqual]", "l"}], ",", 
     RowBox[{"m", "\[GreaterEqual]", 
      RowBox[{"-", "l"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.571072787687845*^9, 3.57107279389316*^9}}],

Cell["\<\
We have 3 equations for three variables u2, u3, u4 (u2 and u3 being polar \
functions, u4 being an axial function). However, perturbations with a given \
harmonic index l are coupled to perturbations with l\[PlusMinus]1 and l\
\[PlusMinus]2.\
\>", "Text",
 CellChangeTimes->{{3.5710762499281673`*^9, 3.571076308480186*^9}}],

Cell[CellGroupData[{

Cell["Equations:", "Subsubsection",
 CellChangeTimes->{{3.5415844155364532`*^9, 3.541584416728113*^9}, {
   3.571072907227786*^9, 3.571072948171791*^9}, 3.571076231716926*^9}],

Cell["\<\
 [typically the equations are stored in a .mx file and called when needed. We \
write them explicitly here so we don\[CloseCurlyQuote]t need external files.]\
\
\>", "Text",
 CellChangeTimes->{{3.5710762342776527`*^9, 3.571076236299488*^9}, 
   3.571519020965786*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"u2ppn", "=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["r", "8"]], 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["r", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["M", "2"]}], "-", 
             RowBox[{"2", " ", "M", " ", "r", " ", 
              RowBox[{"(", 
               RowBox[{"5", "+", "l", "+", 
                SuperscriptBox["l", "2"], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "l", "+", 
                SuperscriptBox["l", "2"], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Mu]", "2"], "-", 
                   SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
            ")"}], " ", 
           RowBox[{
            RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "3"}], " ", "M"}], "+", "r"}], ")"}], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"M", " ", "r", " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], "+", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
          "\[Omega]"}], ")"}]}], "2", " ", "J", " ", 
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", "m", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["M", "2"]}], "-", 
            RowBox[{"12", " ", "M", " ", "r"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["r", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "4"], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
          RowBox[{
           RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"m", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["l", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["r", "3"], " ", 
                SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}], " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"], " ", 
                RowBox[{"Q", "[", "l", "]"}], " ", 
                RowBox[{
                 RowBox[{"u4", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
               "-", 
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox["\[Omega]", "2"], " ", 
                   RowBox[{"Q", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], " ", 
                   RowBox[{
                    RowBox[{"u4", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", "m", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["J", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{"3", " ", "l"}], "+", 
              SuperscriptBox["l", "2"]}], ")"}], " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
            
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{"Q", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "l"}], "]"}], " ", 
            RowBox[{"Q", "[", "l", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["M", "2"]}], "-", 
                 RowBox[{"10", " ", "M", " ", "r"}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"2", " ", "l"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[Mu]", "2"]}], "+", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
                ")"}], " ", 
               RowBox[{
                RowBox[{"u2", "[", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
              "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", " ", "M"}], "-", "r"}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"u3", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
                 "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "M"}], "-", "r"}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                    RowBox[{"r", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "l", "+", 
              SuperscriptBox["l", "2"]}], ")"}], " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
            
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "l"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", " ", 
                  SuperscriptBox["M", "2"]}], "-", 
                 RowBox[{"10", " ", "M", " ", "r"}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    RowBox[{"2", " ", "l"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[Mu]", "2"]}], "+", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
                ")"}], " ", 
               RowBox[{
                RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", " ", "M"}], "-", "r"}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "M"}], "-", "r"}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                    RowBox[{"r", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "+", "l"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"l", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["l", "2"]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["m", "2"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"48", " ", 
                    SuperscriptBox["M", "4"]}], "-", 
                    RowBox[{"48", " ", 
                    SuperscriptBox["M", "3"], " ", "r"}], "+", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["M", "2"], " ", 
                    SuperscriptBox["r", "2"]}], "-", 
                    RowBox[{
                    SuperscriptBox["r", "6"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox["\[Omega]", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"48", " ", 
                    SuperscriptBox["M", "4"]}], "-", 
                    RowBox[{"24", " ", 
                    SuperscriptBox["M", "3"], " ", "r"}], "+", 
                    RowBox[{"2", " ", "M", " ", 
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"10", "+", "l", "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}], "+", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["M", "2"], " ", 
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "-", 
                    RowBox[{
                    SuperscriptBox["r", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", "l", "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
                   ")"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], 
                  " ", 
                  SuperscriptBox["\[Omega]", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                    RowBox[{"10", " ", "M", " ", "r"}], "-", 
                    RowBox[{"2", " ", "l", " ", 
                    SuperscriptBox["r", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[Mu]", "2"]}], "+", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}], " ", 
                  
                  SuperscriptBox[
                   RowBox[{"Q", "[", "l", "]"}], "2"]}]}], ")"}], " ", 
               RowBox[{
                RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox["m", "2"], " ", 
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    SuperscriptBox["M", "3"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["M", "2"], " ", "r"}], "-", 
                    RowBox[{"2", " ", "M", " ", 
                    SuperscriptBox["r", "2"]}], "+", 
                    SuperscriptBox["r", "3"]}], ")"}], " ", 
                    SuperscriptBox["\[Omega]", "2"]}], "+", 
                    RowBox[{"l", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["m", "2"], " ", 
                    SuperscriptBox["M", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}],
                     "-", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"24", " ", 
                    SuperscriptBox["M", "3"]}], "-", 
                    RowBox[{"10", " ", 
                    SuperscriptBox["M", "2"], " ", "r"}], "-", 
                    RowBox[{"5", " ", "M", " ", 
                    SuperscriptBox["r", "2"]}], "+", 
                    SuperscriptBox["r", "3"]}], ")"}], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["l", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["m", "2"], " ", 
                    SuperscriptBox["M", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}],
                     "-", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"24", " ", 
                    SuperscriptBox["M", "3"]}], "-", 
                    RowBox[{"10", " ", 
                    SuperscriptBox["M", "2"], " ", "r"}], "-", 
                    RowBox[{"5", " ", "M", " ", 
                    SuperscriptBox["r", "2"]}], "+", 
                    SuperscriptBox["r", "3"]}], ")"}], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", "l", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "M"}], "-", "r"}], ")"}], " ", 
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], 
                    " ", 
                    SuperscriptBox["\[Omega]", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Q", "[", "l", "]"}], "2"]}]}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "l"}], ")"}], " ", "r", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    SuperscriptBox["m", "2"], " ", 
                    SuperscriptBox["M", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}],
                     "+", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "12"}], " ", 
                    SuperscriptBox["M", "3"]}], "+", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["M", "2"], " ", "r"}], "-", 
                    RowBox[{"4", " ", "M", " ", 
                    SuperscriptBox["r", "2"]}], "+", 
                    SuperscriptBox["r", "3"]}], ")"}], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], 
                    " ", 
                    SuperscriptBox["\[Omega]", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"l", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", "M"}], "+", "r"}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                    RowBox[{"r", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
                    "+", 
                    RowBox[{"\[ImaginaryI]", " ", "m", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Omega]", "2"], " ", 
                    RowBox[{"Q", "[", "l", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                    SuperscriptBox["r", "2"]}], ")"}], " ", 
                    RowBox[{
                    RowBox[{"u4", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
                    "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u4", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
            
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{"Q", "[", 
             RowBox[{"1", "+", "l"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "l"}], ")"}], " ", 
               RowBox[{"Q", "[", 
                RowBox[{"2", "+", "l"}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "l"}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "12"}], " ", 
                    SuperscriptBox["M", "2"]}], "+", 
                    RowBox[{"10", " ", "M", " ", "r"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"2", " ", "l"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
                   ")"}], " ", 
                  RowBox[{
                   RowBox[{"u2", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", "l"}], ")"}]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "M"}], "-", "r"}], ")"}], " ", 
                    RowBox[{
                    RowBox[{"u3", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "[", "r", "]"}]}], "-", 
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", "l"}], ")"}]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "M"}], "-", "r"}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                    RowBox[{"r", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                   ")"}]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", "m", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "l"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                    SuperscriptBox["r", "2"]}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"u4", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"u4", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "l"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "l"}], ")"}], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], "3"], " ", 
         SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u3ppn", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "l", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "l"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
       RowBox[{
        RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["l", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M", " ", 
             SuperscriptBox["\[Mu]", "2"]}], "+", 
            RowBox[{"r", " ", 
             SuperscriptBox["\[Mu]", "2"]}], "-", 
            RowBox[{"r", " ", 
             SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{
        RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
      RowBox[{"2", " ", "M", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], 
     RowBox[{"r", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], "+", 
    FractionBox[
     RowBox[{"2", " ", "J", " ", "m", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"l", "+", 
           SuperscriptBox["l", "2"], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
         RowBox[{
          RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         RowBox[{
          RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
      "\[Omega]"}]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "8"]}]], 
     SuperscriptBox["J", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"24", " ", 
          SuperscriptBox["m", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"12", " ", 
                SuperscriptBox["M", "2"]}], "-", 
               RowBox[{"2", " ", "M", " ", "r", " ", 
                RowBox[{"(", 
                 RowBox[{"5", "+", "l", "+", 
                  SuperscriptBox["l", "2"], "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", "l", "+", 
                  SuperscriptBox["l", "2"], "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
              ")"}], " ", 
             RowBox[{
              RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "3"}], " ", "M"}], "+", "r"}], ")"}], " ", 
                RowBox[{
                 RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
               RowBox[{"M", " ", "r", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
           ")"}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
          SuperscriptBox["\[Omega]", "2"]}]]}], "-", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
           SuperscriptBox["\[Omega]", "2"]}], ")"}]}], "24", " ", "m", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", "m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", " ", 
              SuperscriptBox["M", "2"]}], "-", 
             RowBox[{"12", " ", "M", " ", "r"}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["r", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "4"], " ", 
              SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"m", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
                
                RowBox[{
                 SuperscriptBox["l", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
                
                RowBox[{
                 SuperscriptBox["r", "3"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox["\[Omega]", "2"], " ", 
                 RowBox[{"Q", "[", "l", "]"}], " ", 
                 RowBox[{
                  RowBox[{"u4", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
                "-", 
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[ImaginaryI]", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Omega]", "2"], " ", 
                    RowBox[{"Q", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], " ", 
                    RowBox[{
                    RowBox[{"u4", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", "m", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", 
           SuperscriptBox["M", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], "3"]}], ")"}]}], 
        "2", " ", 
        SuperscriptBox["r", "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "l", " ", "M"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["l", "2"], " ", "M"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["m", "2"], " ", "M"}], "+", 
          RowBox[{
           SuperscriptBox["m", "2"], " ", "r"}], "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Q", "[", "l", "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["l", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Q", "[", 
             RowBox[{"1", "+", "l"}], "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
           RowBox[{
            RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["l", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M", " ", 
                 SuperscriptBox["\[Mu]", "2"]}], "+", 
                RowBox[{"r", " ", 
                 SuperscriptBox["\[Mu]", "2"]}], "-", 
                RowBox[{"r", " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", "M", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             SuperscriptBox["r", "5"], " ", 
             RowBox[{
              RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
            SuperscriptBox["M", "2"]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["m", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", "M"}], "-", "r"}], ")"}], " ", 
            SuperscriptBox["r", "5"], " ", 
            RowBox[{
             RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"240", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", 
            RowBox[{
             RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "+", 
          FractionBox[
           RowBox[{"240", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", 
            RowBox[{
             RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"96", " ", 
            SuperscriptBox["m", "2"], " ", "r", " ", 
            RowBox[{
             RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"96", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", "r", " ", 
            RowBox[{
             RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "+", 
          FractionBox[
           RowBox[{"6", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], "2"], " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
           SuperscriptBox["M", "2"]], "+", 
          FractionBox[
           RowBox[{"6", " ", 
            SuperscriptBox["l", "2"], " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], 
           SuperscriptBox["M", "2"]], "+", 
          FractionBox[
           RowBox[{"48", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "3"], " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{"l", "+", 
            SuperscriptBox["l", "2"]}]], "-", 
          FractionBox[
           RowBox[{"240", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"240", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "+", 
          FractionBox[
           RowBox[{"96", " ", 
            SuperscriptBox["m", "2"], " ", "r", " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "+", 
          FractionBox[
           RowBox[{"96", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", "r", " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["r", "8"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{"M", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
          "-", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{"l", " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{"4", " ", "l", " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"48", " ", "\[ImaginaryI]", " ", "m", " ", 
            SuperscriptBox["r", "3"], " ", 
            RowBox[{"Q", "[", "l", "]"}], " ", 
            RowBox[{
             RowBox[{"u4", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
           RowBox[{"1", "+", "l"}]], "+", 
          FractionBox[
           RowBox[{"48", " ", "\[ImaginaryI]", " ", "m", " ", 
            SuperscriptBox["r", "3"], " ", 
            RowBox[{"Q", "[", "l", "]"}], " ", 
            RowBox[{
             RowBox[{"u4", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
           RowBox[{"l", "+", 
            SuperscriptBox["l", "2"]}]], "-", 
          FractionBox[
           RowBox[{"48", " ", "\[ImaginaryI]", " ", "m", " ", 
            SuperscriptBox["r", "3"], " ", 
            RowBox[{"Q", "[", 
             RowBox[{"1", "+", "l"}], "]"}], " ", 
            RowBox[{
             RowBox[{"u4", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], 
           RowBox[{"1", "+", "l"}]], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "6"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           SuperscriptBox["M", "2"]], "+", 
          FractionBox[
           RowBox[{"4", " ", "l", " ", 
            SuperscriptBox["r", "6"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], "+", 
          
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["l", "2"], " ", 
            SuperscriptBox["r", "6"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], "-", 
          
          FractionBox[
           RowBox[{"4", " ", "l", " ", 
            SuperscriptBox["r", "7"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"M", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
          "-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["l", "2"], " ", 
            SuperscriptBox["r", "7"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"M", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
          "+", 
          FractionBox[
           RowBox[{"l", " ", 
            SuperscriptBox["r", "8"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            SuperscriptBox["M", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
          "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["l", "2"], " ", 
            SuperscriptBox["r", "8"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            SuperscriptBox["M", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
          "+", 
          FractionBox[
           RowBox[{"144", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", "r", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "+", 
          FractionBox[
           RowBox[{"144", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", "r", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"48", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"48", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{"4", " ", "l", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", "l", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["l", "2"], " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["l", "3"], " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["l", "2"], " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            SuperscriptBox["l", "3"], " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], "2"], " ", 
            SuperscriptBox["r", "4"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}], "-", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}], "+", 
              RowBox[{"r", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "M"],
           "+", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["l", "2"], " ", 
            SuperscriptBox["r", "4"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}], "-", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}], "+", 
              RowBox[{"r", " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "M"],
           "+", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", 
              SuperscriptBox["\[Omega]", "2"]}], ")"}]}], "4", " ", "m", " ", 
           
           RowBox[{"(", 
            RowBox[{
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", "m", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"12", " ", 
                 SuperscriptBox["M", "2"]}], "-", 
                RowBox[{"6", " ", "M", " ", "r"}], "+", 
                RowBox[{
                 SuperscriptBox["r", "4"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"m", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "6"}], " ", "M", " ", 
                 SuperscriptBox["r", "3"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}], "+", 
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"12", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                   RowBox[{"6", " ", "M", " ", "r"}], "+", 
                   RowBox[{
                    SuperscriptBox["r", "4"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["l", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"12", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                   RowBox[{"6", " ", "M", " ", "r"}], "+", 
                   RowBox[{
                    SuperscriptBox["r", "4"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], 
              " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", "\[ImaginaryI]", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox["\[Omega]", "2"], " ", 
                 RowBox[{"Q", "[", "l", "]"}], " ", 
                 RowBox[{
                  RowBox[{"u4", "[", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
                "+", 
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "6"}], " ", "\[ImaginaryI]", " ", "M", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Omega]", "2"], " ", 
                    RowBox[{"Q", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], " ", 
                    RowBox[{
                    RowBox[{"u4", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", "m", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                    RowBox[{"6", " ", "M", " ", "r"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "4"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["M", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], ")"}]}], 
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "l", " ", 
              SuperscriptBox["M", "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["M", "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", "l", " ", "M", " ", "r", " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["l", "2"], " ", "M", " ", "r", " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"l", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", "l", " ", 
              SuperscriptBox["M", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["M", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", "l", " ", "M", " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", "M", " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", "l", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", "l", " ", 
              SuperscriptBox["M", "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["M", "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"4", " ", "l", " ", "M", " ", "r", " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["l", "2"], " ", "M", " ", "r", " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["m", "2"], " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", "l", " ", 
              SuperscriptBox["M", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["M", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", "l", " ", "M", " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", "M", " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"2", " ", "l", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "m", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"Q", "[", "l", "]"}], " ", 
              RowBox[{
               RowBox[{"u4", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
             "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "l", " ", "m", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"Q", "[", "l", "]"}], " ", 
              RowBox[{
               RowBox[{"u4", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
             "+", 
             RowBox[{"2", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], 
              " ", 
              RowBox[{"Q", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "l"}], "]"}], " ", 
              RowBox[{"Q", "[", "l", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"u2", "[", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "l"}], "]"}], "[", "r", "]"}], 
                "-", 
                RowBox[{
                 RowBox[{"u3", "[", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "l"}], "]"}], "[", "r", "]"}], 
                "+", 
                RowBox[{"r", " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u2", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
             "-", 
             RowBox[{"8", " ", "l", " ", 
              SuperscriptBox["M", "2"], " ", "r", " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["M", "2"], " ", "r", " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"6", " ", "l", " ", "M", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"6", " ", 
              SuperscriptBox["l", "2"], " ", "M", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "-", 
             RowBox[{"l", " ", 
              SuperscriptBox["r", "3"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "-", 
             RowBox[{
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r", "3"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", "l", " ", 
              SuperscriptBox["M", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["M", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", "l", " ", "M", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "-", 
             RowBox[{"8", " ", 
              SuperscriptBox["l", "2"], " ", "M", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", "l", " ", 
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["l", "2"], " ", 
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], 
              " ", 
              SuperscriptBox[
               RowBox[{"Q", "[", 
                RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"u2", "[", "l", "]"}], "[", "r", "]"}], "-", 
                RowBox[{
                 RowBox[{"u3", "[", "l", "]"}], "[", "r", "]"}], "+", 
                RowBox[{"r", " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u2", "[", "l", "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"2", " ", "l", " ", "r", " ", 
              RowBox[{"Q", "[", 
               RowBox[{"1", "+", "l"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", "m", " ", "r", " ", 
                 RowBox[{
                  RowBox[{"u4", "[", 
                   RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
                FractionBox[
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "l"}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], 
                  " ", 
                  RowBox[{"Q", "[", 
                   RowBox[{"2", "+", "l"}], "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"u2", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "[", "r", "]"}], "-", 
                    RowBox[{
                    RowBox[{"u3", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "[", "r", "]"}], "+", 
                    RowBox[{"r", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
                 "r"]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
              SuperscriptBox["M", "2"]}], ")"}]}], "2", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", 
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"Q", "[", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "l"}], "]"}], " ", 
           RowBox[{"Q", "[", "l", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "-", 
                RowBox[{"3", " ", "l"}], "+", 
                SuperscriptBox["l", "2"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "+", "r"}], ")"}], " ", 
              RowBox[{
               RowBox[{"u2", "[", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
             "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "-", 
                   RowBox[{"3", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"]}], ")"}], " ", "M"}], "+", 
                RowBox[{"r", " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "-", 
                   RowBox[{"3", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"], "+", 
                   RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
               ")"}], " ", 
              RowBox[{
               RowBox[{"u3", "[", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
             "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "-", 
                   RowBox[{"3", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"]}], ")"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u2", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u3", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
            ")"}]}], "-", 
          FractionBox[
           RowBox[{"24", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "4"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"l", "+", 
            SuperscriptBox["l", "2"]}]], "+", 
          FractionBox[
           RowBox[{"16", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "5"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"l", "+", 
              SuperscriptBox["l", "2"]}], ")"}], " ", "M"}]], "-", 
          FractionBox[
           RowBox[{"48", " ", "M", " ", 
            SuperscriptBox["r", "5"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], "+", 
          
          FractionBox[
           RowBox[{"48", " ", 
            SuperscriptBox["r", "6"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], "-", 
          
          FractionBox[
           RowBox[{"12", " ", 
            SuperscriptBox["r", "7"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"M", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
          "+", 
          FractionBox[
           RowBox[{"48", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", "r", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "+", 
          FractionBox[
           RowBox[{"48", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", "M", " ", "r", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"24", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "-", 
          FractionBox[
           RowBox[{"24", " ", "l", " ", 
            SuperscriptBox["m", "2"], " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]], "+", 
          FractionBox[
           RowBox[{"24", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{"20", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"l", " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"l", " ", 
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"24", " ", "l", " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          FractionBox[
           RowBox[{"20", " ", "l", " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{"4", " ", "l", " ", 
            SuperscriptBox["r", "7"], " ", 
            SuperscriptBox[
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u3", "[", "l", "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "-", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "l"}], ")"}], " ", 
              SuperscriptBox["M", "2"]}], ")"}]}], "2", " ", "l", " ", 
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"Q", "[", 
            RowBox[{"1", "+", "l"}], "]"}], " ", 
           RowBox[{"Q", "[", 
            RowBox[{"2", "+", "l"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"6", "+", 
                RowBox[{"5", " ", "l"}], "+", 
                SuperscriptBox["l", "2"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "+", "r"}], ")"}], " ", 
              RowBox[{
               RowBox[{"u2", "[", 
                RowBox[{"2", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"6", "+", 
                   RowBox[{"5", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"]}], ")"}], " ", "M"}], "+", 
                RowBox[{"r", " ", 
                 RowBox[{"(", 
                  RowBox[{"6", "+", 
                   RowBox[{"5", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"], "+", 
                   RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
               ")"}], " ", 
              RowBox[{
               RowBox[{"u3", "[", 
                RowBox[{"2", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"6", "+", 
                   RowBox[{"5", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"]}], ")"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u2", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u3", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
            ")"}]}], "-", 
          FractionBox[
           RowBox[{"24", " ", "\[ImaginaryI]", " ", "m", " ", 
            SuperscriptBox["r", "4"], " ", 
            RowBox[{"Q", "[", "l", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u4", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"1", "+", "l"}]], "-", 
          FractionBox[
           RowBox[{"24", " ", "\[ImaginaryI]", " ", "m", " ", 
            SuperscriptBox["r", "4"], " ", 
            RowBox[{"Q", "[", "l", "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u4", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"l", "+", 
            SuperscriptBox["l", "2"]}]], "+", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
              SuperscriptBox["M", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], ")"}]}], "2", 
           " ", "\[ImaginaryI]", " ", "m", " ", 
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"Q", "[", "l", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SuperscriptBox["l", "2"], " ", "M", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["l", "3"], " ", 
                 SuperscriptBox["r", "2"]}], "-", 
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"8", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                   RowBox[{"4", " ", "M", " ", "r"}], "+", 
                   SuperscriptBox["r", "2"]}], ")"}]}], "-", 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                 SuperscriptBox["r", "3"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Mu]", "2"], "-", 
                   SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}], " ", 
              RowBox[{
               RowBox[{"u4", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
             "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "l"}], ")"}], " ", "M"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], " ", "r"}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u4", "[", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"24", " ", "\[ImaginaryI]", " ", "m", " ", 
            SuperscriptBox["r", "4"], " ", 
            RowBox[{"Q", "[", 
             RowBox[{"1", "+", "l"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"u4", "[", 
               RowBox[{"1", "+", "l"}], "]"}], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], 
           RowBox[{"1", "+", "l"}]], "-", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", "l"}], ")"}], " ", 
              SuperscriptBox["M", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], ")"}]}], "2", 
           " ", "\[ImaginaryI]", " ", "m", " ", 
           SuperscriptBox["r", "4"], " ", 
           RowBox[{"Q", "[", 
            RowBox[{"1", "+", "l"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "8"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "+", 
                   RowBox[{"3", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"]}], ")"}], " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{"4", " ", "M", " ", "r", " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "+", 
                   RowBox[{"3", " ", "l"}], "+", 
                   SuperscriptBox["l", "2"], "+", 
                   RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "l"}], "+", 
                   RowBox[{"3", " ", 
                    SuperscriptBox["l", "2"]}], "+", 
                   SuperscriptBox["l", "3"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[Mu]", "2"]}], "+", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
               ")"}], " ", 
              RowBox[{
               RowBox[{"u4", "[", 
                RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"6", "+", "l"}], ")"}], " ", "M"}], "+", 
                RowBox[{"l", " ", "r"}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"u4", "[", 
                 RowBox[{"1", "+", "l"}], "]"}], "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u4ppn", "=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["r", "4"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
          "\[Omega]"}], ")"}]}], "2", " ", "\[ImaginaryI]", " ", "J", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "m", " ", 
          SuperscriptBox["r", "3"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          RowBox[{
           RowBox[{"u4", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
          RowBox[{"Q", "[", "l", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "l"}], "+", 
               SuperscriptBox["l", "2"], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"u2", "[", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"u3", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", "l", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
          RowBox[{"Q", "[", 
           RowBox[{"1", "+", "l"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"3", " ", "l"}], "+", 
               SuperscriptBox["l", "2"], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"u2", "[", 
               RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"u3", "[", 
                RowBox[{"1", "+", "l"}], "]"}], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["l", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M", " ", 
                 SuperscriptBox["\[Mu]", "2"]}], "+", 
                RowBox[{"r", " ", 
                 SuperscriptBox["\[Mu]", "2"]}], "-", 
                RowBox[{"r", " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            RowBox[{"u4", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", "M", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], "+", 
      RowBox[{"J", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["M", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], "3"]}], ")"}]}], 
          "J", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}]}], ")"}]}], "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "l", " ", "M"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["l", "2"], " ", "M"}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox["m", "2"], " ", "M"}], "+", 
               RowBox[{
                SuperscriptBox["m", "2"], " ", "r"}], "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{"Q", "[", "l", "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox["l", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{"Q", "[", 
                  RowBox[{"1", "+", "l"}], "]"}], "2"]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
                  
                  RowBox[{
                   SuperscriptBox["l", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
                  
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M", " ", 
                    SuperscriptBox["\[Mu]", "2"]}], "+", 
                    RowBox[{"r", " ", 
                    SuperscriptBox["\[Mu]", "2"]}], "-", 
                    RowBox[{"r", " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], 
                " ", 
                RowBox[{
                 RowBox[{"u4", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
               RowBox[{"2", " ", "M", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"2", " ", 
                  SuperscriptBox["m", "2"], " ", "M", " ", "r", " ", 
                  RowBox[{"(", 
                   RowBox[{"l", "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
                  RowBox[{
                   RowBox[{"u4", "[", "l", "]"}], "[", "r", "]"}]}], 
                 RowBox[{"l", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "l"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]]}], "+", 
               FractionBox[
                RowBox[{"r", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"l", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}],
                    "+", 
                   RowBox[{
                    SuperscriptBox["l", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}],
                    "-", 
                   RowBox[{"2", " ", "M", " ", 
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
                 RowBox[{
                  RowBox[{"u4", "[", "l", "]"}], "[", "r", "]"}]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], 
               "-", 
               FractionBox[
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["l", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r"}], 
                   "+", 
                   RowBox[{"l", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SuperscriptBox["M", "2"]}], "-", 
                    RowBox[{"2", " ", "M", " ", "r"}], "-", 
                    SuperscriptBox["r", "2"]}], ")"}]}], "+", 
                   RowBox[{"2", " ", "M", " ", 
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
                 SuperscriptBox[
                  RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
                 RowBox[{
                  RowBox[{"u4", "[", "l", "]"}], "[", "r", "]"}]}], 
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                    SuperscriptBox["M", "2"]}], "+", 
                   RowBox[{"l", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                    SuperscriptBox["r", "2"]}], "-", 
                   RowBox[{"2", " ", "M", " ", "r", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"Q", "[", 
                   RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
                 RowBox[{
                  RowBox[{"u4", "[", "l", "]"}], "[", "r", "]"}]}], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]], "+", 
               RowBox[{
                RowBox[{"1", "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], ")"}]}], 
                "2", " ", "\[ImaginaryI]", " ", "m", " ", 
                RowBox[{"Q", "[", "l", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SuperscriptBox["M", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", "r"}], "+", 
                    RowBox[{"l", " ", 
                    SuperscriptBox["r", "2"]}]}], ")"}], " ", 
                   RowBox[{
                    RowBox[{"u2", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
                  "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"l", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["l", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
                    
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}], " ", 
                    
                    RowBox[{
                    RowBox[{"u3", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
                    "+", 
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"5", "+", "l"}], ")"}], " ", "M"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "r"}]}], 
                    ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"1", "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "l"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], ")"}]}], 
                "2", " ", "\[ImaginaryI]", " ", "m", " ", 
                RowBox[{"Q", "[", 
                 RowBox[{"1", "+", "l"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox["M", "2"]}], "+", 
                    RowBox[{"l", " ", "M", " ", "r"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                    SuperscriptBox["r", "2"]}]}], ")"}], " ", 
                   RowBox[{
                    RowBox[{"u2", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"]}], ")"}], " ", "M"}], "-", 
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
                    ")"}], " ", 
                    RowBox[{
                    RowBox[{"u3", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"]}], ")"}]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u2", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "l"}], ")"}], " ", "M"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"2", "+", "l"}], ")"}], " ", "r"}]}], ")"}], " ", 
                    
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}], "-", 
               FractionBox[
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], " ", 
                 RowBox[{"Q", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "l"}], "]"}], " ", 
                 RowBox[{"Q", "[", "l", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "M"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}], " ", 
                    
                    RowBox[{
                    RowBox[{"u4", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
                   "+", 
                   RowBox[{"6", " ", "M", " ", "r", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u4", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "l"}]], "-", 
               RowBox[{"6", " ", "M", " ", "r", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "-", 
               FractionBox[
                RowBox[{"2", " ", 
                 SuperscriptBox["m", "2"], " ", "r", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "3"}], " ", "M"}], "+", "r"}], ")"}], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}], 
                RowBox[{"l", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"8", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}], " ", "M", " ", "r", " ", 
                 SuperscriptBox[
                  RowBox[{"Q", "[", "l", "]"}], "2"], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}], "l"], "+", 
               FractionBox[
                RowBox[{"8", " ", "l", " ", "M", " ", "r", " ", 
                 SuperscriptBox[
                  RowBox[{"Q", "[", 
                   RowBox[{"1", "+", "l"}], "]"}], "2"], " ", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}]}], 
                RowBox[{"1", "+", "l"}]], "+", 
               FractionBox[
                RowBox[{"l", " ", 
                 RowBox[{"Q", "[", 
                  RowBox[{"1", "+", "l"}], "]"}], " ", 
                 RowBox[{"Q", "[", 
                  RowBox[{"2", "+", "l"}], "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", "l"}], ")"}], " ", "M"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[Mu]", "2"]}], "+", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}], " ", 
                    
                    RowBox[{
                    RowBox[{"u4", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "[", "r", "]"}]}], "-", 
                   RowBox[{"6", " ", "M", " ", "r", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u4", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
                RowBox[{"2", "+", "l"}]]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
             SuperscriptBox["\[Omega]", "2"]}], ")"}]}], "12", " ", 
          "\[ImaginaryI]", " ", "J", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "l"}], ")"}]}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], "2"], " ", 
             RowBox[{"Q", "[", "l", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", "m", 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["l", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
                  RowBox[{"l", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "-", 
                  
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M", " ", 
                    SuperscriptBox["\[Mu]", "2"]}], "+", 
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "+", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
                 ")"}], " ", 
                RowBox[{
                 RowBox[{"u2", "[", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "l"}], "]"}], "[", "r", "]"}]}], 
               "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"m", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["l", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
                    RowBox[{"l", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "-", 
                    
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "-", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   SuperscriptBox["r", "3"], " ", 
                   SuperscriptBox["\[Omega]", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"l", " ", 
                    RowBox[{"Q", "[", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u4", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
                    RowBox[{"Q", "[", "l", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"2", "+", "l"}], ")"}]}], 
             SuperscriptBox["l", "2"], " ", 
             RowBox[{"Q", "[", 
              RowBox[{"1", "+", "l"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"3", " ", "l"}], "+", 
                  SuperscriptBox["l", "2"]}], ")"}], " ", "m", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}], "-", 
                  RowBox[{"r", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "+", 
                    SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
                 ")"}], " ", 
                RowBox[{
                 RowBox[{"u2", "[", 
                  RowBox[{"1", "+", "l"}], "]"}], "[", "r", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"m", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"]}], ")"}], " ", "M"}], "-", 
                    RowBox[{"r", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", "l"}], "+", 
                    SuperscriptBox["l", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], 
                   " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"u3", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "-", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   SuperscriptBox["r", "3"], " ", 
                   SuperscriptBox["\[Omega]", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"2", "+", "l"}], ")"}], " ", 
                    RowBox[{"Q", "[", 
                    RowBox[{"1", "+", "l"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u4", "[", "l", "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                    RowBox[{"Q", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"u4", "[", 
                    RowBox[{"2", "+", "l"}], "]"}], "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.571072829991726*^9, 3.571072837440873*^9}, {
  3.571072875684154*^9, 3.5710728921315327`*^9}, {3.571072979697485*^9, 
  3.57107298248689*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Indices: ", "Subsubsection",
 CellChangeTimes->{{3.541910598120152*^9, 3.5419105993360853`*^9}, {
   3.571072991813348*^9, 3.57107299651178*^9}, 3.57107631286721*^9}],

Cell["\<\
This rule simplifies the notation:\
\>", "Text",
 CellChangeTimes->{{3.5710763148341618`*^9, 3.571076322518099*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulel", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"u2", "[", "l_", "]"}], "\[Rule]", 
      SubscriptBox["u2", "l"]}], ",", 
     RowBox[{
      RowBox[{"u3", "[", "l_", "]"}], "\[Rule]", 
      SubscriptBox["u3", "l"]}], ",", 
     RowBox[{
      RowBox[{"u4", "[", "l_", "]"}], "\[Rule]", 
      SubscriptBox["u4", "l"]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.545823785978849*^9, 3.5458238482172613`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eP1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"u2", "[", "l", "]"}], "''"}], "[", "r", "]"}], "-", 
      "u2ppn"}], ")"}], "/.", "rulel"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eP2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"u3", "[", "l", "]"}], "''"}], "[", "r", "]"}], "-", 
      "u3ppn"}], ")"}], "/.", "rulel"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eA", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"u4", "[", "l", "]"}], "''"}], "[", "r", "]"}], "-", 
      "u4ppn"}], ")"}], "/.", "rulel"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.541910577121566*^9, 3.541910582795164*^9}, {
   3.541910712069724*^9, 3.541910713222371*^9}, {3.541910751278946*^9, 
   3.541910751976282*^9}, {3.5419108386369343`*^9, 3.5419108964658833`*^9}, 
   3.541935638712891*^9, {3.541941916929229*^9, 3.541941939977104*^9}, {
   3.545823738002673*^9, 3.545823764389248*^9}, {3.5458238535981207`*^9, 
   3.545823872190649*^9}, {3.545824509493507*^9, 3.545824510440954*^9}, {
   3.57107285846871*^9, 3.571072863320607*^9}}],

Cell["Let us focus on m=1:", "Text",
 CellChangeTimes->{{3.571073074930912*^9, 3.571073081169269*^9}, {
  3.5710763285961943`*^9, 3.571076335971312*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"m0", "=", "1"}], ";"}]], "Input"],

Cell["\<\
The case l=m needs special treatment due to the propensity rule [see notes]. \
The following rule is needed to avoid fake singularities as l<m\
\>", "Text",
 CellChangeTimes->{{3.571076377115431*^9, 3.571076388640321*^9}, {
  3.571076492481881*^9, 3.571076504808277*^9}, {3.571076567688085*^9, 
  3.5710765721072893`*^9}, {3.5715190327447166`*^9, 3.571519073547928*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ruleUNO", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["u2", 
         RowBox[{"l", "-", "2"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["u3", 
         RowBox[{"l", "-", "2"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["u4", 
         RowBox[{"l", "-", "2"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["u2", 
         RowBox[{"l", "-", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["u3", 
         RowBox[{"l", "-", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["u4", 
         RowBox[{"l", "-", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Q", "[", "l", "]"}], "\[Rule]", "0"}]}], "}"}]}], ";"}], 
  RowBox[{"(*", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleUNO", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"ruleUNO", ",", 
     RowBox[{"D", "[", 
      RowBox[{"ruleUNO", ",", "r"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.545827479324898*^9, 3.545827479952652*^9}, {
  3.571076364367332*^9, 3.571076422737256*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eP10", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FullSimplify", "[", 
       RowBox[{"eP1", "/.", "ruleUNO"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"l", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "m0"}]}], "}"}]}], "}"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eP20", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FullSimplify", "[", 
       RowBox[{"eP2", "/.", "ruleUNO"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"l", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "m0"}]}], "}"}]}], "}"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eA0", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FullSimplify", "[", 
       RowBox[{"eA", "/.", "ruleUNO"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"l", "\[Rule]", "1"}], ",", 
        RowBox[{"m", "\[Rule]", "m0"}]}], "}"}]}], "}"}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.57107306772484*^9, 3.571073067907689*^9}, {
  3.571076509334817*^9, 3.5710765123714867`*^9}}],

Cell["\<\
We store the equations to save time in future:\
\>", "Text",
 CellChangeTimes->{{3.571073097626993*^9, 3.571073103729171*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<BW_eqs_l=1.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"eP10", ",", "eP20", ",", "eA0"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5458275117709618`*^9, 3.545827536011279*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Truncation order: L", "Subsubsection",
 CellChangeTimes->{{3.541844904178443*^9, 3.541844906826528*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<BW_eqs_l=1.mx\>\""}], ";"}]], "Input"],

Cell["\<\
Let us choose a truncation order (it can be any number L\[GreaterEqual]1). \
\>", "Text",
 CellChangeTimes->{{3.5710766004045687`*^9, 3.571076643079975*^9}, 
   3.571076814826479*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"L", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{3.5710747876890173`*^9, 3.5710766461632757`*^9}],

Cell["\<\
The following rules enforce the fact that there is no coupling to \
perturbations with l=-1 (this should be automatic because l\[GreaterEqual]0 \
but we need to impose it by hand to avoid fake 0/0 terms). Since we assume \
m>0, also perturbations with l=0 are vanishing. Separated treatment is needed \
for m=0.\
\>", "Text",
 CellChangeTimes->{{3.57107665930938*^9, 3.571076797319388*^9}, {
  3.571519117155203*^9, 3.571519131448258*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulem1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u2", 
        RowBox[{"-", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u3", 
        RowBox[{"-", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u4", 
        RowBox[{"-", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rule0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u4", "0"], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u3", "0"], "[", "r", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulemon", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["u2", "0"], "[", "r", "]"}], "\[Rule]", "0"}], "}"}]}], 
  ";"}]}], "Input"],

Cell["\<\
The following rules enforce the truncation. We truncate the axial and polar \
sector differnetly. First truncation in the axial sector. [Of course, \
convergence must be checked a posteriori]\
\>", "Text",
 CellChangeTimes->{{3.571076804830511*^9, 3.571076854174304*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u4", "L"], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u4", 
        RowBox[{"L", "+", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u4", 
        RowBox[{"L", "+", "2"}]], "[", "r", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleP1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u1", 
        RowBox[{"L", "+", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u1", 
        RowBox[{"L", "+", "2"}]], "[", "r", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleP2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u2", 
        RowBox[{"L", "+", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u2", 
        RowBox[{"L", "+", "2"}]], "[", "r", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleP3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u3", 
        RowBox[{"L", "+", "1"}]], "[", "r", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u3", 
        RowBox[{"L", "+", "2"}]], "[", "r", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5415910016195707`*^9, 3.541591056625824*^9}, {
   3.541591091254609*^9, 3.5415912229107933`*^9}, {3.5415919214222593`*^9, 
   3.541591942811616*^9}, {3.541592065153803*^9, 3.541592126333247*^9}, {
   3.541592263169917*^9, 3.541592278221059*^9}, {3.5415924313638687`*^9, 
   3.541592570994417*^9}, {3.541592603022656*^9, 3.541592653890464*^9}, {
   3.541592763579584*^9, 3.541592900670385*^9}, 3.541601851817277*^9, 
   3.5416025541688213`*^9, 3.5416031083105164`*^9, 3.54160323227293*^9, 
   3.541603737918811*^9, {3.5416803074697742`*^9, 3.541680309623089*^9}, 
   3.541744949952622*^9, 3.5417452110501347`*^9, 3.541747398179154*^9, 
   3.541748066476948*^9, 3.541910921796826*^9, {3.541937539490925*^9, 
   3.541937540233509*^9}, 3.541943027798029*^9, 3.541943642512404*^9, {
   3.5419438312861643`*^9, 3.5419438598133287`*^9}, 3.5419439934486094`*^9, {
   3.541959185425682*^9, 3.54195920918583*^9}, 3.54196164847163*^9, 
   3.542991060900064*^9, 3.543140371929117*^9, 3.545823942768332*^9, {
   3.54582458146457*^9, 3.5458246019812613`*^9}, 3.5458251669914217`*^9, {
   3.5458252272647057`*^9, 3.545825344439784*^9}, {3.545825412036887*^9, 
   3.545825414090774*^9}, {3.545825529323372*^9, 3.5458255631508904`*^9}, {
   3.5458257216691227`*^9, 3.545825741672881*^9}, {3.545826100950595*^9, 
   3.5458261095695257`*^9}, {3.54582642028616*^9, 3.545826437895245*^9}, {
   3.5458264885847483`*^9, 3.545826519500737*^9}, {3.545826647448482*^9, 
   3.545826785814383*^9}, {3.54582716770411*^9, 3.545827267068491*^9}, {
   3.5458274748572407`*^9, 3.545827506687549*^9}, 3.545827839833968*^9, {
   3.545827962721519*^9, 3.545827962947588*^9}, {3.5458286126926823`*^9, 
   3.5458286160570183`*^9}, {3.545829175527873*^9, 3.545829192026906*^9}, {
   3.546089442449008*^9, 3.5460894467071333`*^9}, {3.5460895091818438`*^9, 
   3.546089512480974*^9}, {3.571073159802767*^9, 3.5710733301308804`*^9}}],

Cell["We merge all previous rules:", "Text",
 CellChangeTimes->{{3.571076859900528*^9, 3.571076870120922*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleI", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"rule0", ",", "rulem1", ",", "rulemon"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleF", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"ruleA", ",", "ruleP1", ",", "ruleP2", ",", "ruleP3"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleF", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"ruleF", ",", 
     RowBox[{"D", "[", 
      RowBox[{"ruleF", ",", "r"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{"ruleF", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell["\<\
This generates our final set of equations:\
\>", "Text",
 CellChangeTimes->{{3.571076874158724*^9, 3.5710768841079817`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eP1Vb", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"eP1", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"l", "\[Rule]", "i"}], ",", 
          RowBox[{"m", "\[Rule]", "m0"}]}], "}"}]}], "//.", "ruleI"}], "//.", 
      "ruleF"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "L"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eP2Vb", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"eP2", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"l", "\[Rule]", "i"}], ",", 
          RowBox[{"m", "\[Rule]", "m0"}]}], "}"}]}], "//.", "ruleI"}], "//.", 
      "ruleF"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "L"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eAVb", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"eA", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"l", "\[Rule]", "i"}], ",", 
          RowBox[{"m", "\[Rule]", "m0"}]}], "}"}]}], "//.", "ruleI"}], "//.", 
      "ruleF"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", 
       RowBox[{"L", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.571073328172596*^9, 3.5710733590026093`*^9}}],

Cell["Let us define Q[l]:", "Text",
 CellChangeTimes->{{3.571076892874723*^9, 3.5710768967468243`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruleQ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Q", "[", "l_", "]"}], "\[Rule]", 
     SqrtBox[
      FractionBox[
       RowBox[{
        SuperscriptBox["l", "2"], "-", 
        SuperscriptBox["m0", "2"]}], 
       RowBox[{
        RowBox[{"4", 
         SuperscriptBox["l", "2"]}], "-", "1"}]]]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eP1V", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Union", "[", 
        RowBox[{"eP10", ",", "eP1Vb"}], "]"}], "]"}], "//.", "ruleI"}], "//.",
      "ruleF"}], "/.", "ruleQ"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eP2V", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Union", "[", 
        RowBox[{"eP20", ",", "eP2Vb"}], "]"}], "]"}], "//.", "ruleI"}], "//.",
      "ruleF"}], "/.", "ruleQ"}]}], ";", 
  RowBox[{"eAV", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Union", "[", 
        RowBox[{"eA0", ",", "eAVb"}], "]"}], "]"}], "//.", "ruleI"}], "//.", 
     "ruleF"}], "/.", "ruleQ"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5710733660234537`*^9, 3.571073383995884*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["EQUATIONS", "Subsubsection",
 CellChangeTimes->{{3.545827854017668*^9, 3.545827855257833*^9}}],

Cell["\<\
We define a big single array of equations and functions. DIM is the total \
number of equations, which depends on the truncation order L.\
\>", "Text",
 CellChangeTimes->{{3.571076917412417*^9, 3.571076947891786*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"EQs0", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "eP20", "}"}], ",", "eAV", ",", "eP1V", ",", "eP2V"}], 
      "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"EQs0", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"eAV", ",", "eP1V", ",", "eP2V"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yV0", "=", 
     RowBox[{"Union", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["u2", "i"], "[", "r", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["u3", "i"], "[", "r", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["u4", "i"], "[", "r", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"L", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Length", "[", "yV0", "]"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"perturbations", ":", " ", 
      RowBox[{"L", "-", 
       RowBox[{"1", " ", "axial"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{"2", "L"}], "+", 
      RowBox[{"2", " ", "polar"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"+", "2"}], " ", "being", " ", "the", " ", "monopole"}], " ", 
      "\[Equal]", ">", " ", 
      RowBox[{
       RowBox[{"TOTAL", " ", "3", "L"}], "+", 
       RowBox[{"1", " ", "equations"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"DIM", "=", 
    RowBox[{"Length", "[", "EQs0", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5415929048103247`*^9, 3.541592952377561*^9}, {
   3.541593085609292*^9, 3.541593197910355*^9}, {3.54159475657918*^9, 
   3.541594758275626*^9}, {3.54191149707438*^9, 3.541911536650119*^9}, {
   3.541912844563291*^9, 3.5419128449534883`*^9}, {3.541936166891444*^9, 
   3.541936200067408*^9}, {3.541936955065919*^9, 3.541936971085104*^9}, {
   3.541959224926476*^9, 3.541959235729076*^9}, 3.545827858325832*^9}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.5415929530202303`*^9, 3.541593199093233*^9, 3.5415947591668863`*^9, 
   3.541596702370892*^9, 3.5415992154361486`*^9, 3.541601858685464*^9, 
   3.541602559376729*^9, 3.541603111777575*^9, 3.541603236921894*^9, 
   3.541603742749445*^9, 3.541680317246192*^9, 3.541744954561679*^9, 
   3.5417471704272413`*^9, 3.5417474031613207`*^9, 3.541748070740633*^9, 
   3.541843517544582*^9, 3.541844238923448*^9, 3.541844933604369*^9, 
   3.5418633612519407`*^9, 3.54191150486131*^9, {3.541912163289441*^9, 
   3.541912191298449*^9}, 3.5419128460804*^9, 3.541936205427689*^9, 
   3.541936493669701*^9, 3.541936638187615*^9, {3.541936957581059*^9, 
   3.5419369722615337`*^9}, 3.541937109905222*^9, 3.541937544517413*^9, 
   3.541942642977791*^9, 3.541942844691125*^9, 3.5419430311742163`*^9, {
   3.5419431032745857`*^9, 3.541943127989588*^9}, 3.541943646965246*^9, {
   3.541943839572247*^9, 3.541943868265643*^9}, 3.541943942726295*^9, 
   3.541944575315415*^9, 3.5419592410809*^9, 3.541961651921905*^9, 
   3.541998209020294*^9, 3.542041820565956*^9, 3.54299106524465*^9, 
   3.543140379509831*^9, 3.543809707855918*^9, 3.545827863508123*^9, 
   3.5458279659507236`*^9, 3.5458286231423407`*^9, 3.5458300327268867`*^9, 
   3.5458301382257853`*^9, 3.546089176476899*^9, 3.546089401717844*^9, 
   3.546089450659445*^9, 3.546089515367158*^9, 3.5710734033902197`*^9, 
   3.571074799622953*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleY", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["u2", "i"], "[", "r", "]"}], "\[Rule]", 
        RowBox[{
         SubscriptBox["y", "i"], "[", "r", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["u3", "i"], "[", "r", "]"}], "\[Rule]", 
        RowBox[{
         SubscriptBox["y", 
          RowBox[{"L", "+", "i"}]], "[", "r", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["u4", "i"], "[", "r", "]"}], "\[Rule]", 
        RowBox[{
         SubscriptBox["y", 
          RowBox[{
           RowBox[{"2", "L"}], "+", "i"}]], "[", "r", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"L", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleYp", "=", 
   RowBox[{"D", "[", 
    RowBox[{"ruleY", ",", "r"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleYpp", "=", 
   RowBox[{"D", "[", 
    RowBox[{"ruleY", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ruleN", "=", 
    RowBox[{"Union", "[", 
     RowBox[{"ruleY", ",", "ruleYp", ",", "ruleYpp"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "**)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQs", "=", 
   RowBox[{"EQs0", "//.", "ruleN"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yV", "=", 
   RowBox[{"yV0", "//.", "ruleN"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "EQs", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "yV", "]"}]}], "Input",
 CellChangeTimes->{{3.541845031908536*^9, 3.5418451583269463`*^9}, {
   3.5418451967589006`*^9, 3.541845298306497*^9}, {3.541845356493432*^9, 
   3.541845414418602*^9}, {3.541845450334093*^9, 3.541845487283045*^9}, 
   3.5419116369148293`*^9, {3.5419367048684893`*^9, 3.5419367858090487`*^9}, {
   3.5419368236297703`*^9, 3.541936873456867*^9}, {3.541936964079636*^9, 
   3.5419369675411158`*^9}, {3.541959261232826*^9, 3.541959284958992*^9}, {
   3.5710734125901403`*^9, 3.571073413531651*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.541936867979945*^9, 3.541936873860231*^9}, 
   3.541936985942894*^9, 3.541937121158297*^9, 3.5419375524141483`*^9, 
   3.541942645630451*^9, 3.5419428463691397`*^9, 3.541943039210949*^9, {
   3.54194312386471*^9, 3.541943131799591*^9}, 3.541943650909734*^9, 
   3.541943877023156*^9, 3.5419439456685753`*^9, 3.541944691309148*^9, 
   3.5419447394801064`*^9, 3.541959248687416*^9, 3.54195928547719*^9, 
   3.541961655112308*^9, 3.541998225673476*^9, 3.542041822391831*^9, 
   3.542991068009926*^9, 3.543140381402173*^9, 3.543809710934511*^9, 
   3.545827984361746*^9, 3.545828631445578*^9, 3.545830034654479*^9, 
   3.5458301480954437`*^9, 3.5460891805777483`*^9, 3.546089413562886*^9, 
   3.5460894527262297`*^9, 3.5460895194330063`*^9, 3.571073418047689*^9, 
   3.571074800924411*^9}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.541936867979945*^9, 3.541936873860231*^9}, 
   3.541936985942894*^9, 3.541937121158297*^9, 3.5419375524141483`*^9, 
   3.541942645630451*^9, 3.5419428463691397`*^9, 3.541943039210949*^9, {
   3.54194312386471*^9, 3.541943131799591*^9}, 3.541943650909734*^9, 
   3.541943877023156*^9, 3.5419439456685753`*^9, 3.541944691309148*^9, 
   3.5419447394801064`*^9, 3.541959248687416*^9, 3.54195928547719*^9, 
   3.541961655112308*^9, 3.541998225673476*^9, 3.542041822391831*^9, 
   3.542991068009926*^9, 3.543140381402173*^9, 3.543809710934511*^9, 
   3.545827984361746*^9, 3.545828631445578*^9, 3.545830034654479*^9, 
   3.5458301480954437`*^9, 3.5460891805777483`*^9, 3.546089413562886*^9, 
   3.5460894527262297`*^9, 3.5460895194330063`*^9, 3.571073418047689*^9, 
   3.571074800925543*^9}]
}, Open  ]],

Cell["\<\
Let us save for future convenience:\
\>", "Text",
 CellChangeTimes->{{3.571076976456545*^9, 3.5710769830737877`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<eqs_coupled_2.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"EQs", ",", "yV", ",", "DIM", ",", "L", ",", "m0"}], "}"}]}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.541594821327487*^9, 3.541594896048403*^9}, {
  3.54159922366938*^9, 3.541599226157528*^9}, {3.5419116449954853`*^9, 
  3.541911659975782*^9}, {3.5420418249612913`*^9, 3.5420418255222597`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series at the horizon:", "Subsubsection",
 CellChangeTimes->{{3.541593486982918*^9, 3.541593490910323*^9}, {
  3.541843565231715*^9, 3.541843568198153*^9}, {3.54185331104989*^9, 
  3.5418533128415947`*^9}}],

Cell["\<\
Here we do the standard series expansion at the horizon on the full set of \
equations EQs. (The order of the expansion, ORDH, can be set freely)\
\>", "Text",
 CellChangeTimes->{{3.571076995821969*^9, 3.571077029156901*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"rH", "=", 
    RowBox[{"2", "M", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["J", "2"], 
        RowBox[{"4", 
         SuperscriptBox["M", "4"]}]]}], ")"}]}]}], ";", 
   RowBox[{"rule1", "=", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["y", "i"], "[", "r", "]"}], "\[Rule]", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"r", "-", "rH"}], ")"}], 
           RowBox[{
            RowBox[{"-", "2"}], " ", "I", " ", "M", " ", "kH"}]], 
          RowBox[{
           SubscriptBox["H", "i"], "[", "r", "]"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["y", "i"], "'"}], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", "-", "rH"}], ")"}], 
             RowBox[{
              RowBox[{"-", "2"}], " ", "I", " ", "M", " ", "kH"}]], 
            RowBox[{
             SubscriptBox["H", "i"], "[", "r", "]"}]}], ",", "r"}], "]"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["y", "i"], "''"}], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", "-", "rH"}], ")"}], 
             RowBox[{
              RowBox[{"-", "2"}], " ", "I", " ", "M", " ", "kH"}]], 
            RowBox[{
             SubscriptBox["H", "i"], "[", "r", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQsH2", "=", 
   RowBox[{"Simplify", "[", 
    FractionBox[
     RowBox[{"EQs", "//.", "rule1"}], "1"], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.541843617477108*^9, 3.541843671121757*^9}, {
   3.541843717718506*^9, 3.541843752364397*^9}, {3.541843806956629*^9, 
   3.541843857928492*^9}, {3.5418438925698423`*^9, 3.541844031391197*^9}, {
   3.5418440646021347`*^9, 3.541844181509811*^9}, 3.541844524194497*^9, {
   3.541846365475643*^9, 3.5418464485051813`*^9}, 3.541846494378669*^9, 
   3.541847209979312*^9, {3.5418533232033443`*^9, 3.541853432610607*^9}, 
   3.541853965582941*^9, 3.54185404141498*^9, {3.54186385846819*^9, 
   3.5418638867205467`*^9}, {3.541911671143526*^9, 3.541911694750659*^9}, {
   3.541946486021406*^9, 3.541946486868232*^9}, {3.54195985973007*^9, 
   3.541959860707059*^9}, {3.545828854690123*^9, 3.5458289004232073`*^9}, {
   3.571074363666286*^9, 3.571074367435844*^9}, 3.571074470939598*^9, 
   3.571076992213821*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDH", "=", 
   RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rule2", "=", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["H", "i"], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["yhor", "i"], "[", "j", "]"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", "-", "rH"}], ")"}], "j"]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", 
             RowBox[{"ORDH", "+", "6"}]}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["H", "i"], "'"}], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SubscriptBox["yhor", "i"], "[", "j", "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"r", "-", "rH"}], ")"}], "j"]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "0", ",", 
               RowBox[{"ORDH", "+", "6"}]}], "}"}]}], "]"}], ",", "r"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["H", "i"], "''"}], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               SubscriptBox["yhor", "i"], "[", "j", "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"r", "-", "rH"}], ")"}], "j"]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "0", ",", 
               RowBox[{"ORDH", "+", "6"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleH", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ss", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"EQsH2", "//.", "rule2"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "rH", ",", 
        RowBox[{"ORDH", "+", "2"}]}], "}"}]}], "]"}], "//.", "ruleH"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yhorV", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["yhor", "i"], "[", "j", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"ORDH", "+", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQhor", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"SeriesCoefficient", "[", 
          RowBox[{
           RowBox[{"ss", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", "j"}], "]"}], "\[Equal]", 
         "0"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"ORDH", "+", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesH", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"EQhor", ",", "yhorV"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "yhorV", "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.54184390209935*^9, 3.541843939830804*^9}, {
   3.54184410108512*^9, 3.541844113618247*^9}, {3.541844263025133*^9, 
   3.541844319927525*^9}, {3.54184447987943*^9, 3.541844705316594*^9}, {
   3.5418465623778477`*^9, 3.541846670341514*^9}, {3.541846700699223*^9, 
   3.541846708294136*^9}, {3.541846746023877*^9, 3.54184677868299*^9}, {
   3.541846916695406*^9, 3.541846927648944*^9}, {3.541847014691558*^9, 
   3.54184711291181*^9}, 3.541847215557126*^9, {3.541848252434156*^9, 
   3.541848252938592*^9}, 3.541851357324911*^9, {3.54185343776366*^9, 
   3.541853562557002*^9}, {3.541853658798428*^9, 3.541853663035163*^9}, {
   3.5418538982736998`*^9, 3.541853903751395*^9}, 3.541863513919857*^9, {
   3.541863928092128*^9, 3.541863965578183*^9}, {3.5418640296295567`*^9, 
   3.5418640417075167`*^9}, {3.541864112464463*^9, 3.541864137501593*^9}, {
   3.5418642069886312`*^9, 3.5418642187005787`*^9}, 3.5418644659341717`*^9, {
   3.541865035046261*^9, 3.541865035240155*^9}, {3.5418650934400177`*^9, 
   3.541865132419901*^9}, 3.541911708403555*^9, {3.541911817287312*^9, 
   3.5419118186701813`*^9}, 3.541946538848504*^9, {3.541946596352468*^9, 
   3.54194668988175*^9}, {3.541946776426684*^9, 3.541946842576415*^9}, 
   3.5419473061528463`*^9, 3.541947401385264*^9, 3.541959857580448*^9, {
   3.542041837912866*^9, 3.542041843748362*^9}, 3.545828010066489*^9, {
   3.545828916020759*^9, 3.5458289361929207`*^9}, {3.5459167836959763`*^9, 
   3.54591678455656*^9}, {3.545916929480153*^9, 3.545916929781282*^9}, 
   3.57107461636963*^9, {3.571074713209332*^9, 3.571074713299852*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.541946806234692*^9, 3.541946843771635*^9}, 
   3.5419473066748753`*^9, 3.5419474024849033`*^9, 3.541959447477683*^9, 
   3.5419598658258047`*^9, 3.541961671031658*^9, 3.5419621150810833`*^9, 
   3.541998235215726*^9, {3.5420418346252117`*^9, 3.54204184537923*^9}, 
   3.542991076775775*^9, 3.543140411042983*^9, 3.5438097257407627`*^9, 
   3.57107461670087*^9, {3.571074713836755*^9, 3.5710747433662443`*^9}, 
   3.571074840292465*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<seriesH_coupled_2.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"seriesH", ",", "ORDH"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.541946849565702*^9, 3.5419468570874987`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Series at infinity:", "Subsubsection",
 CellChangeTimes->{{3.541593486982918*^9, 3.541593490910323*^9}, {
  3.541843565231715*^9, 3.541843568198153*^9}}],

Cell["\<\
Here we do the standard series expansion at infinity on the full set of \
equations EQs. Again the order is arbitrary.\
\>", "Text",
 CellChangeTimes->{{3.571076995821969*^9, 3.57107704804386*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"u1", ",", "u2", ",", "u3"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rule1", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["y", "i"], "[", "r", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"kk", " ", "r"}], "]"}], 
         SuperscriptBox["r", "n"], 
         RowBox[{
          SubscriptBox["H", "i"], "[", "r", "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rule1", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"rule1", ",", 
       RowBox[{"D", "[", 
        RowBox[{"rule1", ",", "r"}], "]"}], ",", 
       RowBox[{"D", "[", 
        RowBox[{"rule1", ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EQs2", "=", 
     RowBox[{"Simplify", "[", 
      FractionBox[
       RowBox[{"EQs", "//.", "rule1"}], 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"kk", " ", "r"}], "]"}], 
        SuperscriptBox["r", 
         RowBox[{"n", "+", "3"}]]}]], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EQs2", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"EQs", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "//.", "rule1"}], 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"kk", " ", "r"}], "]"}], 
          SuperscriptBox["r", 
           RowBox[{"n", "+", "3"}]]}]], ",", 
        FractionBox[
         RowBox[{
          RowBox[{"EQs", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "//.", "rule1"}], 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"kk", " ", "r"}], "]"}], 
          SuperscriptBox["r", 
           RowBox[{"n", "+", "1"}]]}]], ",", 
        FractionBox[
         RowBox[{
          RowBox[{"EQs", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "//.", "rule1"}], 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"kk", " ", "r"}], "]"}], 
          SuperscriptBox["r", "n"]}]], ",", 
        FractionBox[
         RowBox[{
          RowBox[{"EQs", "[", 
           RowBox[{"[", "4", "]"}], "]"}], "//.", "rule1"}], 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"kk", " ", "r"}], "]"}], 
          SuperscriptBox["r", "n"]}]], ",", 
        FractionBox[
         RowBox[{
          RowBox[{"EQs", "[", 
           RowBox[{"[", "5", "]"}], "]"}], "//.", "rule1"}], 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"kk", " ", "r"}], "]"}], 
          SuperscriptBox["r", "n"]}]]}], "}"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.541843617477108*^9, 3.541843671121757*^9}, {
   3.541843717718506*^9, 3.541843752364397*^9}, {3.541843806956629*^9, 
   3.541843857928492*^9}, {3.5418438925698423`*^9, 3.541844031391197*^9}, {
   3.5418440646021347`*^9, 3.541844181509811*^9}, 3.541844524194497*^9, {
   3.541846365475643*^9, 3.5418464485051813`*^9}, 3.541846494378669*^9, 
   3.541847209979312*^9, 3.5419128797675*^9, {3.5419363053422537`*^9, 
   3.5419363136184*^9}, {3.5419370484565773`*^9, 3.541937090346319*^9}, {
   3.5419371290517473`*^9, 3.541937129587879*^9}, {3.541961692569084*^9, 
   3.54196170728926*^9}, 3.541961795346608*^9, 3.541961834397957*^9, {
   3.5419619527708473`*^9, 3.541962021316029*^9}, {3.541962079150302*^9, 
   3.541962087328909*^9}, {3.571074545187768*^9, 3.571074547811717*^9}, {
   3.571074965445759*^9, 3.5710749877925158`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDINF", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rule2", "=", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["H", "i"], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{
             SubscriptBox["yinf", "i"], "[", "j", "]"}], 
            SuperscriptBox["r", "j"]], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", 
             RowBox[{"ORDINF", "+", "4"}]}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["H", "i"], "'"}], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               SubscriptBox["yinf", "i"], "[", "j", "]"}], 
              SuperscriptBox["r", "j"]], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "0", ",", 
               RowBox[{"ORDINF", "+", "4"}]}], "}"}]}], "]"}], ",", "r"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["H", "i"], "''"}], "[", "r", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               SubscriptBox["yinf", "i"], "[", "j", "]"}], 
              SuperscriptBox["r", "j"]], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "0", ",", 
               RowBox[{"ORDINF", "+", "4"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleINF", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["kk", "2"], "\[Rule]", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], "-", 
       SuperscriptBox["\[Omega]", "2"]}]}], ",", 
     RowBox[{"n", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"M", " ", 
         SuperscriptBox["\[Mu]", "2"]}], "-", 
        RowBox[{"2", " ", "M", " ", 
         SuperscriptBox["\[Omega]", "2"]}]}], "kk"]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ss", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"EQs2", "//.", "rule2"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\[Infinity]", ",", 
        RowBox[{"ORDINF", "+", "2"}]}], "}"}]}], "]"}], "/.", "ruleINF"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yinfV", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["yinf", "i"], "[", "j", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"ORDINF", "+", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "yinfV", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesINF", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"SeriesCoefficient", "[", 
              RowBox[{
               RowBox[{"ss", "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", "i"}], "]"}], "\[Equal]",
              "0"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"-", "2"}], ",", 
              RowBox[{"ORDINF", "-", "2"}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "]"}], ",", 
       "yinfV"}], "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.54184390209935*^9, 3.541843939830804*^9}, {
   3.54184410108512*^9, 3.541844113618247*^9}, {3.541844263025133*^9, 
   3.541844319927525*^9}, {3.54184447987943*^9, 3.541844705316594*^9}, {
   3.5418465623778477`*^9, 3.541846670341514*^9}, {3.541846700699223*^9, 
   3.541846708294136*^9}, {3.541846746023877*^9, 3.54184677868299*^9}, {
   3.541846916695406*^9, 3.541846927648944*^9}, {3.541847014691558*^9, 
   3.54184711291181*^9}, 3.541847215557126*^9, {3.541848252434156*^9, 
   3.541848252938592*^9}, 3.541851357324911*^9, {3.541912610785067*^9, 
   3.5419126231434593`*^9}, 3.5419594711341877`*^9, 3.541959871815753*^9, {
   3.541962061500061*^9, 3.541962071475726*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.5418469296986217`*^9, {3.541847049019189*^9, 3.54184705881927*^9}, {
   3.541847093676836*^9, 3.541847113399392*^9}, 3.541847219341007*^9, 
   3.5418482538090477`*^9, 3.5418513587136717`*^9, 3.5419119876574173`*^9, 
   3.5419122197855*^9, 3.541912538676684*^9, {3.541912611588779*^9, 
   3.541912623636652*^9}, 3.5419128676352177`*^9, 3.541937142119143*^9, 
   3.5419594719515533`*^9, 3.5419595517469397`*^9, 3.541959875310966*^9, 
   3.541961695864757*^9, 3.5419617356550207`*^9, 3.541961845409875*^9, {
   3.541962000121746*^9, 3.541962026292919*^9}, 3.541962063764847*^9, 
   3.571075005208774*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<seriesINF_coupled_2.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"seriesINF", ",", "ORDINF"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5418472460480757`*^9, 3.541847260533678*^9}, 
   3.541912018111261*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Integration:", "Subsubsection",
 CellChangeTimes->{{3.541593999006749*^9, 3.5415940017423363`*^9}}],

Cell["\<\
Here we integrate the field equations for a real frequency from the horizon \
to infinity:\
\>", "Text",
 CellChangeTimes->{{3.57107705421943*^9, 3.571077070043584*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "i", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<eqs_coupled_2.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$HistoryLength", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"INT", "[", 
    RowBox[{
    "\[Omega]0_", ",", "\[Mu]0_", ",", "J0_", ",", "VI_", ",", "EPS_", ",", 
     "INF_"}], "]"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ruleP", "=", 
      RowBox[{"{", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"AccuracyGoal", "\[Rule]", "12"}], ",", 
         RowBox[{"PrecisionGoal", "\[Rule]", "12"}], ","}], "*)"}], 
       RowBox[{"MaxSteps", "\[Rule]", 
        SuperscriptBox["10", "5"]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"M", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"rH", "=", 
      RowBox[{"2", "M", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["J0", "2"], 
          RowBox[{"4", 
           SuperscriptBox["M", "4"]}]]}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rhn", "=", 
      RowBox[{"rH", 
       RowBox[{"(", 
        RowBox[{"1", "+", "EPS"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rinf", "=", "INF"}], ";", "\[IndentingNewLine]", 
     RowBox[{"coeffV", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["yhor", "i"], "[", "0", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"paracoeff", "=", 
      RowBox[{"Union", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"coeffV", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
          RowBox[{"VI", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"param", "=", 
      RowBox[{"Union", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Omega]", "\[Rule]", "\[Omega]0"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "\[Mu]0"}], ",", 
          RowBox[{"J", "\[Rule]", "J0"}], ",", 
          RowBox[{"m", "\[Rule]", "m0"}], ",", 
          RowBox[{"\[Gamma]", "\[Rule]", "1"}]}], "}"}], ",", "paracoeff"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"<<", "\"\<seriesH_coupled_2.mx\>\""}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"ygV", "=", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"r", "-", "rH"}], ")"}], 
           RowBox[{
            RowBox[{"-", "2"}], " ", "I", " ", "M", 
            RowBox[{"(", 
             RowBox[{"\[Omega]", "-", 
              FractionBox[
               RowBox[{"J", " ", "m"}], 
               RowBox[{"4", " ", 
                SuperscriptBox["M", "3"]}]]}], ")"}]}]], 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["yhor", "i"], "[", "j", "]"}], 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"r", "-", "rH"}], ")"}], "j"]}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "0", ",", 
              RowBox[{"ORDH", "+", "1"}]}], "}"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "//.", 
       RowBox[{"Union", "[", 
        RowBox[{"param", ",", 
         RowBox[{"(*", 
          RowBox[{"seriesH", ","}], "*)"}], 
         RowBox[{"{", 
          RowBox[{"kH", "\[Rule]", 
           RowBox[{"\[Omega]", "-", 
            FractionBox[
             RowBox[{"J", " ", "m"}], 
             RowBox[{"4", " ", 
              SuperscriptBox["M", "3"]}]]}]}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"<<", "\"\<eqs_coupled_2.mx\>\""}], ";", "\[IndentingNewLine]", 
     RowBox[{"EQS", "=", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"EQs", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "/.", 
       "param"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
     RowBox[{"yBC", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["y", "i"], "[", "rhn", "]"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ygV", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "/.", 
           RowBox[{"r", "\[Rule]", "rhn"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ypBC", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["y", "i"], "'"}], "[", "rhn", "]"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"ygV", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "r"}], "]"}], "/.", 
           RowBox[{"r", "\[Rule]", "rhn"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"BCs", "=", 
      RowBox[{"Union", "[", 
       RowBox[{"yBC", ",", "ypBC"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
     RowBox[{"sol", "=", 
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Union", "[", 
         RowBox[{"EQS", ",", "BCs"}], "]"}], ",", "yV", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "rhn", ",", "rinf"}], "}"}], ",", "ruleP"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Clear", "[", "M", "]"}]}], "\[IndentingNewLine]", ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<done'?\>\"", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.541594003321083*^9, 3.5415941507877903`*^9}, {
   3.541594223158448*^9, 3.5415942820162*^9}, {3.541594410968442*^9, 
   3.541594412227262*^9}, {3.541594649429278*^9, 3.5415948023763313`*^9}, {
   3.541594889920322*^9, 3.541595153476345*^9}, {3.541595190970077*^9, 
   3.541595312623785*^9}, {3.541595481917859*^9, 3.541595539755011*^9}, {
   3.54159559913006*^9, 3.541595654790523*^9}, {3.541601454971957*^9, 
   3.5416014661245337`*^9}, {3.541602124281179*^9, 3.541602125784297*^9}, {
   3.5416037496642437`*^9, 3.5416037540894117`*^9}, {3.54174735268958*^9, 
   3.541747355307579*^9}, {3.541845573871047*^9, 3.5418455852480907`*^9}, {
   3.541845664875819*^9, 3.5418457353821783`*^9}, {3.5418458187380133`*^9, 
   3.541845820008643*^9}, {3.541911660158984*^9, 3.541911660328648*^9}, {
   3.541912047097117*^9, 3.541912049741358*^9}, {3.5419436728646173`*^9, 
   3.541943674983232*^9}, {3.541944760025505*^9, 3.5419447609928102`*^9}, 
   3.541946450069624*^9, {3.54194691609967*^9, 3.5419469855165577`*^9}, {
   3.5419470353795156`*^9, 3.541947044577574*^9}, 3.541947091578183*^9, {
   3.541947132177773*^9, 3.541947136276518*^9}, {3.5419471870194063`*^9, 
   3.541947198730789*^9}, {3.5419472745167227`*^9, 3.541947276478891*^9}, {
   3.5419473669857807`*^9, 3.541947367443014*^9}, {3.541947445036435*^9, 
   3.541947445219866*^9}, 3.5419598829579363`*^9, {3.545828102973035*^9, 
   3.545828127180605*^9}, {3.545828187674233*^9, 3.545828237489861*^9}, 
   3.54582831419879*^9, {3.546089583365118*^9, 3.546089588201427*^9}, {
   3.571074404143762*^9, 3.571074407929318*^9}, {3.571074654281299*^9, 
   3.5710746773369617`*^9}, {3.571074741011365*^9, 3.571074743887752*^9}, {
   3.571077082598114*^9, 3.571077099587309*^9}, {3.571519199534443*^9, 
   3.5715192037026863`*^9}, {3.571519304398984*^9, 3.5715193047206573`*^9}, {
   3.572208367942369*^9, 3.5722083727301617`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.541747405760269*^9, 3.5417480750668793`*^9, 3.5418457474589043`*^9, 
   3.5418458210069437`*^9, 3.541847383860318*^9, 3.5418513628862247`*^9, 
   3.541912035832089*^9, 3.5419122243498173`*^9, 3.54193718240905*^9, 
   3.541937567660562*^9, 3.541942652926097*^9, 3.541942854633481*^9, 
   3.541943044675692*^9, 3.541943137281467*^9, {3.541943654914617*^9, 
   3.5419436756164083`*^9}, 3.541943882137265*^9, 3.541943949217341*^9, 
   3.5419447772635107`*^9, 3.54194645072847*^9, {3.541947037673628*^9, 
   3.541947044978651*^9}, 3.541947092600748*^9, 3.541947137035986*^9, 
   3.5419472017518806`*^9, 3.541947276979122*^9, 3.541947312003306*^9, 
   3.541947369223394*^9, 3.541947448813493*^9, 3.541959488288899*^9, 
   3.541959883653782*^9, 3.541962121709105*^9, 3.541998237724905*^9, 
   3.542041850343576*^9, 3.5429910781294527`*^9, 3.543140275644126*^9, 
   3.543140414086999*^9, 3.543809726115901*^9, 3.5458283162155037`*^9, 
   3.545828637472611*^9, 3.545829841023775*^9, 3.546089200333035*^9, 
   3.5460895406760597`*^9, 3.54608958894802*^9, 3.57107501078564*^9}],

Cell[BoxData["\<\"inza'?\"\>"], "Print",
 CellChangeTimes->{
  3.541603754499247*^9, 3.541680322550634*^9, 3.541680543358527*^9, 
   3.541744958406106*^9, 3.541747174626944*^9, 3.541747405861874*^9, 
   3.5417480751128798`*^9, 3.5418457475156107`*^9, 3.541845821027709*^9, 
   3.541847383929349*^9, 3.541851362965653*^9, 3.54191203584921*^9, 
   3.5419122243690033`*^9, 3.541937182430258*^9, 3.5419375677023153`*^9, 
   3.541942652948732*^9, 3.541942854654025*^9, 3.5419430446994963`*^9, 
   3.541943137313992*^9, {3.541943654963531*^9, 3.5419436756711807`*^9}, 
   3.541943882220952*^9, 3.541943949270813*^9, 3.541944777305077*^9, 
   3.541946450754388*^9, {3.54194703775945*^9, 3.541947045066924*^9}, 
   3.541947092626729*^9, 3.541947137057975*^9, 3.541947201844631*^9, 
   3.541947277004703*^9, 3.5419473120830173`*^9, 3.541947369246537*^9, 
   3.541947448839006*^9, 3.541959488301012*^9, 3.541959883713879*^9, 
   3.541962121770705*^9, 3.5419982377560997`*^9, 3.542041850373176*^9, 
   3.54299107813239*^9, 3.543140275658825*^9, 3.543140414146494*^9, 
   3.5438097261414213`*^9, 3.5458283162543497`*^9, 3.545828637481553*^9, 
   3.545829841039854*^9, 3.546089200348384*^9, 3.5460895407133427`*^9, 
   3.546089588981143*^9, 3.571075010819645*^9}]
}, Open  ]],

Cell["\<\
Check: let us try one single integration.\
\>", "Text",
 CellChangeTimes->{{3.57107711335669*^9, 3.571077129672978*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"DIM", "\[IndentingNewLine]", 
 RowBox[{"vect", "=", 
  RowBox[{
   RowBox[{"IdentityMatrix", "[", "DIM", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"DIM", "-", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"INT", "[", 
   RowBox[{"0.09", ",", "0.1", ",", "0.06", ",", "vect", ",", 
    RowBox[{"5", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}], ",", 
    SuperscriptBox["10", "2"]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "/.", 
   RowBox[{"r", "\[Rule]", "rinf"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.541595316029237*^9, 3.541595369388524*^9}, {
   3.541596457060545*^9, 3.5415964629551067`*^9}, {3.541596497245673*^9, 
   3.541596502345883*^9}, {3.541596602037977*^9, 3.54159662857374*^9}, 
   3.5418457688825817`*^9, {3.5419376306920023`*^9, 3.5419376442779417`*^9}, 
   3.541942664968219*^9, {3.541942858839785*^9, 3.5419428835438967`*^9}, {
   3.541943896308964*^9, 3.541943901762474*^9}, {3.5419439551087837`*^9, 
   3.541943955491712*^9}, 3.541944785669842*^9, {3.541959502148147*^9, 
   3.541959504201344*^9}, {3.545828436200287*^9, 3.545828436278665*^9}, {
   3.545828508161923*^9, 3.545828508356554*^9}, 3.545828660463831*^9, 
   3.546089217641458*^9, {3.546089271772688*^9, 3.546089287295231*^9}, 
   3.5460895477259417`*^9, {3.5460897309916*^9, 3.546089742689398*^9}, {
   3.5710748752961597`*^9, 3.571074878729599*^9}, {3.5710750227899103`*^9, 
   3.571075031337929*^9}, {3.571075265668199*^9, 3.5710753226666193`*^9}, {
   3.571077118061199*^9, 3.571077118397592*^9}}],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.541937631541799*^9, 3.5419376447142878`*^9}, {
   3.541942661594255*^9, 3.5419426653531647`*^9}, {3.541942855952652*^9, 
   3.54194288412077*^9}, 3.541943046400317*^9, 3.541943138562261*^9, {
   3.54194365812016*^9, 3.541943679181095*^9}, {3.5419438846668386`*^9, 
   3.541943902813586*^9}, {3.541943952567315*^9, 3.54194395599933*^9}, {
   3.541944780362114*^9, 3.5419447860118523`*^9}, 3.5419470475587273`*^9, 
   3.5419470957662277`*^9, 3.541947139435358*^9, 3.541947204161716*^9, 
   3.5419472796985073`*^9, 3.541947314163625*^9, 3.541947372961976*^9, 
   3.541947452080325*^9, {3.541959492127658*^9, 3.5419595054390182`*^9}, 
   3.541962123371587*^9, 3.5419982407412577`*^9, 3.5438097309686117`*^9, 
   3.545828319623249*^9, 3.545828437043242*^9, 3.545828509715361*^9, {
   3.545828639766945*^9, 3.545828660881702*^9}, {3.546089203112962*^9, 
   3.546089218042541*^9}, {3.546089281945047*^9, 3.546089287944528*^9}, 
   3.546089543906431*^9, 3.546089590861506*^9, {3.5460897318376102`*^9, 
   3.546089743182028*^9}, {3.5710750138890457`*^9, 3.571075031606373*^9}, {
   3.571075263201912*^9, 3.571075323208631*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.541937631541799*^9, 3.5419376447142878`*^9}, {
   3.541942661594255*^9, 3.5419426653531647`*^9}, {3.541942855952652*^9, 
   3.54194288412077*^9}, 3.541943046400317*^9, 3.541943138562261*^9, {
   3.54194365812016*^9, 3.541943679181095*^9}, {3.5419438846668386`*^9, 
   3.541943902813586*^9}, {3.541943952567315*^9, 3.54194395599933*^9}, {
   3.541944780362114*^9, 3.5419447860118523`*^9}, 3.5419470475587273`*^9, 
   3.5419470957662277`*^9, 3.541947139435358*^9, 3.541947204161716*^9, 
   3.5419472796985073`*^9, 3.541947314163625*^9, 3.541947372961976*^9, 
   3.541947452080325*^9, {3.541959492127658*^9, 3.5419595054390182`*^9}, 
   3.541962123371587*^9, 3.5419982407412577`*^9, 3.5438097309686117`*^9, 
   3.545828319623249*^9, 3.545828437043242*^9, 3.545828509715361*^9, {
   3.545828639766945*^9, 3.545828660881702*^9}, {3.546089203112962*^9, 
   3.546089218042541*^9}, {3.546089281945047*^9, 3.546089287944528*^9}, 
   3.546089543906431*^9, 3.546089590861506*^9, {3.5460897318376102`*^9, 
   3.546089743182028*^9}, {3.5710750138890457`*^9, 3.571075031606373*^9}, {
   3.571075263201912*^9, 3.57107532321329*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.05666699999994762`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.541937631541799*^9, 3.5419376447142878`*^9}, {
   3.541942661594255*^9, 3.5419426653531647`*^9}, {3.541942855952652*^9, 
   3.54194288412077*^9}, 3.541943046400317*^9, 3.541943138562261*^9, {
   3.54194365812016*^9, 3.541943679181095*^9}, {3.5419438846668386`*^9, 
   3.541943902813586*^9}, {3.541943952567315*^9, 3.54194395599933*^9}, {
   3.541944780362114*^9, 3.5419447860118523`*^9}, 3.5419470475587273`*^9, 
   3.5419470957662277`*^9, 3.541947139435358*^9, 3.541947204161716*^9, 
   3.5419472796985073`*^9, 3.541947314163625*^9, 3.541947372961976*^9, 
   3.541947452080325*^9, {3.541959492127658*^9, 3.5419595054390182`*^9}, 
   3.541962123371587*^9, 3.5419982407412577`*^9, 3.5438097309686117`*^9, 
   3.545828319623249*^9, 3.545828437043242*^9, 3.545828509715361*^9, {
   3.545828639766945*^9, 3.545828660881702*^9}, {3.546089203112962*^9, 
   3.546089218042541*^9}, {3.546089281945047*^9, 3.546089287944528*^9}, 
   3.546089543906431*^9, 3.546089590861506*^9, {3.5460897318376102`*^9, 
   3.546089743182028*^9}, {3.5710750138890457`*^9, 3.571075031606373*^9}, {
   3.571075263201912*^9, 3.571075323245817*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BCs at infinity:", "Subsubsection",
 CellChangeTimes->{{3.5412432060079536`*^9, 3.541243209063484*^9}}],

Cell["\<\
This is needed to extract the coefficients of the asymptotic expansion at \
infinity with enough precision.\
\>", "Text",
 CellChangeTimes->{{3.5710771408231983`*^9, 3.5710771665108023`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "k", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<seriesINF_coupled_2.mx\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ORDinf2", "=", 
   RowBox[{"0", 
    RowBox[{"(", 
     RowBox[{"ORDINF", "+", "1"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesINF", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleB", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["yinf", "i"], "[", "0", "]"}], "\[Rule]", 
      SubscriptBox["BBB", "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleC", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["yinf", "i"], "[", "0", "]"}], "\[Rule]", 
      SubscriptBox["CCC", "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"DIM", "+", "1"}]}], ",", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["ys", "i"], "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               SubscriptBox["yinf", "i"], "[", "j", "]"}], 
              SuperscriptBox["r", "j"]], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
           
           RowBox[{"Union", "[", 
            RowBox[{"seriesINF", ",", "ruleB", ",", 
             RowBox[{"{", 
              RowBox[{"kk", "\[Rule]", 
               RowBox[{"-", "k"}]}], "}"}]}], "]"}]}], ")"}], " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "k"}], " ", "r"}], "]"}], 
         SuperscriptBox["r", 
          RowBox[{"M", 
           FractionBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Mu]", "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}], 
            RowBox[{"-", "k"}]]}]]}], "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             FractionBox[
              RowBox[{
               SubscriptBox["yinf", "i"], "[", "j", "]"}], 
              SuperscriptBox["r", "j"]], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
           
           RowBox[{"Union", "[", 
            RowBox[{"seriesINF", ",", "ruleC", ",", 
             RowBox[{"{", 
              RowBox[{"kk", "\[Rule]", "k"}], "}"}]}], "]"}]}], ")"}], " ", 
         RowBox[{"Exp", "[", 
          RowBox[{"k", " ", "r"}], "]"}], 
         SuperscriptBox["r", 
          RowBox[{"M", 
           FractionBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Mu]", "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}], "k"]}]]}]}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["ysp", "i"], "=", 
       RowBox[{"D", "[", 
        RowBox[{
         SubscriptBox["ys", "i"], ",", "r"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i", "++"}]}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EQss", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["ys", "i"], "\[Equal]", 
          SubscriptBox["Y", "i"]}], ",", 
         RowBox[{
          SubscriptBox["ysp", "i"], "\[Equal]", 
          SubscriptBox["Yp", "i"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solBC", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"EQss", ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["BBB", "i"], ",", 
           SubscriptBox["CCC", "i"]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "]"}]}], "]"}],
     "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "solBC", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"solBC", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"solBC", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.5412414498895063`*^9, 3.541241451825223*^9}, {
   3.541241820429599*^9, 3.541241877067543*^9}, {3.541241914038664*^9, 
   3.5412419185605583`*^9}, {3.5412420194719677`*^9, 
   3.5412420628150597`*^9}, {3.541242243794663*^9, 3.541242325378422*^9}, {
   3.541242377291679*^9, 3.541242449716723*^9}, {3.54124289469874*^9, 
   3.541242917942212*^9}, {3.541242972970052*^9, 3.5412430124490128`*^9}, {
   3.541243183711152*^9, 3.541243198651471*^9}, {3.541243243544005*^9, 
   3.541243295494513*^9}, {3.5412433310756807`*^9, 3.541243384269206*^9}, 
   3.541243602770397*^9, 3.541243894341625*^9, {3.54124405714715*^9, 
   3.541244067574277*^9}, {3.541847436484338*^9, 3.541847436640717*^9}, {
   3.541847838836062*^9, 3.541848167071405*^9}, {3.541848201640787*^9, 
   3.541848229026771*^9}, {3.541848314490859*^9, 3.541848317303603*^9}, {
   3.541848363545184*^9, 3.5418483638943453`*^9}, 3.541848547602251*^9, {
   3.541850196362309*^9, 3.541850198683855*^9}, 3.54185109009702*^9, 
   3.541851148967853*^9, {3.541851404311057*^9, 3.541851404865891*^9}, 
   3.54191223784454*^9, {3.541912274157864*^9, 3.541912276702244*^9}, {
   3.541937194531605*^9, 3.541937199813414*^9}, 3.541937279042328*^9, {
   3.541937485930172*^9, 3.541937488057749*^9}, {3.541959513164097*^9, 
   3.541959537291848*^9}, {3.541959587886135*^9, 3.541959589308745*^9}, {
   3.541962128503869*^9, 3.5419621304469547`*^9}}],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{{3.5418481857170057`*^9, 3.541848208189145*^9}, {
   3.541848311171427*^9, 3.54184831841635*^9}, 3.541848490780714*^9, 
   3.541848548208208*^9, 3.541850199079314*^9, 3.541850777481515*^9, 
   3.5418511434271307`*^9, 3.541851223876232*^9, 3.54185137141302*^9, 
   3.541851406006538*^9, {3.541912247569323*^9, 3.5419122772048283`*^9}, 
   3.5419372011821537`*^9, 3.5419372797992153`*^9, 3.541937488705377*^9, 
   3.541937572770938*^9, 3.541942682006466*^9, 3.5419432339792337`*^9, 
   3.5419436844718657`*^9, 3.541943960868174*^9, 3.541944794048305*^9, 
   3.54194645440329*^9, {3.54195951414432*^9, 3.541959538109655*^9}, 
   3.541959624509214*^9, 3.541959888066235*^9, 3.5419621312100687`*^9, 
   3.541998243086673*^9, 3.5420418533519583`*^9, 3.5429910818506937`*^9, 
   3.543140278577421*^9, 3.543140418179228*^9, 3.543809741174747*^9, 
   3.571075041337859*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<coupled_solBC.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"solBC", ",", "ORDinf2"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.541244182733946*^9, 3.541244185860972*^9}, {
  3.541848560897007*^9, 3.541848561685581*^9}, {3.541850781664557*^9, 
  3.541850781756241*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determinant", "Subsubsection",
 CellChangeTimes->{{3.54184742947585*^9, 3.5418474306843643`*^9}}],

Cell["\<\
Finally, we can construct the determinant obtained by integrating N times \
using an orthogonal basis at the horizon. This steps works for any truncation \
order and, given a real frequency \[Omega], it returns the real function \
Abs[det[M]], where M is the matrix constructed from the coefficients of the \
asymptotic expansion at infinity and imposing the desired boundary condition. \
Note that we use IdentityMatrix[DIM][[i]] to define the i-th element of the \
orthogonal basis at the horizon.\
\>", "Text",
 CellChangeTimes->{{3.5710771751877213`*^9, 3.57107732795113*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "DET", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DET", "[", 
    RowBox[{
    "\[Omega]0_", ",", "\[Mu]0_", ",", "J0_", ",", "EPS_", ",", "INF_"}], 
    "]"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"<<", "\"\<coupled_solBC.mx\>\""}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"uV", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"Null", ",", 
        RowBox[{"{", "DIM", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<", 
        RowBox[{"DIM", "+", "1"}]}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"INT", "[", 
          RowBox[{"\[Omega]0", ",", "\[Mu]0", ",", "J0", ",", 
           RowBox[{
            RowBox[{"IdentityMatrix", "[", "DIM", "]"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", "EPS", ",", "INF"}], "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"ynV", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["y", "ii"], "[", "r", "]"}], "/.", 
             RowBox[{"sol", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ynpV", "=", 
          RowBox[{"D", "[", 
           RowBox[{"ynV", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
         RowBox[{"ruleYY", "=", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              SubscriptBox["Y", "ii"], "\[Rule]", 
              RowBox[{"ynV", "[", 
               RowBox[{"[", "ii", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "/.", 
           RowBox[{"r", "\[Rule]", "rinf"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"ruleYYp", "=", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              SubscriptBox["Yp", "ii"], "\[Rule]", 
              RowBox[{"ynpV", "[", 
               RowBox[{"[", "ii", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"ii", ",", "1", ",", "DIM"}], "}"}]}], "]"}], "/.", 
           RowBox[{"r", "\[Rule]", "rinf"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"ruleYYS", "=", 
          RowBox[{"Union", "[", 
           RowBox[{
           "solBC", ",", "param", ",", "ruleYY", ",", "ruleYYp", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"k", "\[Rule]", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["\[Mu]", "2"], "-", 
                 SuperscriptBox["\[Omega]", "2"]}]]}], ",", 
              RowBox[{"r", "\[Rule]", "rinf"}], ",", 
              RowBox[{"M", "\[Rule]", "1"}]}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"ii", "=", "1"}], ",", 
           RowBox[{"ii", "<", 
            RowBox[{"DIM", "+", "1"}]}], ",", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              SubscriptBox["BF", "ii"], "=", 
              RowBox[{
               SubscriptBox["BBB", "ii"], "//.", "ruleYYS"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              SubscriptBox["CF", "ii"], "=", 
              RowBox[{
               SubscriptBox["CCC", "ii"], "//.", "ruleYYS"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ii", "++"}], ";"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"ii", "=", "1"}], ",", 
           RowBox[{"ii", "<", 
            RowBox[{"DIM", "+", "1"}]}], ",", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              SubscriptBox["ysF", "ii"], "=", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    SubscriptBox["yinf", "ii"], "[", "j", "]"}], 
                    SuperscriptBox["r", "j"]], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
                    RowBox[{"Union", "[", 
                    RowBox[{"seriesINF", ",", "ruleB", ",", 
                    RowBox[{"{", 
                    RowBox[{"kk", "\[Rule]", 
                    RowBox[{"-", "k"}]}], "}"}]}], "]"}]}], ")"}], " ", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "k"}], " ", "r"}], "]"}], 
                    SuperscriptBox["r", 
                    RowBox[{"M", 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], 
                    RowBox[{"-", "k"}]]}]]}], "+", " ", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    SubscriptBox["yinf", "ii"], "[", "j", "]"}], 
                    SuperscriptBox["r", "j"]], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
                    RowBox[{"Union", "[", 
                    RowBox[{"seriesINF", ",", "ruleC", ",", 
                    RowBox[{"{", 
                    RowBox[{"kk", "\[Rule]", "k"}], "}"}]}], "]"}]}], ")"}], 
                    " ", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"k", " ", "r"}], "]"}], 
                    SuperscriptBox["r", 
                    RowBox[{"M", 
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Mu]", "2"], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Omega]", "2"]}]}], ")"}], "k"]}]]}]}], 
                  ")"}], "//.", 
                 RowBox[{"Union", "[", 
                  RowBox[{"param", ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"M", "\[Rule]", "1"}], ",", 
                    RowBox[{"r", "\[Rule]", "rinf"}]}], "}"}], ",", 
                   RowBox[{"Flatten", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["BBB", "iii"], "\[Rule]", 
                    SubscriptBox["BF", "iii"]}], ",", 
                    RowBox[{
                    SubscriptBox["CCC", "iii"], "\[Rule]", 
                    SubscriptBox["CF", "iii"]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"iii", ",", "1", ",", "DIM"}], "}"}]}], "]"}], 
                    "]"}]}], "]"}]}], "/.", 
                RowBox[{"k", "\[Rule]", 
                 SqrtBox[
                  RowBox[{
                   SuperscriptBox["\[Mu]", "2"], "-", 
                   SuperscriptBox["\[Omega]", "2"]}]]}]}], "/.", "param"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"ii", "++"}], ";"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"AinV", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            SubscriptBox["CF", "ii"], ",", 
            RowBox[{"{", 
             RowBox[{"ii", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"uV", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "=", 
          RowBox[{"AinV", "/.", 
           RowBox[{"r", "\[Rule]", "rinf"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"i", "++"}], ";"}], "\[IndentingNewLine]", "}"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"MAT", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"uV", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "[", 
         RowBox[{"[", "k", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "DIM"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "DIM"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"det", "=", 
      RowBox[{"Det", "[", "MAT", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Abs", "[", "det", "]"}], "/.", 
      RowBox[{"r", "\[Rule]", "rinf"}]}]}], "\[IndentingNewLine]", ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<done\>\"", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.541595932854068*^9, 3.541595954356278*^9}, {
   3.541595998053851*^9, 3.541596196205315*^9}, {3.5415964255188417`*^9, 
   3.541596426596339*^9}, {3.54159675458225*^9, 3.5415967685529127`*^9}, {
   3.541596802155857*^9, 3.541596867678046*^9}, {3.5415969281425343`*^9, 
   3.541596962064917*^9}, {3.5415970096644287`*^9, 3.541597088832634*^9}, {
   3.541597233293928*^9, 3.541597264201008*^9}, {3.541597320893488*^9, 
   3.5415973229631968`*^9}, {3.541597363034389*^9, 3.541597390457732*^9}, {
   3.5415996441690083`*^9, 3.541599686606022*^9}, {3.541599720181405*^9, 
   3.54159985045749*^9}, {3.5416020403852587`*^9, 3.541602042214902*^9}, {
   3.541602358121594*^9, 3.541602359726224*^9}, {3.54160337959953*^9, 
   3.541603427683094*^9}, 3.541603702154634*^9, {3.541680488074851*^9, 
   3.5416805492677593`*^9}, {3.541680900748706*^9, 3.541680903257649*^9}, {
   3.5416811432048683`*^9, 3.54168118194737*^9}, {3.541845891841877*^9, 
   3.541845901944418*^9}, {3.541845999382978*^9, 3.5418460565685062`*^9}, {
   3.54184858844512*^9, 3.541848596189067*^9}, {3.541848731285741*^9, 
   3.5418487314396467`*^9}, {3.541848764182022*^9, 3.541848835967456*^9}, {
   3.541848893009334*^9, 3.5418489152754583`*^9}, {3.541849834177638*^9, 
   3.54184990634064*^9}, 3.5418499568178253`*^9, {3.541849990349592*^9, 
   3.541850015722329*^9}, {3.541850105143388*^9, 3.54185011092142*^9}, 
   3.541850156457594*^9, {3.541850239371091*^9, 3.5418502705576*^9}, {
   3.5418503024217663`*^9, 3.541850302822423*^9}, {3.541850349827814*^9, 
   3.541850362859337*^9}, {3.541850437006741*^9, 3.541850635324696*^9}, 
   3.541850711814435*^9, 3.541850895371668*^9, {3.5418509680151443`*^9, 
   3.5418509942132883`*^9}, 3.541851632794291*^9, {3.541912437048984*^9, 
   3.541912455787176*^9}, 3.54193737941304*^9, 3.5419376081352243`*^9, 
   3.541944803315625*^9, {3.541945698912747*^9, 3.541945720005548*^9}, 
   3.541960587588282*^9, {3.571075048981024*^9, 3.5710750607466183`*^9}, {
   3.5710772128747883`*^9, 3.5710772273673477`*^9}, {3.57107730297924*^9, 
   3.571077303136504*^9}, {3.57151931027285*^9, 3.5715193106185226`*^9}}],

Cell[BoxData["\<\"ghi\"\>"], "Print",
 CellChangeTimes->{{3.541603396609913*^9, 3.541603428749488*^9}, 
   3.5416037031113997`*^9, 3.5416037584979753`*^9, {3.541680546536644*^9, 
   3.541680549721085*^9}, 3.541680911799964*^9, 3.5416811835806293`*^9, 
   3.541744961436679*^9, 3.541747178410346*^9, 3.541747408973979*^9, 
   3.5417480771418753`*^9, 3.541846254896352*^9, 3.5418500290225554`*^9, 
   3.541850111839539*^9, 3.541850211515665*^9, 3.541850271906115*^9, 
   3.541850303439027*^9, {3.5418503509827623`*^9, 3.541850363479363*^9}, {
   3.541850448191102*^9, 3.541850476923092*^9}, {3.5418505279108047`*^9, 
   3.541850605690056*^9}, 3.541850636358221*^9, 3.541850712559779*^9, 
   3.5418508959890747`*^9, 3.54185099708801*^9, 3.541851489312624*^9, 
   3.541851633558817*^9, 3.541912292102026*^9, {3.5419124377520638`*^9, 
   3.54191245621518*^9}, 3.5419372073696213`*^9, 3.541937287081827*^9, 
   3.541937380206457*^9, 3.5419374933226*^9, {3.541937578704652*^9, 
   3.541937608606184*^9}, {3.5419426745223837`*^9, 3.541942688238637*^9}, 
   3.541943241233938*^9, 3.541943693479082*^9, 3.541943965940297*^9, {
   3.541944798178916*^9, 3.5419448042062273`*^9}, {3.541945699795906*^9, 
   3.541945720668194*^9}, 3.541946460314353*^9, 3.541947378922668*^9, 
   3.54194745776725*^9, 3.5419595187642727`*^9, 3.5419596437031116`*^9, 
   3.5419598994653683`*^9, 3.541960588185882*^9, 3.541962143813081*^9, 
   3.5419982510071087`*^9, 3.5420418570554733`*^9, 3.5429910883676987`*^9, 
   3.5431402850285378`*^9, 3.543140421960038*^9, 3.543809746743805*^9, 
   3.571075069985024*^9}]
}, Open  ]],

Cell["\<\
Check: for a given real frequency we obtain a real number. Note that this can \
be huge, but everything can be renormalized (see below).\
\>", "Text",
 CellChangeTimes->{{3.5710773348613033`*^9, 3.571077372224853*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Timing", "[", 
  RowBox[{"DET", "[", 
   RowBox[{"0.09999", ",", "0.1", ",", "0.02", ",", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]], ",", 
    RowBox[{"2", " ", 
     SuperscriptBox["10", "3"]}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Abs", "[", 
  SubscriptBox["ysF", "2"], "]"}]}], "Input",
 CellChangeTimes->{{3.5415963638639393`*^9, 3.5415963748184032`*^9}, 
   3.541596614267428*^9, {3.541599832129774*^9, 3.541599832804384*^9}, {
   3.541601482220151*^9, 3.5416015126543913`*^9}, {3.541601615580673*^9, 
   3.5416016419477453`*^9}, {3.5416020527968283`*^9, 3.541602054272517*^9}, {
   3.541603439978504*^9, 3.5416034480985403`*^9}, {3.541603694623374*^9, 
   3.54160371268854*^9}, {3.541680560928537*^9, 3.541680576158352*^9}, {
   3.541680905079217*^9, 3.541680909128636*^9}, {3.54168096753817*^9, 
   3.5416809676057987`*^9}, {3.541850646129266*^9, 3.5418506641087847`*^9}, {
   3.541850718771944*^9, 3.5418507222051563`*^9}, {3.541850841091658*^9, 
   3.541850857261079*^9}, {3.54185090403983*^9, 3.541850912707453*^9}, {
   3.541851005969994*^9, 3.541851012856447*^9}, 3.541851789419938*^9, 
   3.541937262830245*^9, 3.541937293058402*^9, {3.541937593522567*^9, 
   3.541937599227983*^9}, 3.541937657107698*^9, {3.5419432475207663`*^9, 
   3.541943247826532*^9}, {3.541944813331325*^9, 3.54194482805797*^9}, {
   3.5710750794820538`*^9, 3.571075082187819*^9}, {3.5710751938398237`*^9, 
   3.5710751938916693`*^9}, {3.571075329820462*^9, 3.571075335432828*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.2366669999998976`", ",", "1.2591182714403713`*^135"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5415973722369757`*^9, 3.541597392901959*^9}, 
   3.541599237160097*^9, {3.541599826581822*^9, 3.541599853820611*^9}, {
   3.541601476703306*^9, 3.541601519125663*^9}, {3.541601617179921*^9, 
   3.541601654126544*^9}, 3.541601884939789*^9, {3.541602048117559*^9, 
   3.541602055940061*^9}, 3.5416021371509037`*^9, 3.541602571555088*^9, {
   3.541603401832304*^9, 3.541603450551859*^9}, {3.541603698898408*^9, 
   3.541603715986504*^9}, 3.541603773938198*^9, {3.5416805535042543`*^9, 
   3.541680576649006*^9}, {3.5416809095037394`*^9, 3.541680916197199*^9}, 
   3.541680968415134*^9, 3.541681187174177*^9, {3.541846248729866*^9, 
   3.5418462562688217`*^9}, 3.5418500321636133`*^9, 3.5418501148708553`*^9, 
   3.541850213977281*^9, 3.541850274088254*^9, 3.541850304664711*^9, {
   3.541850352730913*^9, 3.5418503647880297`*^9}, {3.541850449958221*^9, 
   3.541850479392687*^9}, {3.5418505320055933`*^9, 3.5418506665784273`*^9}, {
   3.541850713548649*^9, 3.541850724679948*^9}, {3.541850844066311*^9, 
   3.541850860086709*^9}, {3.54185089699156*^9, 3.5418509190055437`*^9}, {
   3.5418509994346943`*^9, 3.541851014979084*^9}, 3.541851494572328*^9, 
   3.5418516392084913`*^9, {3.5418517862096767`*^9, 3.5418517921347933`*^9}, 
   3.541912300758482*^9, 3.541912440133759*^9, 3.541937211000825*^9, {
   3.541937264923064*^9, 3.5419372937204227`*^9}, 3.541937383763071*^9, 
   3.5419374952201643`*^9, {3.5419375826729813`*^9, 3.5419376116259623`*^9}, 
   3.541937657621005*^9, {3.5419426774784727`*^9, 3.541942690957264*^9}, {
   3.541943243948636*^9, 3.5419432483739347`*^9}, 3.541943696921139*^9, 
   3.541943968694292*^9, {3.5419448102373333`*^9, 3.541944828436767*^9}, 
   3.541945702665848*^9, 3.541947382485819*^9, 3.54194746088313*^9, 
   3.54195952093677*^9, 3.541959647963896*^9, 3.54195990228074*^9, 
   3.541962146148951*^9, 3.541998253759225*^9, 3.5429910901917973`*^9, 
   3.543140287321947*^9, 3.543140424478883*^9, 3.543809750187151*^9, 
   3.571075083278183*^9, 3.5710752533430367`*^9, {3.5710753370026712`*^9, 
   3.5710753381072073`*^9}}],

Cell[BoxData["776547.6951474356`"], "Output",
 CellChangeTimes->{{3.5415973722369757`*^9, 3.541597392901959*^9}, 
   3.541599237160097*^9, {3.541599826581822*^9, 3.541599853820611*^9}, {
   3.541601476703306*^9, 3.541601519125663*^9}, {3.541601617179921*^9, 
   3.541601654126544*^9}, 3.541601884939789*^9, {3.541602048117559*^9, 
   3.541602055940061*^9}, 3.5416021371509037`*^9, 3.541602571555088*^9, {
   3.541603401832304*^9, 3.541603450551859*^9}, {3.541603698898408*^9, 
   3.541603715986504*^9}, 3.541603773938198*^9, {3.5416805535042543`*^9, 
   3.541680576649006*^9}, {3.5416809095037394`*^9, 3.541680916197199*^9}, 
   3.541680968415134*^9, 3.541681187174177*^9, {3.541846248729866*^9, 
   3.5418462562688217`*^9}, 3.5418500321636133`*^9, 3.5418501148708553`*^9, 
   3.541850213977281*^9, 3.541850274088254*^9, 3.541850304664711*^9, {
   3.541850352730913*^9, 3.5418503647880297`*^9}, {3.541850449958221*^9, 
   3.541850479392687*^9}, {3.5418505320055933`*^9, 3.5418506665784273`*^9}, {
   3.541850713548649*^9, 3.541850724679948*^9}, {3.541850844066311*^9, 
   3.541850860086709*^9}, {3.54185089699156*^9, 3.5418509190055437`*^9}, {
   3.5418509994346943`*^9, 3.541851014979084*^9}, 3.541851494572328*^9, 
   3.5418516392084913`*^9, {3.5418517862096767`*^9, 3.5418517921347933`*^9}, 
   3.541912300758482*^9, 3.541912440133759*^9, 3.541937211000825*^9, {
   3.541937264923064*^9, 3.5419372937204227`*^9}, 3.541937383763071*^9, 
   3.5419374952201643`*^9, {3.5419375826729813`*^9, 3.5419376116259623`*^9}, 
   3.541937657621005*^9, {3.5419426774784727`*^9, 3.541942690957264*^9}, {
   3.541943243948636*^9, 3.5419432483739347`*^9}, 3.541943696921139*^9, 
   3.541943968694292*^9, {3.5419448102373333`*^9, 3.541944828436767*^9}, 
   3.541945702665848*^9, 3.541947382485819*^9, 3.54194746088313*^9, 
   3.54195952093677*^9, 3.541959647963896*^9, 3.54195990228074*^9, 
   3.541962146148951*^9, 3.541998253759225*^9, 3.5429910901917973`*^9, 
   3.543140287321947*^9, 3.543140424478883*^9, 3.543809750187151*^9, 
   3.571075083278183*^9, 3.5710752533430367`*^9, {3.5710753370026712`*^9, 
   3.571075338109376*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Finding the minima", "Subsubsection",
 CellChangeTimes->{{3.571077382464036*^9, 3.571077390192718*^9}}],

Cell[TextData[{
 "Robust numerical methods can be implemented to find the minima of the \
function DET[\[Omega]]. However, it is instructive to show them directly.\n\
The range of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "R"], "below", " ", "is", " ", "tuned", " ", 
     "in", " ", "order", " ", "to", " ", "show", " ", "3", " ", "minima", " ",
      "when", " ", "\[Mu]M"}], "=", 
    RowBox[{
     RowBox[{"0.1", " ", "and", " ", "J"}], "=", 
     RowBox[{"0.1", 
      SuperscriptBox["M", "2"]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.571075565456369*^9, 3.571075599933339*^9}, {
  3.5710773940040073`*^9, 3.571077430851904*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xi", "=", "0.099871"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xf", "=", "0.099875"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim", "=", "300"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx", "=", 
   FractionBox[
    RowBox[{"xf", "-", "xi"}], "dim"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xx", "=", "xi"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AA", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"Null", ",", 
     RowBox[{"{", "dim", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"dim", "+", "1"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DD", "=", 
        RowBox[{"DET", "[", 
         RowBox[{"xx", ",", "0.1", ",", "0.1", ",", 
          RowBox[{"5", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}], ",", 
          RowBox[{"1", " ", 
           SuperscriptBox["10", "3"]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AA", "[", 
         RowBox[{"[", "j", "]"}], "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"N", "[", "xx", "]"}], ",", 
          SuperscriptBox["DD", "1"]}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"xx", "=", 
        RowBox[{"xx", "+", "dx"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"j", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"N", "[", "xx", "]"}], ",", "DD"}], "}"}]}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.541597406311329*^9, 3.541597527470318*^9}, {
   3.5415975606056004`*^9, 3.5415975629516478`*^9}, {3.541597744425613*^9, 
   3.541597744914958*^9}, {3.541597787313759*^9, 3.541597952534957*^9}, {
   3.541598023092106*^9, 3.541598070213718*^9}, {3.541598354538258*^9, 
   3.541598386131957*^9}, {3.541598441845261*^9, 3.541598488243808*^9}, {
   3.5415986524033537`*^9, 3.541598652721962*^9}, 3.5415987930066853`*^9, {
   3.541599243044725*^9, 3.541599243382536*^9}, {3.5415993136637573`*^9, 
   3.541599357342815*^9}, 3.541600162664467*^9, {3.541600244047831*^9, 
   3.541600247861561*^9}, 3.5416008272422*^9, {3.541600892211269*^9, 
   3.541600892682797*^9}, {3.5416009473439093`*^9, 3.54160095092419*^9}, {
   3.541601005644164*^9, 3.541601005711462*^9}, {3.541601047255989*^9, 
   3.541601047902278*^9}, {3.541601085223756*^9, 3.541601086830822*^9}, {
   3.5416011169092093`*^9, 3.541601120522975*^9}, {3.541601170334381*^9, 
   3.541601170581918*^9}, {3.541601244034047*^9, 3.541601277672902*^9}, {
   3.541601324134796*^9, 3.541601357823413*^9}, {3.541601529057488*^9, 
   3.5416015322176027`*^9}, {3.541601674544387*^9, 3.54160167723073*^9}, {
   3.5416021171672153`*^9, 3.541602148040297*^9}, {3.541602297781186*^9, 
   3.541602300535535*^9}, {3.541602364151915*^9, 3.54160236570532*^9}, 
   3.5416024383909283`*^9, {3.5416034615827637`*^9, 3.541603462876646*^9}, 
   3.541603584217566*^9, {3.541603690483247*^9, 3.541603693029768*^9}, 
   3.54174498707452*^9, {3.5417450535565777`*^9, 3.541745053637308*^9}, {
   3.541745193983878*^9, 3.541745203274469*^9}, 3.541747371298605*^9, {
   3.541747538007379*^9, 3.5417475499221287`*^9}, 3.5417475937447443`*^9, 
   3.541747640331435*^9, 3.541747696507403*^9, {3.541748083105089*^9, 
   3.541748089806314*^9}, {3.541749013576261*^9, 3.54174902568452*^9}, {
   3.541749118084187*^9, 3.541749119895358*^9}, {3.54174926067843*^9, 
   3.54174926077494*^9}, {3.5417494259165707`*^9, 3.54174943719477*^9}, {
   3.541749497705822*^9, 3.541749516789752*^9}, {3.541749550500125*^9, 
   3.541749607947741*^9}, {3.541754025040484*^9, 3.5417540811829767`*^9}, {
   3.541754149265519*^9, 3.54175415364502*^9}, 3.541754189345614*^9, 
   3.541851036844162*^9, {3.541851798774653*^9, 3.5418518020171022`*^9}, 
   3.5418519146746073`*^9, 3.5418532337696466`*^9, {3.541859871966107*^9, 
   3.54185987370297*^9}, {3.541912334053533*^9, 3.541912410873583*^9}, {
   3.541912483513577*^9, 3.5419125056653633`*^9}, {3.5419373140246267`*^9, 
   3.541937362775137*^9}, {3.541937401087489*^9, 3.5419374296443357`*^9}, {
   3.5419375030755672`*^9, 3.54193750986733*^9}, 3.5419376647953444`*^9, {
   3.541943271724119*^9, 3.541943278574748*^9}, {3.541943732577141*^9, 
   3.5419437518145742`*^9}, {3.541944831798307*^9, 3.541944832104733*^9}, {
   3.541944872002274*^9, 3.541944907393282*^9}, {3.541944950857499*^9, 
   3.541944995629073*^9}, {3.541945096845357*^9, 3.5419450970839767`*^9}, {
   3.541945261056703*^9, 3.541945280288254*^9}, {3.541945324077857*^9, 
   3.5419453784371233`*^9}, {3.541945744102816*^9, 3.5419457516624823`*^9}, {
   3.54194618803967*^9, 3.541946230918207*^9}, 3.541946273450371*^9, {
   3.54194631577824*^9, 3.5419463175632353`*^9}, {3.541946358788292*^9, 
   3.5419463802152557`*^9}, {3.5419474793664017`*^9, 3.541947494835409*^9}, 
   3.5419599614458523`*^9, {3.541960014047159*^9, 3.541960016149658*^9}, {
   3.54196034376385*^9, 3.541960355369911*^9}, {3.5419604191428423`*^9, 
   3.5419604199356318`*^9}, {3.541960472548122*^9, 3.5419604762560062`*^9}, 
   3.5419606688654537`*^9, {3.541962234013081*^9, 3.5419622376018353`*^9}, {
   3.5419640751356*^9, 3.54196407525667*^9}, {3.5419641064678383`*^9, 
   3.541964114193274*^9}, {3.541964183642685*^9, 3.541964242601543*^9}, {
   3.541964279348624*^9, 3.541964279497924*^9}, {3.541964318402762*^9, 
   3.5419643194005747`*^9}, 3.541964393794299*^9, {3.5419644477318697`*^9, 
   3.541964514973477*^9}, {3.541964550908437*^9, 3.541964552102592*^9}, {
   3.541964638274719*^9, 3.541964638581552*^9}, {3.541964730929796*^9, 
   3.5419648407205*^9}, {3.5419649201077223`*^9, 3.541964978819488*^9}, {
   3.5419982799193153`*^9, 3.541998352560932*^9}, 3.542041866559627*^9, {
   3.542041920563755*^9, 3.5420420343225946`*^9}, {3.542991110311737*^9, 
   3.542991138761833*^9}, {3.542991416512568*^9, 3.542991431475135*^9}, {
   3.542991756060563*^9, 3.54299204036465*^9}, 3.571075124633871*^9, {
   3.571075165523588*^9, 3.571075186364827*^9}, {3.571075351394504*^9, 
   3.571075452362121*^9}, {3.571075537208233*^9, 3.5710755619005203`*^9}, 
   3.571075608298798*^9, {3.57107743738205*^9, 3.5710774630756598`*^9}}],

Cell["We normalize the function:", "Text",
 CellChangeTimes->{{3.571075623912271*^9, 3.571075628789852*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AA", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       FractionBox[
        RowBox[{
         RowBox[{"AA", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], 
        SuperscriptBox[
         RowBox[{
          RowBox[{"AA", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "1"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AA", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListLogPlot", "[", 
  RowBox[{
   RowBox[{"{", "TT", "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt1Xk4VV0bB2DnHOeYZ1KiVDJEEpEkx2sqIkOShBCSRClSZCyh4VWIRKUo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.099871, -6.625073291998716},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->True,
  FrameTicks->{{{{-6.907755278982137, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-5.298317366548036, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.605170185988092, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0., 
       FormBox[
        TagBox[
         InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {-2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  ImageSize->450,
  Method->{},
  PlotRange->{{0.099871, 0.09987498666666872}, {-6.625073291998716, 
   0.3339955291893505}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{-6.907755278982137, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-5.298317366548036, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.605170185988092, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0., 
      FormBox[
       TagBox[
        InterpretationBox["\"1.000\"", 1., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"5.000\"", 5., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.6592600369327783`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659907, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782628`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.5710756560469513`*^9, 3.5710775253720713`*^9}]
}, Open  ]],

Cell[TextData[{
 "The function det(M) shows three minima which are very close to each other. \
These correspond to a spectrum: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     SubscriptBox["\[Omega]", "R"], "2"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Mu]", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"M", " ", "\[Mu]"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
            "l", " ", "+", " ", "n", " ", "+", " ", "S", " ", "+", " ", "1"}],
             ")"}]}], ")"}], "^", "2"}]}], ")"}]}], "+", 
     RowBox[{"O", "(", 
      SuperscriptBox["\[Mu]", "4"], ")"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", where  l is the harmonic index, n is the overtone number and S is the \
polarization (S=0 for axial modes, S=\[PlusMinus]1 for polar modes). The \
three minima appear because of an approximate degeneracy (exact at order ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], ")"}], ".", " ", "In"}], " ", "this", 
       " ", "case", " ", "l"}], "+", "n", "+", "S"}], "=", 
     RowBox[{
     "1", " ", "can", " ", "be", " ", "obtained", " ", "by", " ", "three", 
      " ", "choises", " ", "of", " ", 
      RowBox[{"(", 
       RowBox[{"l", ",", "n", ",", "S"}], ")"}]}]}], ",", " ", 
    RowBox[{"namely", ":", "  ", 
     RowBox[{"(", 
      RowBox[{"1", ",", "0", ",", "0"}], ")"}]}], ",", " ", 
    RowBox[{"(", 
     RowBox[{"2", ",", "0", ",", 
      RowBox[{"-", "1"}]}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{"1", ",", "1", ",", 
      RowBox[{"-", "1"}]}], ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The first correspond to an axial modes, while the second and the third \
correspond to the fundamental and to the first polar overtone."
}], "Text",
 CellChangeTimes->{{3.571075914741465*^9, 3.5710762039554157`*^9}}],

Cell["\<\
The real and the imaginary part of the mode (in modulus) can be obtained by \
zooming around one minimum and fitting data with a quadratic function [see \
Reference].\
\>", "Text",
 CellChangeTimes->{{3.571080895164296*^9, 3.571080927273464*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.571080888818657*^9, 3.571080889631693*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.571075951085713*^9, 3.571075952719006*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1366, 725},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 87, 1, 28, "Input"],
Cell[CellGroupData[{
Cell[669, 25, 920, 20, 92, "Subtitle"],
Cell[1592, 47, 467, 12, 46, "Input"],
Cell[2062, 61, 333, 6, 28, "Text"],
Cell[CellGroupData[{
Cell[2420, 71, 175, 2, 27, "Subsubsection"],
Cell[2598, 75, 277, 6, 29, "Text"],
Cell[2878, 83, 135934, 3418, 3563, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[138849, 3506, 172, 2, 21, "Subsubsection"],
Cell[139024, 3510, 126, 3, 27, "Text"],
Cell[139153, 3515, 477, 14, 28, "Input"],
Cell[139633, 3531, 1241, 34, 63, "Input"],
Cell[140877, 3567, 153, 2, 27, "Text"],
Cell[141033, 3571, 68, 2, 28, "Input"],
Cell[141104, 3575, 380, 6, 27, "Text"],
Cell[141487, 3583, 1348, 40, 46, "Input"],
Cell[142838, 3625, 1183, 38, 63, "Input"],
Cell[144024, 3665, 136, 3, 27, "Text"],
Cell[144163, 3670, 263, 7, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144463, 3682, 110, 1, 27, "Subsubsection"],
Cell[144576, 3685, 83, 2, 28, "Input"],
Cell[144662, 3689, 193, 4, 28, "Text"],
Cell[144858, 3695, 135, 3, 28, "Input"],
Cell[144996, 3700, 449, 8, 45, "Text"],
Cell[145448, 3710, 982, 35, 63, "Input"],
Cell[146433, 3747, 281, 5, 43, "Text"],
Cell[146717, 3754, 3492, 81, 80, "Input"],
Cell[150212, 3837, 110, 1, 27, "Text"],
Cell[150325, 3840, 656, 20, 63, "Input"],
Cell[150984, 3862, 134, 3, 27, "Text"],
Cell[151121, 3867, 1417, 47, 80, "Input"],
Cell[152541, 3916, 103, 1, 27, "Text"],
Cell[152647, 3919, 370, 13, 69, "Input"],
Cell[153020, 3934, 871, 27, 63, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153928, 3966, 100, 1, 27, "Subsubsection"],
Cell[154031, 3969, 227, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[154283, 3977, 2283, 62, 97, "Input"],
Cell[156569, 4041, 1433, 21, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158039, 4067, 2495, 68, 165, "Input"],
Cell[160537, 4137, 836, 12, 28, "Output"],
Cell[161376, 4151, 836, 12, 28, "Output"]
}, Open  ]],
Cell[162227, 4166, 127, 3, 27, "Text"],
Cell[162357, 4171, 561, 13, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162955, 4189, 212, 3, 27, "Subsubsection"],
Cell[163170, 4194, 235, 4, 28, "Text"],
Cell[163408, 4200, 3209, 85, 186, "Input"],
Cell[CellGroupData[{
Cell[166642, 4289, 5789, 148, 262, "Input"],
Cell[172434, 4439, 486, 7, 29, "Output"]
}, Open  ]],
Cell[172935, 4449, 258, 6, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[173230, 4460, 159, 2, 21, "Subsubsection"],
Cell[173392, 4464, 207, 4, 28, "Text"],
Cell[173602, 4470, 3762, 100, 207, "Input"],
Cell[CellGroupData[{
Cell[177389, 4574, 5138, 143, 340, "Input"],
Cell[182530, 4719, 654, 10, 29, "Output"]
}, Open  ]],
Cell[183199, 4732, 290, 7, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[183526, 4744, 105, 1, 21, "Subsubsection"],
Cell[183634, 4747, 179, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[183838, 4755, 8331, 202, 676, "Input"],
Cell[192172, 4959, 1119, 16, 28, "Output"],
Cell[193294, 4977, 1250, 18, 21, "Print"]
}, Open  ]],
Cell[194559, 4998, 130, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[194714, 5005, 1581, 29, 85, "Input"],
Cell[196298, 5036, 1169, 16, 28, "Output"],
Cell[197470, 5054, 1243, 18, 28, "Output"],
Cell[198716, 5074, 1236, 18, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[200001, 5098, 109, 1, 27, "Subsubsection"],
Cell[200113, 5101, 201, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[200339, 5109, 6306, 170, 395, "Input"],
Cell[206648, 5281, 913, 13, 28, "Output"]
}, Open  ]],
Cell[207576, 5297, 480, 12, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208093, 5314, 103, 1, 27, "Subsubsection"],
Cell[208199, 5317, 590, 9, 62, "Text"],
Cell[CellGroupData[{
Cell[208814, 5330, 11499, 259, 865, "Input"],
Cell[220316, 5591, 1580, 22, 21, "Print"]
}, Open  ]],
Cell[221911, 5616, 228, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[222164, 5624, 1516, 25, 53, "Input"],
Cell[223683, 5651, 2193, 32, 38, "Output"],
Cell[225879, 5685, 2119, 29, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[228047, 5720, 109, 1, 27, "Subsubsection"],
Cell[228159, 5723, 728, 18, 48, "Text"],
Cell[228890, 5743, 6364, 113, 282, "Input"],
Cell[235257, 5858, 108, 1, 27, "Text"],
Cell[CellGroupData[{
Cell[235390, 5863, 1033, 31, 79, "Input"],
Cell[236426, 5896, 18322, 362, 279, "Output"]
}, Open  ]],
Cell[254763, 6261, 2075, 56, 106, "Text"],
Cell[256841, 6319, 256, 5, 27, "Text"],
Cell[257100, 6326, 92, 1, 28, "Input"],
Cell[257195, 6329, 92, 1, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
