(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    336678,       9457]
NotebookOptionsPosition[    323924,       9066]
NotebookOutlinePosition[    324259,       9081]
CellTagsIndexPosition[    324216,       9078]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Gravitational perturbations of a Kerr BH to first order in the spin\n",
 StyleBox["Reference: Paolo Pani, \[OpenCurlyDoubleQuote]Advanced methods in \
Black-Hole Perturbation Theory\[CloseCurlyDoubleQuote] (2013)",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{{3.537166800678636*^9, 3.537166824376327*^9}, {
  3.570731826826799*^9, 3.570731827006875*^9}}],

Cell["Regge-Wheeler gauge:", "Text",
 CellChangeTimes->{{3.5707372564382687`*^9, 3.570737263645405*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ClearAll", "[", 
  RowBox[{
  "GM0", ",", "x", ",", "g", ",", "\[Phi]", ",", "\[Phi]0", ",", 
   "\[CapitalLambda]", ",", "\[CapitalPsi]", ",", "\[Alpha]", ",", "\[Gamma]",
    ",", "Y", ",", "\[CapitalSigma]", ",", "\[CapitalDelta]", ",", "NN", ",", 
   "\[Omega]", ",", "\[CapitalDelta]", ",", "\[CapitalSigma]", ",", "gff", 
   ",", "gtt", ",", "\[Phi]", ",", "M", ",", "F", ",", "V", ",", "f0", ",", 
   "f1", ",", "f2", ",", "f3", ",", "f4", ",", "\[CapitalOmega]", ",", "A", 
   ",", "\[Phi]", ",", "B", ",", "\[Zeta]", ",", "\[Phi]", ",", 
   "\[CapitalPhi]1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[LessEqual]", "\[Pi]"}], ",", 
     RowBox[{"J", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"NN", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"rh", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"X", "\[GreaterEqual]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "=", 
    RowBox[{"{", 
     RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gdd0", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"F", "[", "r", "]"}]}], ",", "0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"X", "[", "\[Theta]", "]"}]}], "\[Epsilon]a", "*", 
         RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        SuperscriptBox[
         RowBox[{"B", "[", "r", "]"}], 
         RowBox[{"-", "1"}]], ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        SuperscriptBox["r", "2"], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"X", "[", "\[Theta]", "]"}]}], "\[Epsilon]a", "*", 
         RowBox[{"\[Zeta]", "[", "r", "]"}]}], ",", "0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["r", "2"], 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gddPOLAR", "=", 
   RowBox[{"\[Epsilon]p", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H0", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"H1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"H2", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["r", "2"], 
         RowBox[{"KK", "[", 
          RowBox[{"r", ",", "t"}], "]"}], 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["r", "2"], 
         RowBox[{"KK", "[", 
          RowBox[{"r", ",", "t"}], "]"}], 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]}], "}"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gddAXIAL", "=", 
    RowBox[{"\[Epsilon]p", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[Theta]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"h1", "[", 
           RowBox[{"r", ",", "t"}], "]"}], 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
         "0"}], "}"}]}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ORDERa", "=", "1"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "this", " ", "is", " ", "the", " ", "order", " ", "of", " ", "the", " ", 
    "perturbative", " ", "scheme", " ", "in", " ", "the", " ", "angular", " ",
     "momentum"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ORDERp", "=", "1"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "this", " ", "is", " ", "the", " ", "order", " ", "of", " ", "the", " ", 
    "perturbative", " ", "scheme", " ", "in", " ", "the", " ", "field", " ", 
    "perturbations"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "gddAXIAL", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MatrixForm", "[", "gddPOLAR", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"$HistoryLength", "=", "0"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.496820244298901*^9, {3.4968203558284407`*^9, 3.4968203581404247`*^9}, {
   3.49682248740961*^9, 3.496822507434391*^9}, {3.496822916648978*^9, 
   3.496822924245894*^9}, {3.4968253627796383`*^9, 3.496825365436624*^9}, 
   3.504365165228209*^9, 3.5043809459936323`*^9, {3.504438008491736*^9, 
   3.5044380168067007`*^9}, {3.504495748442292*^9, 3.5044957514036427`*^9}, {
   3.504496120769294*^9, 3.5044961214237957`*^9}, {3.5045400430935097`*^9, 
   3.504540043486771*^9}, 3.504540099117354*^9, {3.504855376546852*^9, 
   3.504855377019938*^9}, {3.5070126406487007`*^9, 3.5070126683387003`*^9}, {
   3.5070165389565005`*^9, 3.507016542543501*^9}, {3.5070192092245007`*^9, 
   3.5070192094035006`*^9}, {3.5070197713987007`*^9, 3.5070197715859003`*^9}, 
   3.5072287166493998`*^9, {3.5370790428078938`*^9, 3.537079043326592*^9}, {
   3.537082332873783*^9, 3.537082336116788*^9}, {3.537082380862068*^9, 
   3.537082398365637*^9}, {3.537083684886382*^9, 3.537083686680084*^9}, {
   3.537083807108232*^9, 3.537083809984517*^9}, {3.537084029485549*^9, 
   3.537084029592424*^9}, {3.537084228699411*^9, 3.537084229009631*^9}, {
   3.537093739462956*^9, 3.537093837223934*^9}, {3.537094060161274*^9, 
   3.537094250708188*^9}, {3.537094294240178*^9, 3.537094391948748*^9}, {
   3.537098735560296*^9, 3.537098742730391*^9}, 3.537098777194285*^9, 
   3.5370992500223923`*^9, {3.537100125866765*^9, 3.5371001690948153`*^9}, {
   3.537100225767215*^9, 3.537100259114603*^9}, {3.537100305753476*^9, 
   3.5371003081749353`*^9}, {3.537100491593274*^9, 3.5371004924902477`*^9}, {
   3.537158374354004*^9, 3.537158410503768*^9}, 3.537158797548081*^9, {
   3.537158899745922*^9, 3.537158932610425*^9}, {3.537159695644637*^9, 
   3.537159703152467*^9}, {3.537159958755862*^9, 3.5371599659978447`*^9}, {
   3.537160571391717*^9, 3.53716061470122*^9}, {3.5371607191431713`*^9, 
   3.537160723528596*^9}, {3.537160855851684*^9, 3.537160857974311*^9}, 
   3.5371608929671307`*^9, {3.537160936616355*^9, 3.537160951620933*^9}, {
   3.5371611515848303`*^9, 3.537161190246645*^9}, {3.537161265251857*^9, 
   3.537161266644121*^9}, {3.5371623243443117`*^9, 3.5371623330720263`*^9}, {
   3.53716364472329*^9, 3.537163666152609*^9}, 3.537165626663948*^9, 
   3.5371667811150513`*^9, 3.53716685907119*^9, {3.5371675934571466`*^9, 
   3.537167596308173*^9}, 3.5371676307084017`*^9, {3.538477915363757*^9, 
   3.538477978002437*^9}, {3.538478215699177*^9, 3.538478262124633*^9}, {
   3.538478293275176*^9, 3.538478395622587*^9}, {3.5387267262357492`*^9, 
   3.538726728116671*^9}, {3.538733367565587*^9, 3.538733368090104*^9}, 
   3.538888288897168*^9, 3.5389371326852503`*^9, 3.540563212618326*^9, 
   3.5422811055975857`*^9, {3.542281143747985*^9, 3.542281161345149*^9}, {
   3.542282443454936*^9, 3.5422824435954037`*^9}, {3.5422848992092533`*^9, 
   3.5422849003328333`*^9}, {3.542285725544567*^9, 3.54228572957697*^9}, {
   3.5422873780596027`*^9, 3.542287378472988*^9}, 3.545057336620832*^9, 
   3.5561916612417316`*^9, {3.5707318303585997`*^9, 3.570731830872801*^9}, {
   3.570737245553772*^9, 3.570737279889409*^9}, {3.571520445201309*^9, 
   3.5715204458260717`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]},
     {"0", "0", 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", "0"},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.537167594136692*^9, 3.53716759715031*^9}, 
   3.5371676311333523`*^9, 3.537168501698287*^9, 3.53716997445231*^9, 
   3.538396060717811*^9, {3.5384770196501093`*^9, 3.5384770305112133`*^9}, 
   3.538478373193861*^9, 3.538478403640004*^9, {3.538726719897394*^9, 
   3.538726728501598*^9}, 3.538733372674468*^9, 3.538818255023616*^9, 
   3.538818353972013*^9, 3.538819605227277*^9, 3.538836546488605*^9, 
   3.538888290769209*^9, {3.538937127192237*^9, 3.538937133051347*^9}, 
   3.538979849298897*^9, 3.538982034296434*^9, 3.539082180421177*^9, 
   3.5405629161346397`*^9, 3.54056321301371*^9, 3.5406053460982656`*^9, 
   3.542105451711419*^9, 3.542105496919793*^9, {3.542281138401196*^9, 
   3.542281161909672*^9}, 3.5422824449063597`*^9, 3.5422857349885807`*^9, 
   3.5422874663786163`*^9, 3.545057187085155*^9, 3.545057338138183*^9, 
   3.5560255564995193`*^9, 3.556080143406055*^9, 3.556191662926692*^9, 
   3.57073183171495*^9, {3.5707372480323467`*^9, 3.5707372803835278`*^9}, 
   3.572207694122532*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"H0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"H1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", "0"},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"H1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"H2", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", "\[Epsilon]p", " ", 
       RowBox[{"KK", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", "\[Epsilon]p", " ", 
       RowBox[{"KK", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.537167594136692*^9, 3.53716759715031*^9}, 
   3.5371676311333523`*^9, 3.537168501698287*^9, 3.53716997445231*^9, 
   3.538396060717811*^9, {3.5384770196501093`*^9, 3.5384770305112133`*^9}, 
   3.538478373193861*^9, 3.538478403640004*^9, {3.538726719897394*^9, 
   3.538726728501598*^9}, 3.538733372674468*^9, 3.538818255023616*^9, 
   3.538818353972013*^9, 3.538819605227277*^9, 3.538836546488605*^9, 
   3.538888290769209*^9, {3.538937127192237*^9, 3.538937133051347*^9}, 
   3.538979849298897*^9, 3.538982034296434*^9, 3.539082180421177*^9, 
   3.5405629161346397`*^9, 3.54056321301371*^9, 3.5406053460982656`*^9, 
   3.542105451711419*^9, 3.542105496919793*^9, {3.542281138401196*^9, 
   3.542281161909672*^9}, 3.5422824449063597`*^9, 3.5422857349885807`*^9, 
   3.5422874663786163`*^9, 3.545057187085155*^9, 3.545057338138183*^9, 
   3.5560255564995193`*^9, 3.556080143406055*^9, 3.556191662926692*^9, 
   3.57073183171495*^9, {3.5707372480323467`*^9, 3.5707372803835278`*^9}, 
   3.5722076941304617`*^9}]
}, Open  ]],

Cell[TextData[{
 "To speed up computations sometimes we defined ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "[", "\[Theta]", "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], ".", " ", "The"}], " ", 
     "rules", " ", "below", " ", "are", " ", "just", " ", "to", " ", 
     "simplify", " ", "the", " ", 
     RowBox[{"equations", ":"}]}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.570722807980754*^9, 3.5707228508683853`*^9}, {
  3.570727036383542*^9, 3.570727070086615*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BISERIES", "[", "Z_", "]"}], ":=", 
   RowBox[{"Z", "/.", 
    RowBox[{"Union", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{"X", "'"}], "[", "\[Theta]", "]"}], "2"], "\[Rule]", 
        RowBox[{"4", " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"X", "[", "\[Theta]", "]"}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "''"}], "[", "\[Theta]", "]"}], "\[Rule]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", 
            RowBox[{"X", "[", "\[Theta]", "]"}]}]}], ")"}]}]}]}], "}"}], 
     "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.537167513618392*^9, 3.537167572937948*^9}, {
   3.537167618115941*^9, 3.537167620075329*^9}, {3.537168510852565*^9, 
   3.537168511006523*^9}, {3.537168652069378*^9, 3.53716865288174*^9}, {
   3.5371688036997557`*^9, 3.537168803848173*^9}, 3.537169984251697*^9, 
   3.53839610848531*^9, {3.5388883043537416`*^9, 3.5388883079995327`*^9}, {
   3.538937141321041*^9, 3.5389371416332283`*^9}, {3.570731845879094*^9, 
   3.570731846012265*^9}}],

Cell["Metric, inverse and determinant:", "Text",
 CellChangeTimes->{{3.570722868173148*^9, 3.5707228747375917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gdd", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"gdd0", "+", "gddPOLAR", "+", "gddAXIAL"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"guu", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Inverse", "[", "gdd", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DET", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Det", "[", "gdd", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim", "=", 
   RowBox[{"Length", "[", "gdd", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"gdd", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "j", "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "gdd", "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "guu", "]"}]}], "Input",
 CellChangeTimes->{{3.496822745111134*^9, 3.4968227573539257`*^9}, {
   3.5070135576051006`*^9, 3.5070135731427007`*^9}, 3.5370938075446243`*^9, 
   3.537095344094717*^9, {3.537098138756166*^9, 3.537098146563369*^9}, {
   3.537098271648501*^9, 3.5370982751763487`*^9}, {3.537098684015606*^9, 
   3.537098700926721*^9}, {3.537098757113214*^9, 3.537098786418333*^9}, {
   3.537159707508955*^9, 3.5371597153437366`*^9}, {3.5371599807500267`*^9, 
   3.5371599814632893`*^9}, {3.5371668606922827`*^9, 3.537166870885435*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        RowBox[{"F", "[", "r", "]"}]}], "+", 
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"H0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"H1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[CurlyPhi]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{"\[Epsilon]a", " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"\[Zeta]", "[", "r", "]"}]}]}]},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"H1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{
       FractionBox["1", 
        RowBox[{"B", "[", "r", "]"}]], "+", 
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"H2", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]},
     {
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h0", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Epsilon]p", " ", 
          RowBox[{"KK", "[", 
           RowBox[{"r", ",", "t"}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], 
      "0"},
     {
      RowBox[{
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[CurlyPhi]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{"\[Epsilon]a", " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], 
      RowBox[{"\[Epsilon]p", " ", 
       RowBox[{"h1", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"S\[CurlyPhi]", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "0", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Epsilon]p", " ", 
          RowBox[{"KK", "[", 
           RowBox[{"r", ",", "t"}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.537160204249015*^9, 3.537160628530621*^9, 3.537160735436764*^9, 
   3.537160915769443*^9, 3.537160958041258*^9, 3.537161297346287*^9, 
   3.5371623375111437`*^9, 3.53716563679412*^9, 3.537166831423455*^9, 
   3.537166872153428*^9, 3.537167636419076*^9, 3.5371685193712606`*^9, 
   3.537168655407276*^9, 3.537168805822556*^9, 3.5371699901482773`*^9, 
   3.538396137616115*^9, 3.538477036896349*^9, 3.538726733348509*^9, 
   3.538733376961267*^9, 3.53881825890903*^9, 3.5388183573761673`*^9, 
   3.538819611027318*^9, 3.538836550587576*^9, 3.538888310502305*^9, 
   3.538937150029627*^9, 3.5389798684643307`*^9, 3.538982037276672*^9, 
   3.539082185180887*^9, 3.540562919240944*^9, 3.540563215961031*^9, 
   3.540605352184762*^9, 3.5421054999909563`*^9, 3.5422811716265297`*^9, 
   3.542282450653829*^9, 3.5422857409046717`*^9, 3.5422874684302073`*^9, 
   3.545057193548231*^9, 3.545057342450118*^9, {3.556025561990106*^9, 
   3.556025567370349*^9}, 3.556080147869814*^9, 3.55619167095921*^9, 
   3.570731850132638*^9, 3.570737293256675*^9, 3.572207712067416*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"F", "[", "r", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", "\[Epsilon]p", " ", 
          RowBox[{"H0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
         RowBox[{"2", " ", "\[Epsilon]a", " ", "\[Epsilon]p", " ", 
          RowBox[{"h0", "[", 
           RowBox[{"r", ",", "t"}], "]"}], " ", 
          RowBox[{"S\[CurlyPhi]", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
          RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"F", "[", "r", "]"}], "2"]}]]}], 
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"B", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"H1", "[", 
            RowBox[{"r", ",", "t"}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{"\[Epsilon]a", " ", 
           RowBox[{"h1", "[", 
            RowBox[{"r", ",", "t"}], "]"}], " ", 
           RowBox[{"S\[CurlyPhi]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
           RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]], 
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[Theta]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Epsilon]a"}], " ", "\[Epsilon]p", " ", 
         RowBox[{"H0", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
         RowBox[{"\[Zeta]", "[", "r", "]"}]}], "+", 
        RowBox[{
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Epsilon]p", " ", 
            RowBox[{"h0", "[", 
             RowBox[{"r", ",", "t"}], "]"}], " ", 
            RowBox[{"S\[CurlyPhi]", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
           RowBox[{"\[Epsilon]a", " ", 
            RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"\[Epsilon]p", " ", 
               RowBox[{"KK", "[", 
                RowBox[{"r", ",", "t"}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}], 
            " ", 
            RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], "2"], " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}]}]]},
     {
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"B", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"H1", "[", 
            RowBox[{"r", ",", "t"}], "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{"\[Epsilon]a", " ", 
           RowBox[{"h1", "[", 
            RowBox[{"r", ",", "t"}], "]"}], " ", 
           RowBox[{"S\[CurlyPhi]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
           RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]], 
      RowBox[{
       RowBox[{"B", "[", "r", "]"}], "-", 
       RowBox[{"\[Epsilon]p", " ", 
        SuperscriptBox[
         RowBox[{"B", "[", "r", "]"}], "2"], " ", 
        RowBox[{"H2", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"B", "[", "r", "]"}], " ", 
         RowBox[{"h1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"S\[Theta]", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"B", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", "r", "]"}], " ", 
            RowBox[{"h1", "[", 
             RowBox[{"r", ",", "t"}], "]"}], " ", 
            RowBox[{"S\[CurlyPhi]", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
           RowBox[{"\[Epsilon]a", " ", 
            RowBox[{"H1", "[", 
             RowBox[{"r", ",", "t"}], "]"}], " ", 
            RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
            RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]]}]},
     {
      FractionBox[
       RowBox[{"\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[Theta]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"B", "[", "r", "]"}], " ", 
         RowBox[{"h1", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"S\[Theta]", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
        SuperscriptBox["r", "2"]]}], 
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"KK", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], 
      FractionBox[
       RowBox[{"\[Epsilon]a", " ", "\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[Theta]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
        RowBox[{"\[Zeta]", "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Epsilon]a"}], " ", "\[Epsilon]p", " ", 
         RowBox[{"H0", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
         RowBox[{"\[Zeta]", "[", "r", "]"}]}], "+", 
        RowBox[{
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Epsilon]p", " ", 
            RowBox[{"h0", "[", 
             RowBox[{"r", ",", "t"}], "]"}], " ", 
            RowBox[{"S\[CurlyPhi]", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
           RowBox[{"\[Epsilon]a", " ", 
            RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"\[Epsilon]p", " ", 
               RowBox[{"KK", "[", 
                RowBox[{"r", ",", "t"}], "]"}], " ", 
               RowBox[{"Y", "[", 
                RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}], 
            " ", 
            RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], ")"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], "2"], " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}]}]], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Epsilon]p", " ", 
         RowBox[{"B", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", "r", "]"}], " ", 
            RowBox[{"h1", "[", 
             RowBox[{"r", ",", "t"}], "]"}], " ", 
            RowBox[{"S\[CurlyPhi]", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
           RowBox[{"\[Epsilon]a", " ", 
            RowBox[{"H1", "[", 
             RowBox[{"r", ",", "t"}], "]"}], " ", 
            RowBox[{"X", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
            RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"X", "[", "\[Theta]", "]"}]}]]}], 
      FractionBox[
       RowBox[{"\[Epsilon]a", " ", "\[Epsilon]p", " ", 
        RowBox[{"h0", "[", 
         RowBox[{"r", ",", "t"}], "]"}], " ", 
        RowBox[{"S\[Theta]", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
        RowBox[{"\[Zeta]", "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        RowBox[{"F", "[", "r", "]"}]}]], 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"F", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[Epsilon]p", " ", 
            RowBox[{"KK", "[", 
             RowBox[{"r", ",", "t"}], "]"}], " ", 
            RowBox[{"Y", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], 
        "+", 
        RowBox[{"2", " ", "\[Epsilon]a", " ", "\[Epsilon]p", " ", 
         RowBox[{"h0", "[", 
          RowBox[{"r", ",", "t"}], "]"}], " ", 
         RowBox[{"S\[CurlyPhi]", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
         RowBox[{"\[Zeta]", "[", "r", "]"}]}]}], 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        RowBox[{"F", "[", "r", "]"}], " ", 
        RowBox[{"X", "[", "\[Theta]", "]"}]}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.537160204249015*^9, 3.537160628530621*^9, 3.537160735436764*^9, 
   3.537160915769443*^9, 3.537160958041258*^9, 3.537161297346287*^9, 
   3.5371623375111437`*^9, 3.53716563679412*^9, 3.537166831423455*^9, 
   3.537166872153428*^9, 3.537167636419076*^9, 3.5371685193712606`*^9, 
   3.537168655407276*^9, 3.537168805822556*^9, 3.5371699901482773`*^9, 
   3.538396137616115*^9, 3.538477036896349*^9, 3.538726733348509*^9, 
   3.538733376961267*^9, 3.53881825890903*^9, 3.5388183573761673`*^9, 
   3.538819611027318*^9, 3.538836550587576*^9, 3.538888310502305*^9, 
   3.538937150029627*^9, 3.5389798684643307`*^9, 3.538982037276672*^9, 
   3.539082185180887*^9, 3.540562919240944*^9, 3.540563215961031*^9, 
   3.540605352184762*^9, 3.5421054999909563`*^9, 3.5422811716265297`*^9, 
   3.542282450653829*^9, 3.5422857409046717`*^9, 3.5422874684302073`*^9, 
   3.545057193548231*^9, 3.545057342450118*^9, {3.556025561990106*^9, 
   3.556025567370349*^9}, 3.556080147869814*^9, 3.55619167095921*^9, 
   3.570731850132638*^9, 3.570737293256675*^9, 3.572207712076673*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic definitions (it can take some minutes!)", "Subsubsection",
 CellChangeTimes->{{3.537161564095697*^9, 3.537161574439938*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Christ", "[", 
       RowBox[{"i", ",", "j", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "[", 
               RowBox[{"[", "l", "]"}], "]"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"D", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"gdd", "[", 
                    RowBox[{"[", "l", "]"}], "]"}], "[", 
                   RowBox[{"[", "i", "]"}], "]"}], ",", 
                  RowBox[{"x", "[", 
                   RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{
                  RowBox[{"g", "[", 
                   RowBox[{"l", ",", "j"}], "]"}], ",", 
                  RowBox[{"x", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "-", 
                RowBox[{"D", "[", 
                 RowBox[{
                  RowBox[{"g", "[", 
                   RowBox[{"j", ",", "i"}], "]"}], ",", 
                  RowBox[{"x", "[", 
                   RowBox[{"[", "l", "]"}], "]"}]}], "]"}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5370982945120773`*^9, 3.537098338999887*^9}, 
   3.5370987011902533`*^9, {3.537159292461233*^9, 3.537159293431672*^9}, {
   3.537159569384078*^9, 3.537159571377721*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Ruddd", "[", 
       RowBox[{"a", ",", "i", ",", "j", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"Christ", "[", 
               RowBox[{"i", ",", "k", ",", "a"}], "]"}], ",", 
              RowBox[{"x", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "-", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"Christ", "[", 
               RowBox[{"i", ",", "j", ",", "a"}], "]"}], ",", 
              RowBox[{"x", "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], "]"}], "+", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Christ", "[", 
                 RowBox[{"i", ",", "k", ",", "\[Beta]"}], "]"}], 
                RowBox[{"Christ", "[", 
                 RowBox[{"\[Beta]", ",", "j", ",", "a"}], "]"}]}], "-", 
               RowBox[{
                RowBox[{"Christ", "[", 
                 RowBox[{"i", ",", "j", ",", "\[Beta]"}], "]"}], 
                RowBox[{"Christ", "[", 
                 RowBox[{"\[Beta]", ",", "k", ",", "a"}], "]"}]}]}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Beta]", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.537098105815898*^9, 3.537098344503994*^9, {3.537098643614915*^9, 
   3.537098644536149*^9}, {3.537098809670596*^9, 3.5370988163403387`*^9}, {
   3.5371016497858553`*^9, 3.53710165396139*^9}, {3.53715845179491*^9, 
   3.5371584631917877`*^9}, {3.537159580527854*^9, 3.537159583690487*^9}, {
   3.53716004279412*^9, 3.5371600485159893`*^9}, {3.537161317859391*^9, 
   3.537161320648589*^9}, {3.537168525340242*^9, 3.53716853028098*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"66.17999300000001`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.537168640871715*^9, 3.537168775696789*^9, 
  3.537168843307889*^9, 3.537170101679109*^9, 3.538396250881109*^9, 
  3.538477134039195*^9, 3.538726738603056*^9, 3.538733381666245*^9, 
  3.538937155556827*^9, 3.538979876505892*^9, 3.538982039959239*^9, 
  3.5390821895652733`*^9, 3.54056292195262*^9, 3.54228125960607*^9, 
  3.5422825271499166`*^9, 3.542285818111177*^9, 3.5422875448292217`*^9, 
  3.545057270403833*^9, 3.5450573476986723`*^9, 3.556025575002488*^9, 
  3.55608015799319*^9, 3.570731940641626*^9, 3.570737374084426*^9, 
  3.572207789645403*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Ricci", "[", 
       RowBox[{"i", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"Ruddd", "[", 
              RowBox[{"l", ",", "i", ",", "l", ",", "k"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537162534655031*^9, 3.5371625374284153`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Ruu", "[", 
       RowBox[{"i", ",", "k"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Ricci", "[", 
               RowBox[{"l", ",", "m"}], "]"}], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "l", "]"}], "]"}], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "[", 
               RowBox[{"[", "m", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "1", ",", "dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"m", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{
  3.5371008115867167`*^9, {3.537162539777337*^9, 3.5371625431261683`*^9}}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.5722078184991827`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SCAL", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"guu", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], 
           RowBox[{"Ricci", "[", 
            RowBox[{"i", ",", "j"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.537162548098844*^9, 3.5371625504566917`*^9}, 
   3.539082214400051*^9, 3.5422816411328793`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Eins", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Ricci", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "-", 
            RowBox[{
             FractionBox["1", "2"], "SCAL", " ", 
             RowBox[{"g", "[", 
              RowBox[{"i", ",", "j"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537162561041321*^9, 3.537162563183304*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Einstein equations :", "Subsection"]], "Subtitle",
 CellChangeTimes->{{3.4748662984784307`*^9, 3.474866318276967*^9}, {
   3.49682537622365*^9, 3.496825382669928*^9}, {3.516876275160224*^9, 
   3.516876279587028*^9}, {3.5355440086694717`*^9, 3.535544016131024*^9}, 
   3.5422812556127653`*^9, 3.570737312274931*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"EQEINST", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"BISERIES", "[", 
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"Eins", "[", 
            RowBox[{"i", ",", "j"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
         "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.494340702923778*^9, 3.494340706649364*^9}, {
   3.4945847708411217`*^9, 3.494584822763629*^9}, {3.494586643087392*^9, 
   3.494586644685483*^9}, {3.4946745839591017`*^9, 3.494674598184272*^9}, {
   3.4948633756636333`*^9, 3.494863377186764*^9}, {3.494863420298729*^9, 
   3.494863426175583*^9}, {3.496820404968685*^9, 3.496820452438518*^9}, {
   3.496821540379427*^9, 3.496821554543049*^9}, {3.504332748727181*^9, 
   3.5043327541579638`*^9}, {3.5043328697883263`*^9, 3.504332870084283*^9}, {
   3.5043391281428413`*^9, 3.504339187096039*^9}, {3.504428270801147*^9, 
   3.504428271363044*^9}, {3.5044286466453247`*^9, 3.5044286468187838`*^9}, {
   3.5044492158292294`*^9, 3.5044492351069727`*^9}, {3.50470795041389*^9, 
   3.504707981830139*^9}, 3.5047095121518087`*^9, 3.504710015264078*^9, {
   3.522752329827031*^9, 3.5227523298463087`*^9}, {3.535545022524313*^9, 
   3.535545022549247*^9}, {3.5370793893347683`*^9, 3.537079389340351*^9}, {
   3.53708320277229*^9, 3.537083256254108*^9}, {3.5371629800080442`*^9, 
   3.5371629828443127`*^9}, {3.5371630418447313`*^9, 3.537163044309452*^9}, 
   3.538396395668947*^9, {3.53893825888251*^9, 3.53893826211685*^9}, {
   3.5389383581141167`*^9, 3.538938366203148*^9}, {3.538981836439662*^9, 
   3.538981853084009*^9}, {3.542281356594841*^9, 3.542281360211338*^9}, {
   3.5422817544318542`*^9, 3.542281830890324*^9}, {3.542283071798513*^9, 
   3.542283074030761*^9}, {3.570732272843296*^9, 3.570732293465349*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq11", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq12", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq13", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq14", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"1", ",", "4"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq22", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"2", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq23", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"2", ",", "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq24", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"2", ",", "4"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq33", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"3", ",", "3"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq34", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"3", ",", "4"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq44", "=", 
   RowBox[{"EQEINST", "[", 
    RowBox[{"4", ",", "4"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.537168916944661*^9, 3.537169101845484*^9}, {
   3.538396576027174*^9, 3.538396576339677*^9}, 3.538478975271874*^9, {
   3.542281865409182*^9, 3.5422819009305277`*^9}, {3.570732324320771*^9, 
   3.570732324468728*^9}, {3.570732370128607*^9, 3.570732371479555*^9}, {
   3.570737326743499*^9, 3.570737330755608*^9}}],

Cell["If we wish, we can save the result:", "Text",
 CellChangeTimes->{{3.570722953606166*^9, 3.5707229590645103`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<eqs_first_order.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "eq11", ",", "eq12", ",", "eq13", ",", "eq14", ",", "eq22", ",", "eq23", 
      ",", "eq24", ",", "eq33", ",", "eq34", ",", "eq44", ",", "ORDERa"}], 
     "}"}]}], "]"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell["\<\
Let us check that the slowly-rotating Kerr BH is a solution at zeroth order \
in the perturbations:\
\>", "Subsubsection",
 CellChangeTimes->{{3.5707323296981773`*^9, 3.570732332035327*^9}, {
  3.5707373443521357`*^9, 3.570737362613584*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<eqs_first_order.mx\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.5389743437208147`*^9, 3.5389743455574503`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"(*", 
    RowBox[{"Clear", "[", 
     RowBox[{
     "B", ",", "F", ",", "\[CapitalPhi]0", ",", "\[CapitalPhi]1", ",", 
      "\[Zeta]"}], "]"}], "*)"}], ";", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "r_", "]"}], ":=", 
     RowBox[{"1", "-", 
      RowBox[{"2", 
       FractionBox["M", "r"]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"B", "[", "r_", "]"}], ":=", 
     RowBox[{"F", "[", "r", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Zeta]", "[", "r_", "]"}], ":=", 
     RowBox[{"2", " ", 
      FractionBox["J", "r"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SS", "[", "X_", "]"}], ":=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{"X", ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]p", ",", "0", ",", "0"}], "}"}]}], "]"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "x_", "]"}], ":=", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "x", "]"}], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$Assumptions", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "\[Theta]", "]"}], ">", "0"}], ",", 
       RowBox[{"0", "<", "\[Theta]", "<", "\[Pi]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"SS", "[", 
    RowBox[{"{", 
     RowBox[{
     "eq11", ",", "eq12", ",", "eq13", ",", "eq14", ",", "eq22", ",", "eq23", 
      ",", "eq24", ",", "eq33", ",", "eq34", ",", "eq44"}], "}"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"B", ",", "F", ",", "A0", ",", "\[Zeta]", ",", "A3"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.53897434848412*^9, 3.538974408045637*^9}, {
   3.538974473640972*^9, 3.538974652762082*^9}, {3.538974753258766*^9, 
   3.538974760045929*^9}, {3.538974834015031*^9, 3.538974888277261*^9}, {
   3.5389749259493723`*^9, 3.538975023705779*^9}, {3.538975127223798*^9, 
   3.538975142601914*^9}, {3.53897525808613*^9, 3.538975294971489*^9}, {
   3.538975335530204*^9, 3.53897534241746*^9}, {3.538975449571961*^9, 
   3.538975455922228*^9}, {3.538975502856578*^9, 3.538975592830714*^9}, {
   3.53897564420142*^9, 3.538975651109107*^9}, {3.538975908386436*^9, 
   3.538975913675036*^9}, {3.538975954533184*^9, 3.53897596340847*^9}, {
   3.538975995099999*^9, 3.5389759977435217`*^9}, {3.538976037140521*^9, 
   3.5389760625843153`*^9}, {3.538976139366055*^9, 3.538976160685598*^9}, {
   3.5389770152568083`*^9, 3.538977050998328*^9}, {3.538977085452772*^9, 
   3.538977100752904*^9}, {3.538977401047586*^9, 3.538977415434545*^9}, {
   3.5389775185217333`*^9, 3.538977522423203*^9}, {3.538977567836783*^9, 
   3.5389775708292217`*^9}, {3.538977684105651*^9, 3.5389776869791183`*^9}, 
   3.5389777182342978`*^9, {3.538977781177442*^9, 3.5389777868946943`*^9}, 
   3.538977824860104*^9, {3.53897792328054*^9, 3.538977968752133*^9}, {
   3.538978053000022*^9, 3.538978073029649*^9}, {3.538978109404194*^9, 
   3.538978110207766*^9}, {3.538978419739251*^9, 3.538978438543838*^9}, {
   3.538978526544932*^9, 3.538978534010376*^9}, {3.538980774103825*^9, 
   3.538980781682358*^9}, {3.538980836645102*^9, 3.538980896063777*^9}, {
   3.5389809390562162`*^9, 3.5389809887749367`*^9}, {3.538981151448208*^9, 
   3.5389811716849337`*^9}, {3.538981536921741*^9, 3.538981539957848*^9}, 
   3.538981597941596*^9, {3.5389816669201183`*^9, 3.5389816687386*^9}, {
   3.5389825511251497`*^9, 3.5389825533889313`*^9}, {3.538982599175993*^9, 
   3.5389826032988653`*^9}, {3.539065785114669*^9, 3.539065804407102*^9}, {
   3.53906584641068*^9, 3.539065879386331*^9}, {3.5390659855575047`*^9, 
   3.5390660142482243`*^9}, {3.539066113066568*^9, 3.5390661199908667`*^9}, {
   3.539074668480452*^9, 3.5390746729425707`*^9}, {3.542282093618705*^9, 
   3.5422822185572977`*^9}, {3.542282478557021*^9, 3.5422824793003063`*^9}, {
   3.5422835229545393`*^9, 3.542283550766518*^9}, {3.542283686150498*^9, 
   3.542283692752688*^9}, {3.542285766335781*^9, 3.542285804377637*^9}, {
   3.542286670225672*^9, 3.5422866804852753`*^9}, {3.542286777852634*^9, 
   3.542286778583617*^9}, {3.5422868213196363`*^9, 3.542286830190027*^9}, {
   3.5422869628390102`*^9, 3.5422869689275007`*^9}, {3.5422870380244637`*^9, 
   3.542287063620022*^9}, {3.542287112221217*^9, 3.5422871297756033`*^9}, {
   3.542287168698822*^9, 3.5422871697994328`*^9}, {3.5422872218619204`*^9, 
   3.542287232409067*^9}, {3.5422873069897623`*^9, 3.542287311097756*^9}, {
   3.542287369247253*^9, 3.5422873699412603`*^9}, {3.570732342586556*^9, 
   3.570732391486847*^9}, {3.570737370021874*^9, 3.570737408068124*^9}, {
   3.570737445495965*^9, 3.570737477438501*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5389807920758867`*^9, 3.5389808968473587`*^9, 3.538980947366193*^9, {
   3.5389809778905497`*^9, 3.538980989979903*^9}, {3.538981152707419*^9, 
   3.538981172748527*^9}, 3.5389815415189734`*^9, 3.538981601189765*^9, {
   3.538982543511579*^9, 3.538982554030183*^9}, 3.538982605259707*^9, 
   3.5390657694913263`*^9, 3.539065805656427*^9, {3.539065847096122*^9, 
   3.539065880165669*^9}, {3.539065991942416*^9, 3.53906601624903*^9}, 
   3.539066121819375*^9, 3.539074678918274*^9, 3.542282206424574*^9, 
   3.542282972599401*^9, 3.542283477167596*^9, 3.542283526898336*^9, 
   3.542283567954731*^9, 3.542283697894116*^9, 3.5422866596862164`*^9, {
   3.5422866917620363`*^9, 3.542286697350191*^9}, 3.542286780399724*^9, 
   3.54228682928929*^9, {3.542287064739517*^9, 3.542287076299087*^9}, {
   3.5422871153735237`*^9, 3.5422871300459633`*^9}, 3.542287173564272*^9, 
   3.542287234800044*^9, 3.542287314560258*^9, 3.542288068338152*^9, {
   3.57073237727579*^9, 3.570732393102948*^9}, {3.570737468736907*^9, 
   3.570737477853196*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["To Kojima\[CloseCurlyQuote]s form:", "Section",
 CellChangeTimes->{{3.570732406335093*^9, 3.570732410452063*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"X", ",", "F", ",", "B", ",", "\[Zeta]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<eqs_first_order.mx\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.53716922719455*^9, 3.537169233712488*^9}, {
  3.537248059004871*^9, 3.537248059168448*^9}, {3.570732430079239*^9, 
  3.570732467372583*^9}, {3.570737481060401*^9, 3.570737481482072*^9}}],

Cell[CellGroupData[{

Cell["Angular part:", "Subsubsection",
 CellChangeTimes->{{3.537169436071678*^9, 3.537169438199121*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[LessEqual]", "\[Pi]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S\[Theta]", "[", 
    RowBox[{"\[Theta]_", ",", "\[CurlyPhi]_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "1"}], 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], ",", "\[CurlyPhi]"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S\[CurlyPhi]", "[", 
    RowBox[{"\[Theta]_", ",", "\[CurlyPhi]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Sin", "[", "\[Theta]", "]"}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], ",", "\[Theta]"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "\[Theta]_", "]"}], ":=", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleANG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], 
        RowBox[{"(", 
         RowBox[{"l", "+", "1"}], ")"}], 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"4", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l", "+", 
          SuperscriptBox["l", "2"], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", "l", "+", 
             SuperscriptBox["l", "2"], "-", 
             RowBox[{"11", " ", 
              SuperscriptBox[
               RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}], " ", 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
             RowBox[{"6", " ", 
              RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
              RowBox[{"Csc", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
              RowBox[{
               SuperscriptBox["Y", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}]}], 
         ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537248251134644*^9, 3.537248268481345*^9}, {
  3.5372500792999687`*^9, 3.537250088360345*^9}, {3.537253909457386*^9, 
  3.537253926144947*^9}, {3.5372539814636497`*^9, 3.5372539881597357`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Background", "Subsubsection",
 CellChangeTimes->{{3.537169326898046*^9, 3.5371693501618633`*^9}, 
   3.5594512759362297`*^9, {3.570737486584359*^9, 3.570737488474786*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     FractionBox["M", "r"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"B", "[", "r_", "]"}], ":=", 
   RowBox[{"F", "[", "r", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Zeta]", "[", "r_", "]"}], ":=", 
   RowBox[{"2", " ", 
    FractionBox["J", "r"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rule0", "=", 
   RowBox[{"{", "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.542288355845552*^9, 3.542288356052559*^9}, {
  3.570732475251079*^9, 3.570732482812971*^9}}],

Cell["\<\
The following three sections are devoted to separate the angular part in the \
linearized Einstein equations. This is done by collecting the coefficient of \
various spherical harmonics of different tensorial order. Due to the \
symmetries of the Regge-Wheeler gauge, the equations divide naturally into \
three groups, see the notes for details. For each equation, we first \
factorize the equation in the desired form and then we check that the \
coefficients are purely radial functions and that the final equation is \
equivalent to the original one.\
\>", "Text",
 CellChangeTimes->{{3.5707375057202053`*^9, 3.5707376321222553`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
First group (tt - tr - rr - \[Theta]\[Theta]+\[CurlyPhi]\[CurlyPhi] \
components)\
\>", "Subsection",
 CellChangeTimes->{{3.537254761723589*^9, 3.537254785316331*^9}}],

Cell[CellGroupData[{

Cell["tt component", "Subsubsection",
 CellChangeTimes->{{3.537169268647767*^9, 3.5371692704750853`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{"eq11", ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
      "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK011", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.537169507284244*^9, 3.53716953270294*^9}, {
   3.537169578608453*^9, 3.53716961363238*^9}, {3.537248413801042*^9, 
   3.537248426049795*^9}, {3.537248639019959*^9, 3.537248644259548*^9}, 
   3.537253997493038*^9, {3.537254108715371*^9, 3.537254108841729*^9}, {
   3.5372690669078608`*^9, 3.537269069162951*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537248411107026*^9, 3.5372484265799294`*^9}, 
   3.537248666277124*^9, 3.537250111154983*^9, 3.537250703626197*^9, 
   3.537251489453289*^9, 3.537254011637959*^9, 3.537254113970936*^9, 
   3.537255540627244*^9, 3.5372763462450037`*^9, 3.537368050472342*^9, 
   3.537853511626397*^9, 3.537854387713902*^9, 3.542288378590722*^9, 
   3.5707326232287397`*^9, 3.570737498743244*^9, 3.572207839212384*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.537273493737158*^9, 3.53727350033913*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c00", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c3", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c2", ",", "c3"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c2", ",", "c3"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK11", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"c00", " ", 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c1", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c2", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c3", " ", 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", "EQ"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A00", "=", "c00"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"At0", "=", "c1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B0", "=", "c2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C0", "=", "c3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ11", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.53716948100196*^9, 3.537169483009519*^9}, 
   3.537169619181869*^9, {3.5371696727962313`*^9, 3.537169727892139*^9}, {
   3.5372484751074142`*^9, 3.537248477537779*^9}, {3.5372514846277723`*^9, 
   3.537251488749593*^9}, {3.537252875598175*^9, 3.537252892534996*^9}, {
   3.537253671243442*^9, 3.537253678320369*^9}, {3.537253723220069*^9, 
   3.537253785996915*^9}, {3.537254117159768*^9, 3.537254155592581*^9}, 
   3.537255526206328*^9, 3.53725841031039*^9, 3.537276396164982*^9, 
   3.5422884259314613`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.5372484309969883`*^9, 3.537248503264172*^9, 3.537248757022991*^9, 
   3.537250179003783*^9, 3.537250667958878*^9, 3.5372507063920403`*^9, 
   3.537251911535214*^9, 3.537252918168009*^9, {3.537253752519332*^9, 
   3.537253787440804*^9}, 3.537254072996722*^9, 3.537254118173338*^9, 
   3.5372541566614447`*^9, 3.53725562117763*^9, 3.5372764060569963`*^9, 
   3.5372764438281193`*^9, 3.537368138573812*^9, 3.537854449692273*^9, 
   3.5422884306934013`*^9, 3.570732627588769*^9, 3.570737500740159*^9, 
   3.572207864704433*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.5372484309969883`*^9, 3.537248503264172*^9, 3.537248757022991*^9, 
   3.537250179003783*^9, 3.537250667958878*^9, 3.5372507063920403`*^9, 
   3.537251911535214*^9, 3.537252918168009*^9, {3.537253752519332*^9, 
   3.537253787440804*^9}, 3.537254072996722*^9, 3.537254118173338*^9, 
   3.5372541566614447`*^9, 3.53725562117763*^9, 3.5372764060569963`*^9, 
   3.5372764438281193`*^9, 3.537368138573812*^9, 3.537854449692273*^9, 
   3.5422884306934013`*^9, 3.570732627588769*^9, 3.570737500740159*^9, 
   3.572207864705555*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.5372484309969883`*^9, 3.537248503264172*^9, 3.537248757022991*^9, 
   3.537250179003783*^9, 3.537250667958878*^9, 3.5372507063920403`*^9, 
   3.537251911535214*^9, 3.537252918168009*^9, {3.537253752519332*^9, 
   3.537253787440804*^9}, 3.537254072996722*^9, 3.537254118173338*^9, 
   3.5372541566614447`*^9, 3.53725562117763*^9, 3.5372764060569963`*^9, 
   3.5372764438281193`*^9, 3.537368138573812*^9, 3.537854449692273*^9, 
   3.5422884306934013`*^9, 3.570732627588769*^9, 3.570737500740159*^9, 
   3.572207864731711*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CreateDirectory", "[", "\"\<data\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_11.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK011", ",", "CHECK11", ",", "EQ11", ",", "A00", ",", "At0", ",", 
      "B0", ",", "C0"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.537275548913558*^9, 3.537275558960106*^9}, 
   3.5372758439815063`*^9, 3.542288426837204*^9, {3.571081141312042*^9, 
   3.57108114173234*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["tr component", "Subsubsection",
 CellChangeTimes->{{3.53716963493226*^9, 3.537169636827498*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{"eq12", ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
      "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK012", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.537169507284244*^9, 3.53716953270294*^9}, {
   3.537169578608453*^9, 3.53716961363238*^9}, {3.537248413801042*^9, 
   3.537248426049795*^9}, {3.537248639019959*^9, 3.537248644259548*^9}, 
   3.537253997493038*^9, {3.537254108715371*^9, 3.537254108841729*^9}, {
   3.537254299516198*^9, 3.537254303289443*^9}, {3.537269062105171*^9, 
   3.537269063565974*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537248411107026*^9, 3.5372484265799294`*^9}, 
   3.537248666277124*^9, 3.537250111154983*^9, 3.537250703626197*^9, 
   3.537251489453289*^9, 3.537254011637959*^9, 3.537254113970936*^9, 
   3.5372543612450027`*^9, 3.537255626779948*^9, 3.53727647063461*^9, 
   3.537368153132669*^9, 3.537854462873013*^9, 3.5422884928848*^9, 
   3.57073263644013*^9, 3.570737501433395*^9, 3.5722078908109903`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{3.5372735057357616`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c00", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c3", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c2", ",", "c3"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c2", ",", "c3"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK12", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"c00", " ", 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c1", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c2", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c3", " ", 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", "EQ"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A1", "=", "c00"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"At1", "=", "c1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B1", "=", "c2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C1", "=", "c3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ12", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.53716948100196*^9, 3.537169483009519*^9}, 
   3.537169619181869*^9, {3.5371696727962313`*^9, 3.537169727892139*^9}, {
   3.5372484751074142`*^9, 3.537248477537779*^9}, {3.5372514846277723`*^9, 
   3.537251488749593*^9}, {3.537252875598175*^9, 3.537252892534996*^9}, {
   3.537253671243442*^9, 3.537253678320369*^9}, {3.537253723220069*^9, 
   3.537253785996915*^9}, {3.537254117159768*^9, 3.537254155592581*^9}, {
   3.5372543158351917`*^9, 3.537254323603422*^9}, 3.5372548991488867`*^9, 
   3.537255544115424*^9, 3.537258407315776*^9, 3.537276458763158*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537254404404522*^9, 3.537255666625065*^9, 
  3.537276505374876*^9, 3.537368187688025*^9, 3.537854495070902*^9, 
  3.5422885180399227`*^9, 3.570732638337597*^9, 3.570737503090111*^9, 
  3.572207892969178*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537254404404522*^9, 3.537255666625065*^9, 
  3.537276505374876*^9, 3.537368187688025*^9, 3.537854495070902*^9, 
  3.5422885180399227`*^9, 3.570732638337597*^9, 3.570737503090111*^9, 
  3.572207892973419*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.537254404404522*^9, 3.537255666625065*^9, 
  3.537276505374876*^9, 3.537368187688025*^9, 3.537854495070902*^9, 
  3.5422885180399227`*^9, 3.570732638337597*^9, 3.570737503090111*^9, 
  3.57220789297596*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_12.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK012", ",", "CHECK12", ",", "EQ12", ",", "A1", ",", "At1", ",", 
      "B1", ",", "C1"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537275776560432*^9, 3.5372757889426613`*^9}, 
   3.537275841048933*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["rr component", "Subsubsection",
 CellChangeTimes->{{3.53716963493226*^9, 3.537169636827498*^9}, {
  3.5371741574535103`*^9, 3.537174157577919*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{"eq22", ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
      "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK022", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.537169507284244*^9, 3.53716953270294*^9}, {
   3.537169578608453*^9, 3.53716961363238*^9}, {3.537248413801042*^9, 
   3.537248426049795*^9}, {3.537248639019959*^9, 3.537248644259548*^9}, 
   3.537253997493038*^9, {3.537254108715371*^9, 3.537254108841729*^9}, {
   3.537254299516198*^9, 3.537254303289443*^9}, {3.5372544423010397`*^9, 
   3.5372544471611433`*^9}, {3.5372690550644417`*^9, 3.537269058218396*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537248411107026*^9, 3.5372484265799294`*^9}, 
   3.537248666277124*^9, 3.537250111154983*^9, 3.537250703626197*^9, 
   3.537251489453289*^9, 3.537254011637959*^9, 3.537254113970936*^9, 
   3.5372543612450027`*^9, 3.5372544868672943`*^9, 3.537255682147243*^9, 
   3.537276533782236*^9, 3.5373682093418903`*^9, 3.537854515566843*^9, 
   3.542288543030045*^9, 3.570732648120392*^9, 3.570737504439663*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{3.537273509019459*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c00", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c3", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c2", ",", "c3"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c2", ",", "c3"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK22", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"c00", " ", 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c1", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c2", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c3", " ", 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", "EQ"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A2", "=", "c00"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"At2", "=", "c1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B2", "=", "c2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C2", "=", "c3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ22", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.53716948100196*^9, 3.537169483009519*^9}, 
   3.537169619181869*^9, {3.5371696727962313`*^9, 3.537169727892139*^9}, {
   3.5372484751074142`*^9, 3.537248477537779*^9}, {3.5372514846277723`*^9, 
   3.537251488749593*^9}, {3.537252875598175*^9, 3.537252892534996*^9}, {
   3.537253671243442*^9, 3.537253678320369*^9}, {3.537253723220069*^9, 
   3.537253785996915*^9}, {3.537254117159768*^9, 3.537254155592581*^9}, {
   3.5372543158351917`*^9, 3.537254323603422*^9}, {3.5372544552503233`*^9, 
   3.53725446874*^9}, 3.537254903010745*^9, {3.537255558526573*^9, 
   3.537255563482643*^9}, 3.537258404773123*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537254542646624*^9, 3.5372557419528713`*^9, 
  3.537276590392522*^9, 3.537368261007318*^9, 3.5378545657133827`*^9, 
  3.542288550233857*^9, 3.5707326495777473`*^9, 3.570737505859171*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537254542646624*^9, 3.5372557419528713`*^9, 
  3.537276590392522*^9, 3.537368261007318*^9, 3.5378545657133827`*^9, 
  3.542288550233857*^9, 3.5707326495777473`*^9, 3.570737505859892*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.537254542646624*^9, 3.5372557419528713`*^9, 
  3.537276590392522*^9, 3.537368261007318*^9, 3.5378545657133827`*^9, 
  3.542288550233857*^9, 3.5707326495777473`*^9, 3.570737505876988*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_22.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK022", ",", "CHECK22", ",", "EQ22", ",", "A2", ",", "At2", ",", 
      "B2", ",", "C2"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537254489971036*^9, 3.537254508909588*^9}, {
   3.53725557756077*^9, 3.5372555799775476`*^9}, {3.537275793524164*^9, 
   3.537275805170054*^9}, 3.5372758385341663`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[Theta]\[Theta]+\[CurlyPhi]\[CurlyPhi] component", "Subsubsection",
 CellChangeTimes->{{3.53716963493226*^9, 3.537169636827498*^9}, {
  3.5371741574535103`*^9, 3.537174157577919*^9}, {3.537174203239767*^9, 
  3.5371742068081512`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"eq33", "+", 
           FractionBox["eq44", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}],
        ")"}], "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK033p44", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.537169507284244*^9, 3.53716953270294*^9}, {
   3.537169578608453*^9, 3.53716961363238*^9}, {3.537248413801042*^9, 
   3.537248426049795*^9}, {3.537248639019959*^9, 3.537248644259548*^9}, 
   3.537253997493038*^9, {3.537254108715371*^9, 3.537254108841729*^9}, {
   3.537254299516198*^9, 3.537254303289443*^9}, {3.5372544423010397`*^9, 
   3.5372544471611433`*^9}, {3.537254670507762*^9, 3.537254679571418*^9}, {
   3.537269043146199*^9, 3.537269049526883*^9}, 3.537275811730938*^9, {
   3.5372799202328176`*^9, 3.537279925375423*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537248411107026*^9, 3.5372484265799294`*^9}, 
   3.537248666277124*^9, 3.537250111154983*^9, 3.537250703626197*^9, 
   3.537251489453289*^9, 3.537254011637959*^9, 3.537254113970936*^9, 
   3.5372543612450027`*^9, 3.5372544868672943`*^9, 3.537254780196033*^9, 
   3.5372558386920547`*^9, 3.537276738772066*^9, {3.5372799663256617`*^9, 
   3.537279980933346*^9}, 3.537368369190074*^9, 3.537854679568406*^9, 
   3.542288584674258*^9, 3.570732665138187*^9, 3.570737510955572*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{3.5372735168806257`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c00", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c0", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c22", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"c2", ",", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c3", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c22", ",", "c3"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c00", ",", "c1", ",", "c22", ",", "c3"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.53716948100196*^9, 3.537169483009519*^9}, 
   3.537169619181869*^9, {3.5371696727962313`*^9, 3.537169727892139*^9}, {
   3.5372484751074142`*^9, 3.537248477537779*^9}, {3.5372514846277723`*^9, 
   3.537251488749593*^9}, {3.537252875598175*^9, 3.537252892534996*^9}, {
   3.537253671243442*^9, 3.537253678320369*^9}, {3.537253723220069*^9, 
   3.537253785996915*^9}, {3.537254117159768*^9, 3.537254155592581*^9}, {
   3.5372543158351917`*^9, 3.537254323603422*^9}, {3.5372544552503233`*^9, 
   3.53725446874*^9}, {3.537254689820739*^9, 3.5372547038396397`*^9}, 
   3.537254908394858*^9, {3.537255261687401*^9, 3.537255276304949*^9}, {
   3.5372583953120747`*^9, 3.537258397451314*^9}, 3.537276636052628*^9, 
   3.537280083963036*^9, {3.542288848111396*^9, 3.542288885810645*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.537255274259219*^9, 3.537278901986043*^9, 3.537280071536091*^9, 
   3.537368492555485*^9, 3.537854782383738*^9, 3.542288694577078*^9, {
   3.542288876730844*^9, 3.5422888868907413`*^9}, 3.570732671536397*^9, 
   3.570737517088666*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.537255274259219*^9, 3.537278901986043*^9, 3.537280071536091*^9, 
   3.537368492555485*^9, 3.537854782383738*^9, 3.542288694577078*^9, {
   3.542288876730844*^9, 3.5422888868907413`*^9}, 3.570732671536397*^9, 
   3.570737517089798*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CHECK33p44", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"c00", " ", 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c1", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c22", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
    RowBox[{"c3", " ", 
     RowBox[{
      SuperscriptBox["Y", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", "EQ"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.542288869255374*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.537280081982635*^9, 3.537368492783698*^9, 
  3.537854782685606*^9, 3.542288726602703*^9, 3.5422888888887444`*^9, 
  3.570732675346875*^9, 3.570737517165779*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"A33", "=", "c00"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"At3", "=", "c1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B3", "=", "c22"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"C3", "=", "c3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ33p44", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.537275814306282*^9, 3.537275818190179*^9}, 
   3.537280079855351*^9, 3.5375211512469463`*^9, 3.5422886003279533`*^9, 
   3.5422888722381773`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_33p44.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK033p44", ",", "CHECK33p44", ",", "EQ33p44", ",", "A33", ",", "At3",
       ",", "B3", ",", "C3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5372547334818563`*^9, 3.537254750002302*^9}, {
   3.5372557605146017`*^9, 3.537255762313734*^9}, {3.537275821483561*^9, 
   3.537275859472704*^9}, 3.542288601842204*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Second group (t\[Theta] - t\[CurlyPhi] - r\[Theta] - r\[CurlyPhi] components)\
\
\>", "Subsection",
 CellChangeTimes->{{3.537254761723589*^9, 3.537254804999716*^9}, {
  3.5372548507222137`*^9, 3.5372548647358637`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruleANG2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"XX", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"W", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "+", 
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"W", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "-", 
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"W", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "l", "+", 
            SuperscriptBox["l", "2"], "+", 
            SuperscriptBox[
             RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"4", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"2", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}]}], "-", 
             RowBox[{"11", " ", 
              SuperscriptBox[
               RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], " ", 
          
          RowBox[{"W", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "4"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", "l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "6"}], "+", 
               RowBox[{"5", " ", 
                SuperscriptBox[
                 RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
             
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox[
              RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"XX", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"l", "+", 
          SuperscriptBox["l", "2"], "+", 
          SuperscriptBox[
           RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"W", "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "+", 
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", 
              RowBox[{"Y", "[", 
               RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], 
          "+", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l", "+", 
            SuperscriptBox["l", "2"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"XX", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"7", " ", 
                RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", " ", "\[Theta]"}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
            RowBox[{"12", " ", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "3"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "3"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
        ")"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5372594278551407`*^9, 3.5372594350733337`*^9}, {
  3.537266976956217*^9, 3.5372669929727173`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"ruleANG2", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
       RowBox[{
        FractionBox[
         RowBox[{"XX", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "2"], "+", 
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], 
         RowBox[{
          SuperscriptBox["Y", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"W", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "-", 
          RowBox[{
           RowBox[{"Cot", "[", "\[Theta]", "]"}], 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}]}], 
     "}"}]}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{3.53725943932444*^9}],

Cell[CellGroupData[{

Cell["t\[Theta] component", "Subsubsection",
 CellChangeTimes->{{3.5372567772098217`*^9, 3.53725678017848*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{"eq13", ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}],
        ")"}], "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG2", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK013", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"EQQ", ",", "0"}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5372567834248877`*^9, 3.537256789612069*^9}, 
   3.5372594467764797`*^9, {3.537269033363967*^9, 3.537269035125557*^9}, {
   3.537270046863418*^9, 3.537270047168686*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537256791362462*^9, 3.5372567951061087`*^9}, 
   3.537259460202023*^9, 3.537266996936286*^9, {3.537270048042592*^9, 
   3.537270055555917*^9}, 3.537280214241515*^9, 3.537368514042427*^9, 
   3.5378548075284977`*^9, 3.5422889077402077`*^9, 3.570732690070486*^9, 
   3.570737518538109*^9, 3.5722079410539503`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{
  3.537257983549049*^9, 3.537259460749791*^9, {3.537270034297554*^9, 
   3.5372700358730907`*^9}, {3.537273304674755*^9, 3.5372733097066813`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"W", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]cos", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"cY\[CurlyPhi]", ",", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cY\[CurlyPhi]cos", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"Coefficient", "[", 
       RowBox[{"cY\[CurlyPhi]", ",", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK13", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cX", " ", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cW", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"W", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]0", " ", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]cos", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"cY\[CurlyPhi]0", " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{"cY\[CurlyPhi]cos", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]], "-", "EQ"}], ")"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.537257815655593*^9, 3.537257896937211*^9}, {
  3.537257934329865*^9, 3.5372580164455223`*^9}, {3.5372581938641367`*^9, 
  3.5372581957494373`*^9}, {3.5372582766778708`*^9, 3.537258322448601*^9}, {
  3.537258460689163*^9, 3.537258473165188*^9}, {3.537262351877323*^9, 
  3.53726236664986*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.537258468256172*^9, 3.537258471526218*^9}, 
   3.5372598747778063`*^9, {3.537262353581588*^9, 3.537262367317194*^9}, 
   3.537270344729527*^9, 3.537280512093708*^9, 3.537368930257699*^9, 
   3.53785512551483*^9, 3.542288929097499*^9, 3.570732696331514*^9, 
   3.570737524765131*^9, 3.572207946650326*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.537258468256172*^9, 3.537258471526218*^9}, 
   3.5372598747778063`*^9, {3.537262353581588*^9, 3.537262367317194*^9}, 
   3.537270344729527*^9, 3.537280512093708*^9, 3.537368930257699*^9, 
   3.53785512551483*^9, 3.542288929097499*^9, 3.570732696331514*^9, 
   3.570737524765131*^9, 3.572207946651334*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537258468256172*^9, 3.537258471526218*^9}, 
   3.5372598747778063`*^9, {3.537262353581588*^9, 3.537262367317194*^9}, 
   3.537270344729527*^9, 3.537280512093708*^9, 3.537368930257699*^9, 
   3.53785512551483*^9, 3.542288929097499*^9, 3.570732696331514*^9, 
   3.570737524765131*^9, 3.572207946706524*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]0", "=", "cY\[Theta]0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]t0", "=", "cY\[Theta]cos"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]0", "=", 
   RowBox[{"-", "cY\[CurlyPhi]0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]t0", "=", 
   RowBox[{"-", "cY\[CurlyPhi]cos"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Eta]0", "=", "cY"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]0", "=", "cX"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]0", "=", "cW"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ13", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.537258848728797*^9, 3.5372589207170753`*^9}, {
  3.537262607957755*^9, 3.53726261159894*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_13.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK013", ",", "CHECK13", ",", "EQ13", ",", "\[Alpha]0", ",", 
      "\[Alpha]t0", ",", "\[Beta]0", ",", "\[Beta]t0", ",", "\[Eta]0", ",", 
      "\[Xi]0", ",", "\[Chi]0"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537262455429329*^9, 3.5372624893919573`*^9}, {
  3.537275867262362*^9, 3.5372758681414003`*^9}, {3.537275957250991*^9, 
  3.537275973171132*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["r\[Theta] component", "Subsubsection",
 CellChangeTimes->{{3.537267797915071*^9, 3.537267800308117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{"eq23", ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}],
        ")"}], "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG2", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK023", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5372567834248877`*^9, 3.537256789612069*^9}, 
   3.5372594467764797`*^9, {3.537262535423731*^9, 3.537262538501383*^9}, {
   3.537267804093533*^9, 3.5372678075868692`*^9}, {3.537275328691866*^9, 
   3.537275330684761*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537256791362462*^9, 3.5372567951061087`*^9}, 
   3.537259460202023*^9, 3.537262599987797*^9, 3.537267009271978*^9, 
   3.5372823504948387`*^9, 3.5373700752956953`*^9, 3.537517156898738*^9, 
   3.5378551546874533`*^9, 3.5422889416569433`*^9, 3.570732702259665*^9, 
   3.570737525946755*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{
  3.537257983549049*^9, 3.537259460749791*^9, 3.537273338756853*^9, {
   3.53727352913587*^9, 3.5372735314393473`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"W", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]cos", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"cY\[CurlyPhi]", ",", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cY\[CurlyPhi]cos", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"Coefficient", "[", 
       RowBox[{"cY\[CurlyPhi]", ",", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK23", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cX", " ", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cW", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"W", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]0", " ", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]cos", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"cY\[CurlyPhi]0", " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{"cY\[CurlyPhi]cos", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]], "-", "EQ"}], ")"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.537257815655593*^9, 3.537257896937211*^9}, {
  3.537257934329865*^9, 3.5372580164455223`*^9}, {3.5372581938641367`*^9, 
  3.5372581957494373`*^9}, {3.5372582766778708`*^9, 3.537258322448601*^9}, {
  3.537258460689163*^9, 3.537258473165188*^9}, {3.537262351877323*^9, 
  3.53726236664986*^9}, {3.537262557909388*^9, 3.5372625587847548`*^9}, {
  3.5372678132791452`*^9, 3.537267813827435*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537282669025072*^9, 3.537370368700632*^9, 
  3.537517158566905*^9, 3.53751741305075*^9, 3.5378554252017097`*^9, 
  3.542288965321529*^9, 3.570732718734487*^9, 3.570737542412486*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537282669025072*^9, 3.537370368700632*^9, 
  3.537517158566905*^9, 3.53751741305075*^9, 3.5378554252017097`*^9, 
  3.542288965321529*^9, 3.570732718734487*^9, 3.5707375424132233`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.537282669025072*^9, 3.537370368700632*^9, 
  3.537517158566905*^9, 3.53751741305075*^9, 3.5378554252017097`*^9, 
  3.542288965321529*^9, 3.570732718734487*^9, 3.570737542553453*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]1", "=", "cY\[Theta]0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]t1", "=", "cY\[Theta]cos"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]1", "=", 
   RowBox[{"-", "cY\[CurlyPhi]0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]t1", "=", 
   RowBox[{"-", "cY\[CurlyPhi]cos"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Eta]1", "=", "cY"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]1", "=", "cX"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Chi]1", "=", "cW"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"\[Beta]\[Beta]0", "=", "cY\[Theta]0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[Beta]\[Beta]t0", "=", "cY\[Theta]cos"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]\[Alpha]0", "=", "cY\[CurlyPhi]0"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]\[Alpha]t0", "=", "cY\[CurlyPhi]cos"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[Zeta]0", "=", "cY"}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Chi]\[Chi]0", "=", "cX"}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Xi]\[Xi]0", "=", 
     RowBox[{"-", "cW"}]}], ";"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ23", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.537267824573831*^9, 3.537267825063336*^9}, {
  3.537267858800156*^9, 3.537267938067178*^9}, {3.5375167414830093`*^9, 
  3.537516787677816*^9}, {3.537516847094943*^9, 3.537516877294012*^9}, {
  3.537517042279296*^9, 3.53751704831507*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_23.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK023", ",", "CHECK23", ",", "EQ23", ",", "\[Alpha]1", ",", 
      "\[Alpha]t1", ",", "\[Beta]1", ",", "\[Beta]t1", ",", "\[Eta]1", ",", 
      "\[Xi]1", ",", "\[Chi]1"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5372760090948133`*^9, 3.537276018858121*^9}, {
  3.537517158688555*^9, 3.537517176694454*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["t\[CurlyPhi] component", "Subsubsection",
 CellChangeTimes->{{3.5372567772098217`*^9, 3.53725678017848*^9}, {
  3.537262532999593*^9, 3.5372625334531527`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          FractionBox["eq14", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}],
        ")"}], "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG2", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK014", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5372567834248877`*^9, 3.537256789612069*^9}, 
   3.5372594467764797`*^9, {3.537262535423731*^9, 3.537262538501383*^9}, {
   3.537268883946919*^9, 3.537268897980733*^9}, {3.5372690234575663`*^9, 
   3.537269025568308*^9}, {3.5372811511092978`*^9, 3.537281154404366*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537256791362462*^9, 3.5372567951061087`*^9}, 
   3.537259460202023*^9, 3.537262599987797*^9, 3.537267009271978*^9, 
   3.5372689259736967`*^9, 3.537270377171228*^9, 3.537271852844398*^9, 
   3.537280671046465*^9, 3.537281167780183*^9, 3.5373690073727083`*^9, 
   3.53751744320485*^9, 3.537855461487075*^9, 3.542288994697446*^9, 
   3.5707327306209383`*^9, 3.5707375463991213`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EQ", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
      RowBox[{
       SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.537257983549049*^9, 3.537259460749791*^9, {3.537268708456567*^9, 
   3.537268711357202*^9}, 3.5372687974668007`*^9, {3.53726993970963*^9, 
   3.537269940012361*^9}, 3.537273316454764*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"W", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]cos", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"cY\[CurlyPhi]", ",", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cY\[CurlyPhi]cos", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"Coefficient", "[", 
       RowBox[{"cY\[CurlyPhi]", ",", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK14", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cX", " ", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cW", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"W", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]0", " ", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]cos", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"cY\[CurlyPhi]0", " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{"cY\[CurlyPhi]cos", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]], "-", "EQ"}], ")"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.537257815655593*^9, 3.537257896937211*^9}, {
   3.537257934329865*^9, 3.5372580164455223`*^9}, {3.5372581938641367`*^9, 
   3.5372581957494373`*^9}, {3.5372582766778708`*^9, 3.537258322448601*^9}, {
   3.537258460689163*^9, 3.537258473165188*^9}, {3.537262351877323*^9, 
   3.53726236664986*^9}, {3.537262557909388*^9, 3.5372625587847548`*^9}, {
   3.5372680500319242`*^9, 3.537268075741397*^9}, {3.537268701523198*^9, 
   3.5372687612428226`*^9}, {3.537268798759427*^9, 3.537268799388218*^9}, {
   3.53727310817793*^9, 3.537273108609922*^9}, {3.537281171308783*^9, 
   3.5372811923033524`*^9}, 3.537517345589183*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.537258468256172*^9, 3.537258471526218*^9}, 
   3.5372598747778063`*^9, {3.537262353581588*^9, 3.537262367317194*^9}, 
   3.5372640172050543`*^9, 3.537268013426054*^9, 3.537268067809393*^9, 
   3.5372687863528633`*^9, 3.537268827053104*^9, 3.537271694881649*^9, 
   3.537273135385743*^9, 3.53728188621136*^9, 3.53737004631468*^9, 
   3.537518237639249*^9, 3.537518394798822*^9, 3.53785628166759*^9, 
   3.5422891343882837`*^9, 3.5707327592709093`*^9, 3.570737575519257*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.537258468256172*^9, 3.537258471526218*^9}, 
   3.5372598747778063`*^9, {3.537262353581588*^9, 3.537262367317194*^9}, 
   3.5372640172050543`*^9, 3.537268013426054*^9, 3.537268067809393*^9, 
   3.5372687863528633`*^9, 3.537268827053104*^9, 3.537271694881649*^9, 
   3.537273135385743*^9, 3.53728188621136*^9, 3.53737004631468*^9, 
   3.537518237639249*^9, 3.537518394798822*^9, 3.53785628166759*^9, 
   3.5422891343882837`*^9, 3.5707327592709093`*^9, 3.5707375755199823`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537258468256172*^9, 3.537258471526218*^9}, 
   3.5372598747778063`*^9, {3.537262353581588*^9, 3.537262367317194*^9}, 
   3.5372640172050543`*^9, 3.537268013426054*^9, 3.537268067809393*^9, 
   3.5372687863528633`*^9, 3.537268827053104*^9, 3.537271694881649*^9, 
   3.537273135385743*^9, 3.53728188621136*^9, 3.53737004631468*^9, 
   3.537518237639249*^9, 3.537518394798822*^9, 3.53785628166759*^9, 
   3.5422891343882837`*^9, 3.5707327592709093`*^9, 3.5707375757678022`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Beta]\[Beta]0", "=", "cY\[Theta]0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]\[Beta]t0", "=", "cY\[Theta]cos"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]\[Alpha]0", "=", "cY\[CurlyPhi]0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]\[Alpha]t0", "=", "cY\[CurlyPhi]cos"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Zeta]0", "=", "cY"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]\[Chi]0", "=", "cX"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]\[Xi]0", "=", 
   RowBox[{"-", "cW"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ14", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.537258848728797*^9, 3.5372589207170753`*^9}, {
  3.5372625673374863`*^9, 3.537262572663588*^9}, {3.537262617403561*^9, 
  3.537262618961411*^9}, {3.537517231900807*^9, 3.5375172958179626`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_14.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK014", ",", "CHECK14", ",", "EQ14", ",", "\[Beta]\[Beta]0", ",", 
      "\[Beta]\[Beta]t0", ",", "\[Alpha]\[Alpha]0", ",", "\[Alpha]\[Alpha]t0",
       ",", "\[Zeta]0", ",", "\[Xi]\[Xi]0", ",", "\[Chi]\[Chi]0"}], "}"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537262455429329*^9, 3.5372624893919573`*^9}, {
  3.53726257686959*^9, 3.537262592378282*^9}, {3.5372759779756393`*^9, 
  3.53727598884529*^9}, {3.5375173029059067`*^9, 3.537517321232348*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["r\[CurlyPhi] component", "Subsubsection",
 CellChangeTimes->{{3.537267797915071*^9, 3.537267800308117*^9}, {
  3.5372720616169653`*^9, 3.5372720621208878`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          FractionBox["eq24", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]], ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}],
        ")"}], "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG2", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK024", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5372567834248877`*^9, 3.537256789612069*^9}, 
   3.5372594467764797`*^9, {3.537262535423731*^9, 3.537262538501383*^9}, {
   3.537267804093533*^9, 3.5372678075868692`*^9}, {3.537272065303438*^9, 
   3.5372720690047283`*^9}, {3.53727533326468*^9, 3.53727533527738*^9}, {
   3.537282351737678*^9, 3.537282354591723*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.537256791362462*^9, 3.5372567951061087`*^9}, 
   3.537259460202023*^9, 3.537262599987797*^9, 3.537267009271978*^9, 
   3.537282876209581*^9, 3.537370419521347*^9, 3.537518621223496*^9, 
   3.537856337717998*^9, 3.5422891734593*^9, 3.5707327646868277`*^9, 
   3.570737577211219*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"EQQ", ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{
  3.537257983549049*^9, 3.537259460749791*^9, {3.537273349225313*^9, 
   3.5372733509860992`*^9}, {3.53727353531936*^9, 3.5372735380315123`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"W", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]cos", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"cY\[CurlyPhi]", ",", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cY\[CurlyPhi]cos", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"Coefficient", "[", 
       RowBox[{"cY\[CurlyPhi]", ",", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX", ",", "cW", ",", "cY", ",", "cY\[Theta]0", ",", "cY\[Theta]cos", 
      ",", "cY\[CurlyPhi]0", ",", "cY\[CurlyPhi]cos"}], "}"}], ",", 
    "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK24", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"cX", " ", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cW", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      RowBox[{"W", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]0", " ", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     RowBox[{"cY\[Theta]cos", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"cY\[CurlyPhi]0", " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{"cY\[CurlyPhi]cos", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]], "-", "EQ"}], ")"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.537257815655593*^9, 3.537257896937211*^9}, {
  3.537257934329865*^9, 3.5372580164455223`*^9}, {3.5372581938641367`*^9, 
  3.5372581957494373`*^9}, {3.5372582766778708`*^9, 3.537258322448601*^9}, {
  3.537258460689163*^9, 3.537258473165188*^9}, {3.537262351877323*^9, 
  3.53726236664986*^9}, {3.537262557909388*^9, 3.5372625587847548`*^9}, {
  3.5372678132791452`*^9, 3.537267813827435*^9}, {3.537272092055056*^9, 
  3.537272092362483*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537283172975836*^9, 3.53737069317714*^9, 
  3.537518856371241*^9, 3.53785661385303*^9, 3.5422891999186077`*^9, 
  3.570732775550968*^9, 3.570737587472365*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.537283172975836*^9, 3.53737069317714*^9, 
  3.537518856371241*^9, 3.53785661385303*^9, 3.5422891999186077`*^9, 
  3.570732775550968*^9, 3.570737587473127*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.537283172975836*^9, 3.53737069317714*^9, 
  3.537518856371241*^9, 3.53785661385303*^9, 3.5422891999186077`*^9, 
  3.570732775550968*^9, 3.57073758751799*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Beta]\[Beta]1", "=", "cY\[Theta]0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]\[Beta]t1", "=", "cY\[Theta]cos"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]\[Alpha]1", "=", "cY\[CurlyPhi]0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]\[Alpha]t1", "=", "cY\[CurlyPhi]cos"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Zeta]1", "=", "cY"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]\[Chi]1", "=", "cX"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]\[Xi]1", "=", 
   RowBox[{"-", "cW"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ24", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.537267824573831*^9, 3.537267825063336*^9}, {
  3.537267858800156*^9, 3.537267938067178*^9}, {3.537272096039526*^9, 
  3.5372721032003727`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_24.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK024", ",", "CHECK24", ",", "EQ24", ",", "\[Beta]\[Beta]1", ",", 
      "\[Beta]\[Beta]t1", ",", "\[Alpha]\[Alpha]1", ",", "\[Alpha]\[Alpha]t1",
       ",", "\[Zeta]1", ",", "\[Chi]\[Chi]1", ",", "\[Xi]\[Xi]1"}], "}"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537267955762085*^9, 3.537267989671874*^9}, {
  3.537272108531742*^9, 3.53727212676989*^9}, {3.5372760019229403`*^9, 
  3.5372760278845587`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Third group (\[Theta]\[CurlyPhi]  and  \[Theta]\[Theta] - \[CurlyPhi]\
\[CurlyPhi] components)\
\>", "Subsection",
 CellChangeTimes->{{3.537254761723589*^9, 3.537254804999716*^9}, {
  3.5372548507222137`*^9, 3.5372548647358637`*^9}, {3.537254940482621*^9, 
  3.537254955955806*^9}}],

Cell[CellGroupData[{

Cell["\[Theta]\[CurlyPhi] component", "Subsubsection",
 CellChangeTimes->{{3.5372721888118362`*^9, 3.53727219248359*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{"eq34", ",", 
          RowBox[{"{", 
           RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}],
        ")"}], "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG2", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK034", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5372722083325357`*^9, 3.537272211176832*^9}, {
  3.537275338872718*^9, 3.537275340370768*^9}, {3.537282371116212*^9, 
  3.537282394214814*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.53727337449295*^9, 3.53728328619521*^9, 
  3.537370717615806*^9, 3.537856639452289*^9, 3.542289209187725*^9, 
  3.570732783357238*^9, 3.570737588432004*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{
       RowBox[{"EQQ", "/.", "ruleANG2"}], ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{3.537273358899774*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"XX", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cX0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cX", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cXcos", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cX", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"W", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cW", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cWcos", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cW", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.537274733658681*^9, 3.537274734764345*^9}, {
  3.537274832009347*^9, 3.537274835510779*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cY\[Theta]", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    SuperscriptBox[
     RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.537272290463771*^9, 3.537272335562632*^9}, {
   3.537274841107585*^9, 3.5372748853970747`*^9}, 3.57073278660017*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX0", ",", "cXcos", ",", "cW0", ",", "cWcos", ",", "cY\[Theta]", ",", 
      "cY\[CurlyPhi]"}], "}"}], ",", "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX0", ",", "cXcos", ",", "cW0", ",", "cWcos", ",", "cY\[Theta]", ",", 
      "cY\[CurlyPhi]"}], "}"}], ",", "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.5372723546044703`*^9, 3.537272369920073*^9}, {
  3.5372748900367727`*^9, 3.53727491268367*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.537273554542561*^9, {3.53727490258348*^9, 3.537274913654127*^9}, 
   3.5372749746625633`*^9, 3.537283442633079*^9, 3.537370856120377*^9, 
   3.537856746564927*^9, 3.5422892213235397`*^9, 3.570732787868659*^9, 
   3.570737589088279*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.537273554542561*^9, {3.53727490258348*^9, 3.537274913654127*^9}, 
   3.5372749746625633`*^9, 3.537283442633079*^9, 3.537370856120377*^9, 
   3.537856746564927*^9, 3.5422892213235397`*^9, 3.570732787868659*^9, 
   3.5707375890891457`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CHECK34", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cX0", "+", 
        RowBox[{"cXcos", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
      FractionBox[
       RowBox[{"XX", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cW0", "+", 
        RowBox[{"cWcos", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
      FractionBox[
       RowBox[{"W", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], "+", 
     RowBox[{"cY\[Theta]", " ", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
     FractionBox[
      RowBox[{"cY\[CurlyPhi]", " ", 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]], "-", 
     FractionBox["EQ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]]}], ")"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.537272414682169*^9, 3.537272450634903*^9}, {
   3.5372744356759644`*^9, 3.537274438311056*^9}, {3.5372751063879843`*^9, 
   3.537275121412098*^9}, 3.537275180998488*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.537273648977601*^9, 3.537274546490212*^9, 
  3.53727513543651*^9, 3.537275183898444*^9, 3.53728344286032*^9, 
  3.5373708563945827`*^9, 3.537856747309948*^9, 3.5422892215179977`*^9, 
  3.5707327900382967`*^9, 3.570737589149693*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Kf", "=", "cY\[Theta]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kg", "=", "cY\[CurlyPhi]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ks", "=", "cX0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KsC", "=", "cXcos"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kt", "=", "cW0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KtC", "=", "cWcos"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ34", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.53727248482165*^9, 3.5372725201387978`*^9}, {
  3.537275200114992*^9, 3.5372752222542686`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_34.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK034", ",", "CHECK34", ",", "EQ34", ",", "Kf", ",", "Kg", ",", "Ks",
       ",", "KsC", ",", "Kt", ",", "KtC"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.537272534542425*^9, 3.537272550143458*^9}, {
  3.5372752635947027`*^9, 3.537275269367981*^9}, {3.5372760360767307`*^9, 
  3.537276045361657*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[" \[Theta]\[Theta] - \[CurlyPhi]\[CurlyPhi] components", "Subsubsection",
 CellChangeTimes->{3.537272196899149*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQQ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"eq33", "-", 
          FractionBox["eq44", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
      "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleANG2", ",", "rule0"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]p", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"CHECK033m44", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"EQQ", ",", "0"}], "]"}], "/.", "rule0"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5372722083325357`*^9, 3.537272211176832*^9}, {
  3.537275277166904*^9, 3.5372752789805737`*^9}, {3.5372753459063168`*^9, 
  3.537275364387556*^9}, {3.5372799678497477`*^9, 3.53727996803139*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.53727337449295*^9, {3.537275352022903*^9, 3.537275371904634*^9}, 
   3.5372754346481133`*^9, 3.537283560307805*^9, 3.53737091431388*^9, 
   3.537856813478561*^9, 3.542289234778675*^9, 3.570732794309016*^9, 
   3.570737590485776*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{
       RowBox[{"EQQ", "/.", "ruleANG2"}], ",", "1"}], "]"}], "/.", 
     RowBox[{
      SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{3.537273358899774*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{"XX", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cX0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cX", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cXcos", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cX", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"W", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cW0", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cW", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cWcos", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"cW", ",", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]", "=", 
   FractionBox[
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"EQ", ",", 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}], 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[CurlyPhi]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX0", ",", "cXcos", ",", "cW0", ",", "cWcos", ",", "cY\[Theta]", ",", 
      "cY\[CurlyPhi]"}], "}"}], ",", "\[Theta]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cX0", ",", "cXcos", ",", "cW0", ",", "cWcos", ",", "cY\[Theta]", ",", 
      "cY\[CurlyPhi]"}], "}"}], ",", "\[CurlyPhi]"}], "]"}], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"CHECK33m44", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"cX0", "+", 
         RowBox[{"cXcos", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
       FractionBox[
        RowBox[{"XX", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"cW0", "+", 
         RowBox[{"cWcos", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
       FractionBox[
        RowBox[{"W", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], "+", 
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "cY\[Theta]", " ", 
       FractionBox[
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], "+", 
      RowBox[{"cY\[CurlyPhi]", " ", 
       FractionBox[
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], "-", 
      FractionBox["EQ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]]}], ")"}], "]"}], "/.", 
   RowBox[{
    SuperscriptBox["AA", "2"], "\[Rule]", "1"}]}]}]}], "Input",
 CellChangeTimes->{{3.537284017702568*^9, 3.5372840425836353`*^9}, {
  3.570732804377903*^9, 3.570732804511754*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5707328049027367`*^9, 3.570737593689228*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5707328049027367`*^9, 3.570737593689981*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5707328049027367`*^9, 3.570737593724886*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Kgg", "=", "cY\[Theta]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kff", "=", 
   RowBox[{"-", "cY\[CurlyPhi]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ktt", "=", 
   RowBox[{"-", "cX0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KttC", "=", 
   RowBox[{"-", "cXcos"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kss", "=", "cW0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"KssC", "=", "cWcos"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ33m44", "=", "EQ"}], ";"}]}], "Input",
 CellChangeTimes->{{3.53727248482165*^9, 3.5372725201387978`*^9}, {
  3.537275200114992*^9, 3.5372752222542686`*^9}, {3.537275389397789*^9, 
  3.537275452319354*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<data/Kojima_Form_33m44.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "CHECK033m44", ",", "CHECK33m44", ",", "EQ33m44", ",", "Kff", ",", "Kgg",
       ",", "Kss", ",", "KssC", ",", "Ktt", ",", "KttC"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.537272534542425*^9, 3.537272550143458*^9}, {
  3.537272648751787*^9, 3.5372726669606047`*^9}, {3.5372754047542953`*^9, 
  3.537275408583959*^9}, {3.537276052440546*^9, 3.5372760619476023`*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Radial field equations without couplings\
\>", "Section",
 CellChangeTimes->{{3.5707328513283157`*^9, 3.570732854403159*^9}, {
  3.570732948667737*^9, 3.57073295105409*^9}}],

Cell["\<\
The angular part of the equations derived above can be completely separeted \
by using the orthogonality properties of the spherical harmonics. As \
explained in the notes, this procedure introduces couplings between polar and \
axial functions with different multipolar index $l$. However, these couplings \
do not affect the QNM spectrum at first order and we neglect them here.\
\>", "Text",
 CellChangeTimes->{{3.570737640760907*^9, 3.570737796206073*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"F", ",", "h10"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fun", "[", "t_", "]"}], ":=", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", "r_", "]"}], ":=", 
    RowBox[{"1", "-", 
     RowBox[{"2", 
      FractionBox["M", "r"]}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H0", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"H00", "[", "r", "]"}], " ", 
    RowBox[{"fun", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H1", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"H10", "[", "r", "]"}], " ", 
    RowBox[{"fun", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H2", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"H20", "[", "r", "]"}], " ", 
    RowBox[{"fun", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"KK", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"K0", "[", "r", "]"}], " ", 
    RowBox[{"fun", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h0", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"h00", "[", "r", "]"}], " ", 
    RowBox[{"fun", "[", "t", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", 
    RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"h10", "[", "r", "]"}], " ", 
    RowBox[{"fun", "[", "t", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5707334145812063`*^9, 3.5707334213886013`*^9}, {
  3.572207986274045*^9, 3.572207987270018*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_11.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_12.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_22.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_33p44.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_13.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_23.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_14.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_24.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_34.mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"<<", "\"\<data/Kojima_Form_33m44.mx\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.570732955861446*^9, 3.5707329624903727`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruleJ", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQ1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{"A00", "+", 
        RowBox[{"I", " ", "m", " ", "C0"}]}], ")"}]}], "/.", "ruleJ"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ2", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{"A1", "+", 
        RowBox[{"I", " ", "m", " ", "C1"}]}], ")"}]}], "/.", "ruleJ"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ3", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{"A2", "+", 
        RowBox[{"I", " ", "m", " ", "C2"}]}], ")"}]}], "/.", "ruleJ"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EQ4", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], 
         ")"}], 
        RowBox[{"-", "1"}]], 
       RowBox[{"(", 
        RowBox[{"A33", "+", 
         RowBox[{"I", " ", "m", " ", "C3"}]}], ")"}]}], "/.", "ruleJ"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ5", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"l", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}], "\[Alpha]0"}], "+", 
        RowBox[{"I", " ", "m", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"l", "-", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"l", "+", "2"}], ")"}], "\[Xi]0"}], "-", "\[Beta]t0", 
           "-", "\[Zeta]0"}], ")"}]}]}], ")"}]}], "/.", "ruleJ"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ6", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"l", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}], "\[Alpha]1"}], "+", 
        RowBox[{"I", " ", "m", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"l", "-", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"l", "+", "2"}], ")"}], "\[Xi]1"}], "-", "\[Beta]t1", 
           "-", "\[Zeta]1"}], ")"}]}]}], ")"}]}], "/.", "ruleJ"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ7", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"l", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}], "\[Beta]0"}], "+", 
        RowBox[{"I", " ", "m", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"l", "-", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"l", "+", "2"}], ")"}], "\[Chi]0"}], "+", "\[Alpha]t0", 
           "+", "\[Eta]0"}], ")"}]}]}], ")"}]}], "/.", "ruleJ"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EQ8", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], 
         ")"}], 
        RowBox[{"-", "1"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"l", 
          RowBox[{"(", 
           RowBox[{"l", "+", "1"}], ")"}], "\[Beta]1"}], "+", 
         RowBox[{"I", " ", "m", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"l", "-", "1"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"l", "+", "2"}], ")"}], "\[Chi]1"}], "+", "\[Alpha]t1", 
            "+", "\[Eta]1"}], ")"}]}]}], ")"}]}], "/.", "ruleJ"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ9", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"l", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}], "Ks"}], "-", 
        RowBox[{"I", " ", "m", " ", "Kf"}]}], ")"}]}], "/.", "ruleJ"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ10", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], ")"}], 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"l", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}], "Kt"}], "+", 
        RowBox[{"I", " ", "m", " ", "Kg"}]}], ")"}]}], "/.", "ruleJ"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.570732976526404*^9, 3.570733002135913*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<pert_eqs_Kerr.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
     "EQ1", ",", "EQ2", ",", "EQ3", ",", "EQ4", ",", "EQ5", ",", "EQ6", ",", 
      "EQ7", ",", "EQ8", ",", "EQ9", ",", "EQ10"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.57073304047967*^9, 3.570733044112864*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Axial sector", "Section",
 CellChangeTimes->{{3.542537028946878*^9, 3.542537029561904*^9}, {
  3.5559955326580544`*^9, 3.555995541489908*^9}, {3.5561872711604443`*^9, 
  3.556187340824786*^9}, {3.556892761772294*^9, 3.556892766172265*^9}, {
  3.5571191840506907`*^9, 3.557119184618227*^9}, {3.5572113324488983`*^9, 
  3.557211354570675*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<pert_eqs_Kerr.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     RowBox[{"M", "/", "r"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SJ", "[", "X_", "]"}], ":=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{"X", ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.542428671157145*^9, 3.542428686596583*^9}, {
   3.5571197717234783`*^9, 3.557119771856491*^9}, {3.557211367343265*^9, 
   3.557211367483931*^9}, 3.558929238412737*^9, {3.570733271614812*^9, 
   3.570733278370504*^9}, {3.5707333165755157`*^9, 3.570733323051362*^9}, {
   3.570733639297111*^9, 3.5707336491069927`*^9}}],

Cell["Let us define the RW function", "Text",
 CellChangeTimes->{{3.57073781674325*^9, 3.5707378217457848`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h10", "[", "r_", "]"}], ":=", 
   RowBox[{"r", " ", 
    FractionBox[
     RowBox[{"\[Psi]", "[", "r", "]"}], 
     RowBox[{"F", "[", "r", "]"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5423448609825497`*^9, 3.542344864950758*^9}, {
   3.542344931635303*^9, 3.542344966811694*^9}, {3.542345016005052*^9, 
   3.542345019315699*^9}, {3.5423473756322803`*^9, 3.5423473976939707`*^9}, 
   3.542347990145932*^9, {3.5423485140139427`*^9, 3.542348517261765*^9}, {
   3.542354613949541*^9, 3.5423546165640793`*^9}, 3.5423589451544657`*^9, {
   3.542428692647097*^9, 3.542428701260599*^9}, {3.555072005523469*^9, 
   3.555072007322955*^9}, {3.55711976915132*^9, 3.557119776227292*^9}, {
   3.570733329577615*^9, 3.570733329815269*^9}, {3.5707378386092157`*^9, 
   3.570737838972054*^9}}],

Cell["\<\
First, we solve EQ8 for h0 and substitute this in the others\
\>", "Text",
 CellChangeTimes->{{3.5707378422994556`*^9, 3.57073785493602*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleJ", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"h0pn", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"EQ8", "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"h00", "'"}], "[", "r", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleh0", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"h0pn", ",", 
     RowBox[{"D", "[", 
      RowBox[{"h0pn", ",", "r"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{"h0pn", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"EQ7", "//.", "ruleh0"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h0n", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"%", "\[Equal]", "0"}], ",", 
      RowBox[{"h00", "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleh0b", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"h0n", ",", 
     RowBox[{"D", "[", 
      RowBox[{"h0n", ",", "r"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{"h0n", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ERW1", "=", 
   RowBox[{
    RowBox[{"EQ8", "/.", "ruleh0b"}], "/.", "ruleJ"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]pp", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"ERW1", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Psi]", "''"}], "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.542348541601006*^9, 3.542348648451509*^9}, {
   3.5423487287331953`*^9, 3.5423488147685833`*^9}, {3.542349643611281*^9, 
   3.54234969384312*^9}, {3.542354213105013*^9, 3.542354262618174*^9}, {
   3.542354368016897*^9, 3.542354369940484*^9}, {3.542355004854755*^9, 
   3.54235507914357*^9}, {3.542358984562427*^9, 3.542359000046928*^9}, {
   3.542359128865159*^9, 3.54235913431155*^9}, {3.542367376079482*^9, 
   3.542367384352333*^9}, 3.555072020106629*^9, {3.5707334501438913`*^9, 
   3.57073345031739*^9}, {3.570733572647805*^9, 3.57073357653688*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["h00", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "J", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], " ", "m", " ", 
              "\[Epsilon]a"}], "-", 
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", 
              SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}], " ", 
           RowBox[{"h00", "[", "r", "]"}]}], 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}]]}], "-", 
        FractionBox[
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
            RowBox[{
            "4", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", "\[Omega]"}], 
            "-", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
          RowBox[{"\[Psi]", "[", "r", "]"}]}], 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}]]}], ")"}]}], 
     
     RowBox[{"l", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "l"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "J", " ", "m", " ", "\[Epsilon]a"}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}]}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5550720205692596`*^9, 3.555072572373431*^9, 3.556895289853623*^9, 
   3.5570343705300417`*^9, 3.557038681103676*^9, {3.557039098445429*^9, 
   3.5570391243670692`*^9}, 3.55712000335925*^9, 3.559635539375675*^9, 
   3.570733348508156*^9, {3.570733445246994*^9, 3.570733450797765*^9}, {
   3.570733572981879*^9, 3.570733577105201*^9}, 3.57073785656035*^9, 
   3.572208093050827*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ERW1b", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", "ERW1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5423592177190313`*^9, 3.542359287701087*^9}, {
  3.542359447296796*^9, 3.5423594485284643`*^9}, {3.5707334553739767`*^9, 
  3.570733455515623*^9}, {3.570733652216482*^9, 3.570733670275083*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox["r", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
    "\[Omega]"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        SuperscriptBox["r", "3"], " ", "\[Omega]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", "M", " ", "r"}], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"l", "+", 
             SuperscriptBox["l", "2"], "-", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "14"}], "+", 
             RowBox[{"5", " ", "l"}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["l", "2"]}]}], ")"}], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "26"}], "+", 
             RowBox[{"9", " ", "l"}], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["l", "2"]}]}], ")"}], " ", "M", " ", "r"}], "-", 
          
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"18", "+", 
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "6"}], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["l", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "6"}], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}], " ", 
     RowBox[{"\[Psi]", "[", "r", "]"}]}], "-", 
    RowBox[{"l", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "l"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "J", " ", "m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "\[Epsilon]a"}],
           "+", 
          RowBox[{"M", " ", 
           SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
        SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
        RowBox[{
         SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.542359222427753*^9, 3.5423592540299788`*^9}, 
   3.542359288046218*^9, 3.5423594489442673`*^9, 3.54238971777312*^9, 
   3.542428735398368*^9, 3.555072612238782*^9, 3.5568953129886436`*^9, 
   3.557034388692257*^9, 3.557038700305873*^9, 3.557039098552656*^9, 
   3.557039142994718*^9, 3.557120018076191*^9, 3.5596355577959633`*^9, 
   3.5707334563207493`*^9, 3.570733582771456*^9, 3.570733670925877*^9, 
   3.5707378645786*^9, 3.5722081064994173`*^9}]
}, Open  ]],

Cell["\<\
CHECK: Solving two of the equations for \[Psi]\[CloseCurlyQuote]\
\[CloseCurlyQuote] and h0[r], the other axial equation is automatically \
satisified\
\>", "Text",
 CellChangeTimes->{{3.570733911844055*^9, 3.570733913194006*^9}, {
  3.570737884462942*^9, 3.570737908041752*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RWpp", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"ERW1b", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Psi]", "''"}], "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleRW", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"h0pn", ",", "RWpp"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"h00R", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"SJ", "[", 
         RowBox[{"EQ10", "//.", 
          RowBox[{"Union", "[", 
           RowBox[{"ruleRW", ",", 
            RowBox[{"D", "[", 
             RowBox[{"ruleRW", ",", "r"}], "]"}]}], "]"}]}], "]"}], "]"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"h00", "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RULEaxial", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"RWpp", ",", "h00R"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"SJ", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"EQ7", ",", "EQ8", ",", "EQ10"}], "}"}], "//.", 
    RowBox[{"Union", "[", 
     RowBox[{"RULEaxial", ",", 
      RowBox[{"D", "[", 
       RowBox[{"RULEaxial", ",", "r"}], "]"}], ",", 
      RowBox[{"D", "[", 
       RowBox[{"RULEaxial", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "2"}], "}"}]}], "]"}], ",", 
      RowBox[{"D", "[", 
       RowBox[{"RULEaxial", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], "]"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.57073358459194*^9, 3.570733631432886*^9}, {
  3.570733676821699*^9, 3.570733730263321*^9}, {3.57073377522668*^9, 
  3.570733922466189*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"h00", "[", "r", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", "J", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "l", "+", 
              SuperscriptBox["l", "2"]}], ")"}], " ", "m", " ", 
            "\[Epsilon]a"}], "+", 
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}], " ", 
         RowBox[{"\[Psi]", "[", "r", "]"}]}], "+", 
        RowBox[{"l", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "l"}], ")"}], " ", 
         SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
         RowBox[{
          SuperscriptBox["\[Psi]", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
     RowBox[{"l", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "l"}], ")"}], " ", "r", " ", "\[Omega]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "J", " ", "m", " ", "\[Epsilon]a"}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}]}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.570733592985821*^9, 3.570733631706699*^9, {3.570733679820012*^9, 
   3.570733730554528*^9}, 3.570733785955282*^9, {3.570733821731598*^9, 
   3.570733923661314*^9}, 3.5707379096430893`*^9, 3.57220811074765*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.570733592985821*^9, 3.570733631706699*^9, {3.570733679820012*^9, 
   3.570733730554528*^9}, 3.570733785955282*^9, {3.570733821731598*^9, 
   3.570733923661314*^9}, 3.5707379096430893`*^9, 3.572208111309827*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["ERW1b"], "Input",
 CellChangeTimes->{{3.572208134291376*^9, 3.5722081449166727`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox["r", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
    "\[Omega]"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        SuperscriptBox["r", "3"], " ", "\[Omega]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", "M", " ", "r"}], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"l", "+", 
             SuperscriptBox["l", "2"], "-", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "14"}], "+", 
             RowBox[{"5", " ", "l"}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["l", "2"]}]}], ")"}], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "26"}], "+", 
             RowBox[{"9", " ", "l"}], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["l", "2"]}]}], ")"}], " ", "M", " ", "r"}], "-", 
          
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"18", "+", 
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "6"}], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["l", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "6"}], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}], " ", 
     RowBox[{"\[Psi]", "[", "r", "]"}]}], "-", 
    RowBox[{"l", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "l"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "J", " ", "m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "\[Epsilon]a"}],
           "+", 
          RowBox[{"M", " ", 
           SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
        SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
        RowBox[{
         SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.572208145342514*^9}]
}, Open  ]],

Cell["\<\
We are then left with a single Regge-Wheeler master equation, ERW.
We redefine the RW function in order to have a final equation in a nicer, \
Schroedinger-lilke form.\
\>", "Text",
 CellChangeTimes->{{3.570733944659206*^9, 3.570733945027327*^9}, {
  3.570737911458123*^9, 3.570737966741584*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Psi]", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CurlyPhi]", "[", "r", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", 
      FractionBox[
       RowBox[{"2", " ", "m", " ", "\[Epsilon]a", " ", "J"}], 
       RowBox[{
        SuperscriptBox["r", "3"], " ", "\[Omega]"}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ERW", "=", "ERW1b"}], ";"}]}], "Input",
 CellChangeTimes->{{3.570734014937566*^9, 3.5707340306206913`*^9}, {
  3.5707340719518147`*^9, 3.570734077481531*^9}, {3.570734119000589*^9, 
  3.5707341328039703`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"ERW", ",", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "''"}], "[", "r", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"ERW", ",", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "'"}], "[", "r", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c0", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"ERW", ",", 
     RowBox[{"\[CurlyPhi]", "[", "r", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"c10", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", 
    RowBox[{
     FractionBox["c1", "c2"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{
        RowBox[{"F", "'"}], "[", "r", "]"}], 
       RowBox[{"F", "[", "r", "]"}]}]]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Va", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"SJ", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Omega]", "2"], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[Epsilon]a", " ", "m", " ", 
        RowBox[{"\[Zeta]", "[", "r", "]"}], " ", "\[Omega]"}], 
       SuperscriptBox["r", "2"]], "-", 
      RowBox[{
       FractionBox["c0", "c2"], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], "2"], "1"]}]}], 
     RowBox[{"F", "[", "r", "]"}]], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.570733960777835*^9, 3.570734002950221*^9}, {
  3.5707340367348413`*^9, 3.570734038790626*^9}, {3.57073408188704*^9, 
  3.570734084314968*^9}, {3.5707341380779743`*^9, 3.57073417231248*^9}, {
  3.570734202792143*^9, 3.570734251741469*^9}, {3.57073431801357*^9, 
  3.5707343195494328`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.570734003253931*^9, 3.5707340392275143`*^9, {3.5707340846958027`*^9, 
   3.570734161346583*^9}, {3.570734212931829*^9, 3.57073425218747*^9}, 
   3.570734319855541*^9, {3.570737955376478*^9, 3.5707379688239737`*^9}, 
   3.572208157738946*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "M"}], "+", 
    RowBox[{"l", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "l"}], ")"}], " ", "r"}]}], 
   SuperscriptBox["r", "3"]], "+", 
  FractionBox[
   RowBox[{"24", " ", "J", " ", "m", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "7"}], " ", "M"}], "+", 
      RowBox[{"3", " ", "r"}]}], ")"}], " ", "\[Epsilon]a"}], 
   RowBox[{"l", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "l"}], ")"}], " ", 
    SuperscriptBox["r", "6"], " ", "\[Omega]"}]]}]], "Output",
 CellChangeTimes->{
  3.570734003253931*^9, 3.5707340392275143`*^9, {3.5707340846958027`*^9, 
   3.570734161346583*^9}, {3.570734212931829*^9, 3.57073425218747*^9}, 
   3.570734319855541*^9, {3.570737955376478*^9, 3.5707379688239737`*^9}, 
   3.572208158001189*^9}]
}, Open  ]],

Cell["\<\
Check: this is precisely the original equation:\
\>", "Text",
 CellChangeTimes->{{3.570737970401132*^9, 3.570737983361024*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"SJ", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], "c2"], "ERW"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"F", "[", "r", "]"}], "2"], 
       RowBox[{
        RowBox[{"\[CurlyPhi]", "''"}], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "'"}], "[", "r", "]"}], 
       RowBox[{"F", "[", "r", "]"}], 
       RowBox[{
        RowBox[{"\[CurlyPhi]", "'"}], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "-", 
         FractionBox[
          RowBox[{"2", " ", "\[Epsilon]a", " ", "m", " ", 
           RowBox[{"\[Zeta]", "[", "r", "]"}], " ", "\[Omega]"}], 
          SuperscriptBox["r", "2"]], "-", 
         RowBox[{
          RowBox[{"F", "[", "r", "]"}], 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"l", 
              RowBox[{"(", 
               RowBox[{"l", "+", "1"}], ")"}]}], 
             SuperscriptBox["r", "2"]], "-", 
            FractionBox[
             RowBox[{"6", "M"}], 
             SuperscriptBox["r", "3"]], "+", 
            FractionBox[
             RowBox[{"24", " ", "J", " ", "m", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "7"}], " ", "M"}], "+", 
                RowBox[{"3", " ", "r"}]}], ")"}], " ", "\[Epsilon]a"}], 
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", 
              SuperscriptBox["r", "6"], " ", "\[Omega]"}]]}], ")"}]}]}], 
        ")"}], 
       RowBox[{"\[CurlyPhi]", "[", "r", "]"}]}]}], ")"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.57073425655906*^9, 3.5707343579223423`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.57073433096751*^9, 3.570734358387917*^9}, 
   3.5707379844570932`*^9, 3.572208188460588*^9}]
}, Open  ]],

Cell["\<\
The equation above can now be solved with our preferred method (e.g. \
continued fractions or direct integration) to find the first order \
corrections to the QNMs.\
\>", "Text",
 CellChangeTimes->{{3.5707380000455303`*^9, 3.5707380339564*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polar sector", "Section",
 CellChangeTimes->{{3.542537028946878*^9, 3.542537029561904*^9}, {
  3.5559955326580544`*^9, 3.555995541489908*^9}, {3.5561872711604443`*^9, 
  3.556187340824786*^9}, {3.556892761772294*^9, 3.556892766172265*^9}, {
  3.557211351607342*^9, 3.557211352820137*^9}}],

Cell["\<\
This is more involved. We mostly follow Zerilli, \
http://inspirehep.net/record/93100 and specialize his treatment to the \
uncharged case, Q=0)\
\>", "Text",
 CellChangeTimes->{
  3.5561873127307673`*^9, {3.57073803841893*^9, 3.5707380693560333`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"F", ",", "ft01", ",", "ft02", ",", "ft12"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     RowBox[{"M", "/", "r"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SJ", "[", "X_", "]"}], ":=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{"X", ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "\"\<pert_eqs_Kerr.mx\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.556187785616454*^9, 3.556187824540345*^9}, {
   3.556191223639613*^9, 3.556191226683077*^9}, {3.55619145498734*^9, 
   3.556191470592861*^9}, {3.5561915454064817`*^9, 3.5561915458938103`*^9}, {
   3.5561918396334457`*^9, 3.556191839868471*^9}, {3.5561966087422132`*^9, 
   3.5561966121792192`*^9}, 3.558929449662921*^9, {3.5707332979605923`*^9, 
   3.570733307481429*^9}, {3.570734411184235*^9, 3.570734411330892*^9}}],

Cell["We first solve EQ9 for H2:", "Text",
 CellChangeTimes->{{3.556892941157276*^9, 3.556892948221877*^9}, {
  3.570737124424879*^9, 3.570737125132367*^9}, {3.570738076989749*^9, 
  3.570738077757025*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H2n", "=", 
  RowBox[{"SJ", "[", 
   RowBox[{
    RowBox[{"H20", "[", "r", "]"}], "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"EQ9", "\[Equal]", "0"}], ",", 
       RowBox[{"H20", "[", "r", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.556103466746908*^9, 3.556103539375648*^9}, 
   3.5561038482963*^9, {3.5561965405670853`*^9, 3.556196563383594*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["r", "2"], " ", 
    RowBox[{"H00", "[", "r", "]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]], "+", 
  FractionBox[
   RowBox[{
   "4", " ", "J", " ", "m", " ", "r", " ", "\[Epsilon]a", " ", "\[Omega]", 
    " ", 
    RowBox[{"K0", "[", "r", "]"}]}], 
   RowBox[{"l", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "l"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], 
     "2"]}]]}]], "Output",
 CellChangeTimes->{{3.556196549497385*^9, 3.556196563757682*^9}, 
   3.556196620467681*^9, 3.556863850519484*^9, 3.557125970563396*^9, 
   3.570736368716552*^9, 3.570738078958107*^9}]
}, Open  ]],

Cell["\<\
We insert the solution of H2 obtained before into other Einstein\
\[CloseCurlyQuote]s equations:\
\>", "Text",
 CellChangeTimes->{{3.556893088216565*^9, 3.5568931095596724`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleH2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"H20", "[", "r", "]"}], "\[Rule]", "H2n"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H20", "'"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"H2n", ",", "r"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H20", "''"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"H2n", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"EQ2b", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", 
    RowBox[{"EQ2", "//.", 
     RowBox[{"Union", "[", "ruleH2", "]"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ5b", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", 
    RowBox[{"EQ5", "//.", 
     RowBox[{"Union", "[", "ruleH2", "]"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ6b", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", 
    RowBox[{"EQ6", "//.", 
     RowBox[{"Union", "[", "ruleH2", "]"}]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.556103558566916*^9, 3.5561035870760307`*^9}, {
  3.556103688128943*^9, 3.5561036939232903`*^9}, {3.5561038523034973`*^9, 
  3.556103853415886*^9}, {3.556176311208788*^9, 3.556176315416237*^9}, {
  3.556176673321801*^9, 3.5561766783817387`*^9}, {3.5561923017920856`*^9, 
  3.556192329174131*^9}, {3.55619238424642*^9, 3.556192394465941*^9}, {
  3.5561927140449743`*^9, 3.556192714543594*^9}, {3.556196771338118*^9, 
  3.556196816223112*^9}, {3.556197442050169*^9, 3.556197461188842*^9}, {
  3.5707364073355713`*^9, 3.570736411524444*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", "l", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "l"}], ")"}], " ", 
     SuperscriptBox["r", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}]], 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "l", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "l"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"J", " ", "m", " ", "\[Epsilon]a"}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}], " ", 
       RowBox[{"H00", "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["l", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "-", 
            RowBox[{
            "2", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", "\[Omega]"}]}], 
           ")"}], " ", 
          RowBox[{"H10", "[", "r", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", "\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "M"}], "-", "r"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["l", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "M"}], "-", "r"}], ")"}]}], "+", 
               RowBox[{
               "4", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
                "\[Omega]"}]}], ")"}], " ", 
             RowBox[{"K0", "[", "r", "]"}]}], "+", 
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"J", " ", "m", " ", "\[Epsilon]a", " ", 
                RowBox[{
                 SuperscriptBox["H00", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                SuperscriptBox["r", "2"], " ", "\[Omega]", " ", 
                RowBox[{
                 SuperscriptBox["K0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.55610356649807*^9, 3.5561035877795277`*^9}, 
   3.5561036957727118`*^9, 3.5561038541371326`*^9, 3.5561044784742527`*^9, 
   3.556170103087225*^9, 3.556176316603505*^9, 3.556176679359*^9, 
   3.556188299063613*^9, 3.556192254230661*^9, 3.556192330564939*^9, 
   3.5561923963367043`*^9, 3.5561927151440077`*^9, 3.5561968214893*^9, {
   3.556197449981122*^9, 3.5561974633430967`*^9}, 3.556863939359614*^9, 
   3.55686540895603*^9, 3.570736412587237*^9, 3.570738085621663*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", 
     SuperscriptBox["r", "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "r"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "l"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
          SuperscriptBox["r", "3"], " ", "\[Omega]"}], "+", 
         RowBox[{"2", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["l", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"H00", "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l", " ", "M", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["l", "2"], " ", "M", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
            RowBox[{"2", " ", "J", " ", "m", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "M"}], "+", "r"}], ")"}], " ", "\[Epsilon]a", " ",
              "\[Omega]"}]}], ")"}], " ", 
          RowBox[{"H10", "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "l"}], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
             SuperscriptBox["r", "3"], " ", "\[Omega]"}], "+", 
            RowBox[{"2", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "l", "+", 
                  SuperscriptBox["l", "2"]}], ")"}], " ", "M"}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "-", "l", "-", 
                  SuperscriptBox["l", "2"], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"K0", "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
            "4", " ", "J", " ", "m", " ", "r", " ", "\[Epsilon]a", " ", 
             RowBox[{
              SuperscriptBox["H00", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["r", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["l", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
               RowBox[{
               "4", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
                "\[Omega]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["H10", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"2", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", " ", "M"}], "-", 
                  RowBox[{"3", " ", "r"}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["K0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"r", " ", 
                   RowBox[{
                    SuperscriptBox["H00", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["K0", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.55610356649807*^9, 3.5561035877795277`*^9}, 
   3.5561036957727118`*^9, 3.5561038541371326`*^9, 3.5561044784742527`*^9, 
   3.556170103087225*^9, 3.556176316603505*^9, 3.556176679359*^9, 
   3.556188299063613*^9, 3.556192254230661*^9, 3.556192330564939*^9, 
   3.5561923963367043`*^9, 3.5561927151440077`*^9, 3.5561968214893*^9, {
   3.556197449981122*^9, 3.5561974633430967`*^9}, 3.556863939359614*^9, 
   3.55686540895603*^9, 3.570736412587237*^9, 3.570738086109956*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "l", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "l"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "J", " ", "m", " ", "\[Epsilon]a"}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", "\[Omega]"}]}], ")"}], " ", 
    RowBox[{"H10", "[", "r", "]"}]}], "+", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "J", " ", "m", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "M"}], "-", 
         RowBox[{"5", " ", "r"}]}], ")"}], " ", "\[Epsilon]a", " ", 
       "\[Omega]", " ", 
       RowBox[{"K0", "[", "r", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", "r", " ", 
          RowBox[{
           SuperscriptBox["H00", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["l", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}], "+", 
            RowBox[{
            "2", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", "\[Omega]"}]}], 
           ")"}], " ", 
          RowBox[{
           SuperscriptBox["K0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
     ")"}]}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["r", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.55610356649807*^9, 3.5561035877795277`*^9}, 
   3.5561036957727118`*^9, 3.5561038541371326`*^9, 3.5561044784742527`*^9, 
   3.556170103087225*^9, 3.556176316603505*^9, 3.556176679359*^9, 
   3.556188299063613*^9, 3.556192254230661*^9, 3.556192330564939*^9, 
   3.5561923963367043`*^9, 3.5561927151440077`*^9, 3.5561968214893*^9, {
   3.556197449981122*^9, 3.5561974633430967`*^9}, 3.556863939359614*^9, 
   3.55686540895603*^9, 3.570736412587237*^9, 3.570738086223768*^9}]
}, Open  ]],

Cell["\<\
Note that now the equations contains second derivatives of H00 and K00 which \
are first order in the spin. We can solve the system perturbatively (a \
similar procedure is explained more in detail below). First, we solve two of \
the equations above for K0\[CloseCurlyQuote] and H0\[CloseCurlyQuote]:\
\>", "Text",
 CellChangeTimes->{{3.5568931318164577`*^9, 3.556893138937067*^9}, {
  3.5568932148591948`*^9, 3.556893280983198*^9}, {3.5568934176139936`*^9, 
  3.5568934330551033`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"syst1a", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EQ2b", "\[Equal]", "0"}], ",", 
         RowBox[{"EQ6b", "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"H00", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"K0", "'"}], "[", "r", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H00pn", "=", 
   RowBox[{"SJ", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"H00", "'"}], "[", "r", "]"}], "/.", "syst1a"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K0pn", "=", 
   RowBox[{"SJ", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"K0", "'"}], "[", "r", "]"}], "/.", "syst1a"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesyst1a", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"H00", "'"}], "[", "r", "]"}], "\[Rule]", "H00pn"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H00", "''"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"H00pn", ",", "r"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"K0", "'"}], "[", "r", "]"}], "\[Rule]", "K0pn"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"K0", "''"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"K0pn", ",", "r"}], "]"}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.556192767593692*^9, 3.5561928135004253`*^9}, {
   3.55619684177273*^9, 3.55619692942041*^9}, 3.570738095622593*^9}],

Cell["\<\
Then, at first order in J, the following are now H0\[CloseCurlyQuote], K0\
\[CloseCurlyQuote] and H1\[CloseCurlyQuote] as only functions of H0, K0, H1\
\[CloseCurlyQuote]:\
\>", "Text",
 CellChangeTimes->{{3.55619763424365*^9, 3.5561976663288097`*^9}, {
  3.556893151303323*^9, 3.556893155923971*^9}, {3.556893289354354*^9, 
  3.556893306040979*^9}, {3.5707447558648863`*^9, 3.5707447559978523`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"syst1", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EQ2b", "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"EQ5b", "//.", "rulesyst1a"}], ")"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{"EQ6b", "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H00", "'"}], "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"K0", "'"}], "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"H10", "'"}], "[", "r", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H00pn", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"H00", "'"}], "[", "r", "]"}], "/.", "syst1"}], "]"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K0pn", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"K0", "'"}], "[", "r", "]"}], "/.", "syst1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H10pn", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"H10", "'"}], "[", "r", "]"}], "/.", "syst1"}], "]"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesyst1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"H00", "'"}], "[", "r", "]"}], "\[Rule]", "H00pn"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"K0", "'"}], "[", "r", "]"}], "\[Rule]", "K0pn"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H10", "'"}], "[", "r", "]"}], "\[Rule]", "H10pn"}]}], "}"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.556103729383913*^9, 3.556103768886948*^9}, {
   3.556170116354148*^9, 3.556170116854311*^9}, {3.556192824541998*^9, 
   3.5561928380935802`*^9}, 3.5561969384851637`*^9, {3.556196996548315*^9, 
   3.556197019742238*^9}, {3.556197052442316*^9, 3.5561970705466013`*^9}, {
   3.5561977523060513`*^9, 3.5561977842800407`*^9}}],

Cell["We can eliminate H0:", "Text",
 CellChangeTimes->{{3.5568933476076202`*^9, 3.556893351281266*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQ3b", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"EQ3", "//.", 
     RowBox[{"Union", "[", 
      RowBox[{"ruleH2", ",", "rulesyst1"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"H0n", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", 
    RowBox[{
     RowBox[{"H00", "[", "r", "]"}], "/.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"EQ3b", "\[Equal]", "0"}], ",", 
        RowBox[{"H00", "[", "r", "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleH0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"H00", "[", "r", "]"}], "\[Rule]", "H0n"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H00", "'"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"H0n", ",", "r"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H00", "''"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"H0n", ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5561037702126083`*^9, 3.556103789895403*^9}, {
   3.556103831816143*^9, 3.556103859434661*^9}, {3.556103998187668*^9, 
   3.556104006348699*^9}, {3.55611457302194*^9, 3.5561145737365828`*^9}, {
   3.556176338380459*^9, 3.556176338511367*^9}, {3.5561766864589643`*^9, 
   3.55617668720968*^9}, {3.556197684886178*^9, 3.55619773938173*^9}, 
   3.5561977876768436`*^9, {3.556197950777954*^9, 3.556197964512115*^9}, {
   3.556198011634425*^9, 3.5561980122442427`*^9}, {3.556198067253731*^9, 
   3.556198073883628*^9}, {3.556198234723341*^9, 3.556198252024521*^9}, {
   3.5561983857780523`*^9, 3.5561983948861313`*^9}, {3.570736458665234*^9, 
   3.5707364588231697`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["r", "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "M"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Omega]", "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "M"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], " ", 
     "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l", " ", "M"}], "+", 
          RowBox[{
           SuperscriptBox["l", "2"], " ", "M"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
        RowBox[{"H10", "[", "r", "]"}]}], "+", 
       RowBox[{"r", " ", "\[Omega]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "6"}], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", "M", " ", "r"}], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "l", "+", 
             SuperscriptBox["l", "2"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"K0", "[", "r", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}]}], ")"}]}], 
     RowBox[{"J", " ", "m", " ", "\[Epsilon]a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["l", "5"], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["l", "6"], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["l", "3"], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               SuperscriptBox["M", "2"]}], "-", 
              RowBox[{"10", " ", "M", " ", "r"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["r", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["l", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["M", "3"]}], "-", 
              RowBox[{"M", " ", 
               SuperscriptBox["r", "2"]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", "l", " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox["\[Omega]", "2"]}], "+", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
            SuperscriptBox["r", "6"], " ", 
            SuperscriptBox["\[Omega]", "4"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["l", "2"], " ", "M", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["M", "2"]}], "-", 
              RowBox[{"3", " ", "M", " ", "r"}], "+", 
              SuperscriptBox["r", "2"], "+", 
              RowBox[{"4", " ", "M", " ", 
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox["\[Omega]", "2"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "4"], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"H10", "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", "r", " ", "\[Omega]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               SuperscriptBox["M", "2"]}], "-", 
              RowBox[{"12", " ", "M", " ", "r"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["r", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["r", "4"], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["l", "3"], " ", "r", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["M", "2"], "-", 
              RowBox[{"M", " ", "r"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "4"], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["l", "4"], " ", "r", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["M", "2"], "-", 
              RowBox[{"M", " ", "r"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "4"], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "6"}], " ", 
               SuperscriptBox["M", "3"]}], "+", 
              RowBox[{"2", " ", "M", " ", 
               SuperscriptBox["r", "2"]}], "+", 
              RowBox[{"26", " ", "M", " ", 
               SuperscriptBox["r", "4"], " ", 
               SuperscriptBox["\[Omega]", "2"]}], "-", 
              RowBox[{"10", " ", 
               SuperscriptBox["r", "5"], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["l", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "6"}], " ", 
               SuperscriptBox["M", "3"]}], "+", 
              RowBox[{
               SuperscriptBox["M", "2"], " ", "r"}], "+", 
              RowBox[{"M", " ", 
               SuperscriptBox["r", "2"]}], "+", 
              RowBox[{"26", " ", "M", " ", 
               SuperscriptBox["r", "4"], " ", 
               SuperscriptBox["\[Omega]", "2"]}], "-", 
              RowBox[{"8", " ", 
               SuperscriptBox["r", "5"], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"K0", "[", "r", "]"}]}]}], ")"}]}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.556103783833268*^9, 3.556103790391386*^9}, {
   3.556103840074768*^9, 3.556103859726583*^9}, 3.5561040067436647`*^9, 
   3.556104481421936*^9, 3.556114576874002*^9, 3.556170127706294*^9, 
   3.556176339978635*^9, 3.556176689737556*^9, 3.5561883075486507`*^9, 
   3.556197733362657*^9, 3.5561977974215117`*^9, {3.5561980135310802`*^9, 
   3.556198023317545*^9}, 3.5561982591026506`*^9, 3.556198403339079*^9, 
   3.5568639687567387`*^9, 3.556865443396394*^9, 3.57073646225007*^9, 
   3.570738099834988*^9}]
}, Open  ]],

Cell["\<\
Therefore, we just have two equations for H1, K:\
\>", "Text",
 CellChangeTimes->{{3.556893355238778*^9, 3.556893370958963*^9}, {
  3.570736468412681*^9, 3.570736471262094*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq33", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{"EQ2", "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleH2", ",", "ruleH0"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq34", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{"EQ5", "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"ruleH2", ",", "ruleH0"}], "]"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.556103906653504*^9, 3.556103966905072*^9}, {
   3.556105291971147*^9, 3.556105295309825*^9}, {3.55617634670111*^9, 
   3.556176369906015*^9}, {3.556176413785056*^9, 3.556176415876017*^9}, {
   3.556176456685377*^9, 3.556176464600092*^9}, {3.5561766980782967`*^9, 
   3.5561767284705477`*^9}, {3.556176768333839*^9, 3.556176806308614*^9}, {
   3.5561768563219833`*^9, 3.5561768831053534`*^9}, {3.5561980395558777`*^9, 
   3.556198052277375*^9}, {3.5561982700524673`*^9, 3.556198283535816*^9}, {
   3.556198844962336*^9, 3.556198855396571*^9}, {3.5562001855098753`*^9, 
   3.5562001942549143`*^9}, 3.556603754299901*^9, {3.556863754061419*^9, 
   3.556863754977434*^9}, {3.5707364753705378`*^9, 3.5707364784165573`*^9}}],

Cell["\<\
Equations 33 and 34 contains second derivatives of H1 and K which are \
proportional to J. Within our perturbative scheme, we can eliminate them by \
taking the zeroth order of eq33 and eq34, solve them for \
H10\[CloseCurlyQuote] and K\[CloseCurlyQuote] , then substitute the \
derivatives into the full form of eq33 and eq34 and finally expand at first \
order.\
\>", "Text",
 CellChangeTimes->{{3.556252595048726*^9, 3.556252690019711*^9}, {
  3.55625277946236*^9, 3.556252805984479*^9}, {3.556253011303862*^9, 
  3.556253057295413*^9}, {3.5707365308125353`*^9, 3.570736555663364*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq330", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq33", "/.", 
     RowBox[{"\[Epsilon]a", "\[Rule]", "0"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq340", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eq34", "/.", 
     RowBox[{"\[Epsilon]a", "\[Rule]", "0"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"systH1K0", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"eq330", "\[Equal]", "0"}], ",", 
         RowBox[{"eq340", "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["K0", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], ",", 
         RowBox[{
          SuperscriptBox["H10", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "}"}]}], "]"}], "]"}],
     "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq33b", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{"eq33", "/.", 
      RowBox[{"D", "[", 
       RowBox[{"systH1K0", ",", "r"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq34b", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{"eq34", "/.", 
      RowBox[{"D", "[", 
       RowBox[{"systH1K0", ",", "r"}], "]"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.556252314129101*^9, 3.5562524828589973`*^9}, {
  3.556252530398184*^9, 3.556252539809211*^9}, {3.556252798976985*^9, 
  3.5562527994098997`*^9}, {3.556252993283865*^9, 3.556253005612027*^9}, {
  3.55625306392873*^9, 3.5562530988907623`*^9}, {3.5707365087108*^9, 
  3.570736519109254*^9}}],

Cell["\<\
 Finally, we get a system of two equations that we can solve for H10\
\[CloseCurlyQuote] and K\[CloseCurlyQuote] :\
\>", "Text",
 CellChangeTimes->{{3.556252816880129*^9, 3.556252818383238*^9}, {
  3.570736562009122*^9, 3.570736572130725*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"syst3", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eq33b", "\[Equal]", "0"}], ",", 
       RowBox[{"eq34b", "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H10", "'"}], "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"K0", "'"}], "[", "r", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H10pn", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"H10", "'"}], "[", "r", "]"}], "/.", 
      RowBox[{"syst3", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K0pn", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"K0", "'"}], "[", "r", "]"}], "/.", 
      RowBox[{"syst3", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.55625282094401*^9, 3.556252897646112*^9}, 
   3.556253105821754*^9, {3.556253320659429*^9, 3.556253326924222*^9}, 
   3.556515253311494*^9, {3.5566037794010067`*^9, 3.556603782421006*^9}, {
   3.570736574684615*^9, 3.570736589235853*^9}}],

Cell[CellGroupData[{

Cell["Single 2nd order equation: ", "Subsubsection",
 CellChangeTimes->{{3.556113118663888*^9, 3.556113122719274*^9}, {
  3.556188345570615*^9, 3.556188351593329*^9}, {3.57073810885255*^9, 
  3.570738109963698*^9}}],

Cell["\<\
We perform a linear transformation on K0 and H10 in order to obtain a single \
second order equation (i.e. the Zerilli equation)\
\>", "Text",
 CellChangeTimes->{{3.556188353986375*^9, 3.556188393459125*^9}, {
  3.556253919564837*^9, 3.55625392069908*^9}, {3.556893550893855*^9, 
  3.556893551955389*^9}, {3.5707381183945627`*^9, 3.5707381277535667`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq33F", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"K0", "'"}], "[", "r", "]"}], "-", "K0pn"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq34F", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"H10", "'"}], "[", "r", "]"}], "-", "H10pn"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.556253960832546*^9, 3.556253988223288*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"K0", "[", "r_", "]"}], ":=", 
   RowBox[{"\[CapitalPsi]1", "[", "r", "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"H10", "[", "r_", "]"}], ":=", 
    RowBox[{"\[Omega]", " ", 
     RowBox[{"\[CapitalPsi]2", "[", "r", "]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"this", " ", "is", " ", "just", " ", "a", " ", "redefinition"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E1", "=", 
   RowBox[{"Simplify", "[", "eq33F", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E2", "=", 
   RowBox[{"Simplify", "[", "eq34F", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"syst\[CapitalPsi]", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"E1", "\[Equal]", "0"}], ",", 
         RowBox[{"E2", "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalPsi]1", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"\[CapitalPsi]2", "'"}], "[", "r", "]"}]}], "}"}]}], "]"}], 
     "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"K0", ",", "H10"}], "]"}]}], "Input",
 CellChangeTimes->{{3.556106221701378*^9, 3.556106250050995*^9}, {
   3.55610702533326*^9, 3.556107142571906*^9}, {3.556253994709928*^9, 
   3.556253995842702*^9}, 3.556254037852871*^9, {3.55689355702779*^9, 
   3.556893564121827*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "The", " ", "matrix", " ", "A", " ", "is", " ", "defined", " ", "in", " ", 
    "Zerilli"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A11", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[CapitalPsi]1", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "/.", 
         "syst\[CapitalPsi]"}], ",", 
        RowBox[{"\[CapitalPsi]1", "[", "r", "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A12", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[CapitalPsi]1", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "/.", 
         "syst\[CapitalPsi]"}], ",", 
        RowBox[{"\[CapitalPsi]2", "[", "r", "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A21", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[CapitalPsi]2", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "/.", 
         "syst\[CapitalPsi]"}], ",", 
        RowBox[{"\[CapitalPsi]1", "[", "r", "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A22", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[CapitalPsi]2", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "/.", 
         "syst\[CapitalPsi]"}], ",", 
        RowBox[{"\[CapitalPsi]2", "[", "r", "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Source", " ", 
     RowBox[{"terms", ":", " ", 
      RowBox[{
      "they", " ", "are", " ", "zero", " ", "as", " ", "they", " ", "should", 
       " ", "be"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"S1", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CapitalPsi]1", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], "/.", 
        "syst\[CapitalPsi]"}], ")"}], "-", 
      RowBox[{"A11", " ", 
       RowBox[{"\[CapitalPsi]1", "[", "r", "]"}]}], "-", 
      RowBox[{"A12", " ", 
       RowBox[{"\[CapitalPsi]2", "[", "r", "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"S2", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CapitalPsi]2", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], "/.", 
        "syst\[CapitalPsi]"}], ")"}], "-", 
      RowBox[{"A21", " ", 
       RowBox[{"\[CapitalPsi]1", "[", "r", "]"}]}], "-", 
      RowBox[{"A22", " ", 
       RowBox[{"\[CapitalPsi]2", "[", "r", "]"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5561071702123938`*^9, 3.5561073274046593`*^9}, {
   3.556254061164977*^9, 3.556254063828979*^9}, {3.556893572362917*^9, 
   3.556893589441475*^9}, 3.570736614557228*^9, 3.570736752222612*^9, {
   3.57073813557276*^9, 3.570738139677895*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.57073675298101*^9, 3.570738131155426*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.57073675298101*^9, 3.5707381311760073`*^9}]
}, Open  ]],

Cell["\<\
Here we follow Zerilli with Q=0:\
\>", "Text",
 CellChangeTimes->{{3.556893598847847*^9, 3.556893605225112*^9}, {
  3.570738146525736*^9, 3.570738151145548*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "V", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"F11", ",", "F22", ",", "F12", ",", "F21", ",", "n"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"A11", ",", "A12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"A21", ",", "A22"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FF", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"F11", "[", "r", "]"}], "+", 
        RowBox[{"0", "\[Epsilon]a", " ", 
         RowBox[{"F11b", "[", "r", "]"}]}]}], " ", ",", 
       RowBox[{
        RowBox[{"F12", "[", "r", "]"}], "+", 
        RowBox[{"0", "\[Epsilon]a", " ", 
         RowBox[{"F12b", "[", "r", "]"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"F21", "[", "r", "]"}], "+", 
        RowBox[{"0", "\[Epsilon]a", "  ", 
         RowBox[{"F21b", "[", "r", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"F22", "[", "r", "]"}], "+", 
        RowBox[{"0", "\[Epsilon]a", "  ", 
         RowBox[{"F22b", "[", "r", "]"}]}]}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MM", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]a", "  ", 
        RowBox[{"G1", "[", "r", "]"}]}], ",", 
       RowBox[{"1", "+", 
        RowBox[{"\[Epsilon]a", " ", 
         RowBox[{"W", "[", "r", "]"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Omega]", "2"]}], "+", "V", "+", 
        RowBox[{"\[Epsilon]a", " ", 
         RowBox[{"V1", "[", "r", "]"}]}]}], ",", 
       RowBox[{"\[Epsilon]a", " ", 
        RowBox[{"G2", "[", "r", "]"}]}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eqMATRIX", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"n", "[", "r", "]"}], " ", 
       RowBox[{
        RowBox[{"Inverse", "[", "FF", "]"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"AA", ".", "FF"}], "-", 
          RowBox[{"D", "[", 
           RowBox[{"FF", ",", "r"}], "]"}]}], ")"}]}]}], "-", "MM"}], "]"}]}],
    ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"ZEROth", " ", "ORDER"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     FractionBox["M", "r"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "r_", "]"}], ":=", 
   RowBox[{"F", "[", "r", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F12", "[", "r_", "]"}], ":=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F21", "[", "r_", "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"M", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"2", " ", "M"}], "-", "r"}]], "-", 
        FractionBox["6", 
         RowBox[{
          RowBox[{"6", " ", "M"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}]]}], ")"}]}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"F", "[", "r", "]"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"6", " ", "M"}], 
       SuperscriptBox["r", "3"]], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", "l"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["r", "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "l"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "M"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], 
           "2"]]}], ")"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F11", "[", "r_", "]"}], ":=", 
   FractionBox[
    RowBox[{
     RowBox[{"24", " ", 
      SuperscriptBox["M", "2"]}], "+", 
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "l", "+", 
        SuperscriptBox["l", "2"]}], ")"}], " ", "M", " ", "r"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "l"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "l"}], ")"}], " ", 
      SuperscriptBox["r", "2"]}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "M"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F22", "[", "r_", "]"}], ":=", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["r", "2"]}], 
    RowBox[{
     RowBox[{"2", " ", "M"}], "-", "r"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"eqMs", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Series", "[", 
    RowBox[{"eqMATRIX", ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]a", ",", "0", ",", "0"}], "}"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.556107356135187*^9, 3.556107456029314*^9}, {
   3.55610753381385*^9, 3.556107579734394*^9}, {3.5561076196685658`*^9, 
   3.556107912719468*^9}, {3.556109687969018*^9, 3.556109688216103*^9}, {
   3.556109722272874*^9, 3.5561097367005157`*^9}, {3.556112744176174*^9, 
   3.556112777480803*^9}, {3.556114784644576*^9, 3.556114835898466*^9}, {
   3.5561713173513107`*^9, 3.556171320773941*^9}, {3.5561713674069033`*^9, 
   3.5561714185315943`*^9}, {3.556254797350564*^9, 3.556254828407433*^9}, {
   3.556254932763414*^9, 3.556254964387744*^9}, {3.5562550366057796`*^9, 
   3.556255050685849*^9}, {3.556255181956851*^9, 3.55625521407843*^9}, {
   3.556256341774353*^9, 3.5562563629784517`*^9}, {3.556256548114575*^9, 
   3.556256549628435*^9}, {3.55626005881008*^9, 3.556260060745236*^9}, {
   3.556261105520603*^9, 3.5562611137968187`*^9}, {3.5562633688813257`*^9, 
   3.556263391191846*^9}, {3.5562641328046083`*^9, 3.5562641375524178`*^9}, {
   3.556264317658881*^9, 3.556264321523109*^9}, {3.5562645506255617`*^9, 
   3.5562645511380863`*^9}, {3.556268550099969*^9, 3.556268628109447*^9}, {
   3.556269364327199*^9, 3.556269390796557*^9}, {3.556270408238872*^9, 
   3.556270431966628*^9}, 3.5568563744410152`*^9, {3.556856607246251*^9, 
   3.556856608701408*^9}, {3.556893616030899*^9, 3.556893618314005*^9}, {
   3.557134596070231*^9, 3.557134599647683*^9}, {3.570736621327732*^9, 
   3.570736699197495*^9}, {3.5707381436081142`*^9, 3.570738143765725*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]a", "]"}], "1"],
      SeriesData[$CellContext`\[Epsilon]a, 0, {}, 1, 1, 1],
      Editable->False], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]a", "]"}], "1"],
      SeriesData[$CellContext`\[Epsilon]a, 0, {}, 1, 1, 1],
      Editable->False]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]a", "]"}], "1"],
      SeriesData[$CellContext`\[Epsilon]a, 0, {}, 1, 1, 1],
      Editable->False], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]a", "]"}], "1"],
      SeriesData[$CellContext`\[Epsilon]a, 0, {}, 1, 1, 1],
      Editable->False]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5562563633867207`*^9, 3.556256550422833*^9, 3.5562565998015842`*^9, 
   3.556260118933086*^9, 3.556263391528762*^9, 3.556263456473298*^9, 
   3.5562641892123404`*^9, 3.556264551956593*^9, 3.5562646391135406`*^9, 
   3.5562693577254887`*^9, 3.556269461730051*^9, {3.5562704333135843`*^9, 
   3.5562704527412653`*^9}, 3.556515410510488*^9, 3.556604676305238*^9, 
   3.556856492543432*^9, 3.5568566236037397`*^9, 3.5568646949586973`*^9, 
   3.556865817462338*^9, 3.557135041906117*^9, {3.570736621886259*^9, 
   3.5707366406062317`*^9}, {3.57073668665763*^9, 3.570736705200017*^9}, 
   3.5707367614874763`*^9, 3.57073815999159*^9}]
}, Open  ]],

Cell["The zeroth order is solved. Let us look at the first order:", "Text",
 CellChangeTimes->{{3.556893625816093*^9, 3.556893635682719*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqMs1", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"eqMATRIX", ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.556255346963456*^9, 3.5562553602091217`*^9}, {
  3.556256376442572*^9, 3.556256386457437*^9}, {3.556256621786585*^9, 
  3.556256627147356*^9}}],

Cell["We solve for the extra coefficients defined above:", "Text",
 CellChangeTimes->{{3.556893644964243*^9, 3.556893656874086*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"syst1", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"eqMs1", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"eqMs1", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"eqMs1", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"eqMs1", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"V1", "[", "r", "]"}], ",", 
         RowBox[{"W", "[", "r", "]"}], ",", 
         RowBox[{"G1", "[", "r", "]"}], ",", 
         RowBox[{"G2", "[", "r", "]"}]}], "}"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.556270765089189*^9, 3.5562707843289967`*^9}, {
  3.55627088595083*^9, 3.5562708864277554`*^9}, {3.5571378699026127`*^9, 
  3.557137898271212*^9}}],

Cell["Check: this is a solution:", "Text",
 CellChangeTimes->{{3.5707381633060427`*^9, 3.5707381733237057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"eqMs1", "/.", "syst1"}], "]"}]], "Input",
 CellChangeTimes->{{3.55627077391311*^9, 3.556270789044304*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5562707900405083`*^9, 3.556270887434759*^9, 3.556513182657947*^9, 
   3.5566052890907183`*^9, 3.556856514021461*^9, 3.556856629861865*^9, {
   3.55686470554423*^9, 3.556864709516185*^9}, 3.556865822157189*^9, 
   3.557137900043792*^9, 3.570736725855536*^9, 3.570736761594392*^9, 
   3.570738176351881*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Single second-order equation: R\[CloseCurlyQuote]\[CloseCurlyQuote]+Ulm R\
\[CloseCurlyQuote]+Vlm R=Slm [X\[CloseCurlyQuote]=dX/drs, tortoise]\
\>", "Subsubsection",
 CellChangeTimes->{{3.556514758147072*^9, 3.5565148198522987`*^9}, {
  3.556605248404236*^9, 3.5566052499430656`*^9}}],

Cell["Setting up the single 2nd order eq:", "Text",
 CellChangeTimes->{{3.557133815211461*^9, 3.557133815843156*^9}, {
  3.557137827021594*^9, 3.557137836030422*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"F", ",", "Kt"}], "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"**", "two"}], " ", 
    RowBox[{"equations", ":"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ln", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Kt", "'"}], "[", "r", "]"}], " ", 
         RowBox[{"F", "[", "r", "]"}]}], "\[Equal]", 
        RowBox[{
         RowBox[{"\[Epsilon]a", " ", 
          RowBox[{"G1", "[", "r", "]"}], " ", 
          RowBox[{"Kt", "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Epsilon]a", " ", 
             RowBox[{"W", "[", "r", "]"}]}]}], ")"}], " ", 
          RowBox[{"Lt", "[", "r", "]"}]}], "+", 
         RowBox[{"S1t", "[", "r", "]"}]}]}], ",", 
       RowBox[{"Lt", "[", "r", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eqKt", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Lt", "'"}], "[", "r", "]"}], " ", 
        RowBox[{"F", "[", "r", "]"}]}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Omega]", "2"], "-", 
             RowBox[{"VV", "[", "r", "]"}], "-", 
             RowBox[{"\[Epsilon]a", " ", 
              RowBox[{"V1", "[", "r", "]"}]}]}], ")"}]}], 
          RowBox[{"Kt", "[", "r", "]"}]}], "+", 
         RowBox[{"\[Epsilon]a", " ", 
          RowBox[{"G2", "[", "r", "]"}], 
          RowBox[{"Lt", "[", "r", "]"}]}], "+", 
         RowBox[{"S2t", "[", "r", "]"}]}], ")"}]}], "//.", 
      RowBox[{"Union", "[", 
       RowBox[{"Ln", ",", 
        RowBox[{"D", "[", 
         RowBox[{"Ln", ",", "r"}], "]"}]}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "**)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"eqKt", ",", 
     RowBox[{
      RowBox[{"Kt", "''"}], "[", "r", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"c1", "=", 
  RowBox[{"Normal", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], "2"], 
        RowBox[{
         RowBox[{
          RowBox[{"F", "'"}], "[", "r", "]"}], 
         RowBox[{"F", "[", "r", "]"}]}]], 
       FractionBox[
        RowBox[{"Coefficient", "[", 
         RowBox[{"eqKt", ",", 
          RowBox[{
           RowBox[{"Kt", "'"}], "[", "r", "]"}]}], "]"}], "c2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"uLM", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"c1", "-", "1"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"vLM", "=", 
  RowBox[{"Normal", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], "2"], "1"], 
       FractionBox[
        RowBox[{"Coefficient", "[", 
         RowBox[{"eqKt", ",", 
          RowBox[{"Kt", "[", "r", "]"}]}], "]"}], "c2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"sLM", "=", 
  RowBox[{"-", 
   RowBox[{"Normal", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"F", "[", "r", "]"}], "2"], "eqKt"}], "c2"], "-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"F", "[", "r", "]"}], "2"], 
           RowBox[{
            RowBox[{"Kt", "''"}], "[", "r", "]"}]}], "+", 
          RowBox[{"c1", " ", 
           RowBox[{
            RowBox[{"F", "'"}], "[", "r", "]"}], 
           RowBox[{"F", "[", "r", "]"}], 
           RowBox[{
            RowBox[{"Kt", "'"}], "[", "r", "]"}]}], "+", 
          RowBox[{"vLM", " ", 
           RowBox[{"Kt", "[", "r", "]"}]}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.557133827324026*^9, 3.5571340911898623`*^9}, {
   3.557134162954668*^9, 3.557134259575501*^9}, {3.5571344650960493`*^9, 
   3.557134553763892*^9}, {3.5571378439905167`*^9, 3.557137858695077*^9}, {
   3.55713792096813*^9, 3.5571379317444*^9}, 3.557138027063158*^9, {
   3.557139495933091*^9, 3.557139498634124*^9}, {3.557151396897567*^9, 
   3.55715141797444*^9}, {3.570736772333424*^9, 3.570736773266635*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{"\[Epsilon]a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G1", "[", "r", "]"}], "+", 
      RowBox[{"G2", "[", "r", "]"}], "+", 
      RowBox[{
       RowBox[{"F", "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["W", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]]}]], "Output",
 CellChangeTimes->{{3.557134040643104*^9, 3.5571340919355183`*^9}, 
   3.557134260011104*^9, {3.55713455001586*^9, 3.557134554416583*^9}, {
   3.557137904229856*^9, 3.5571379325621233`*^9}, 3.557138027433858*^9, {
   3.557151409656394*^9, 3.5571514187193203`*^9}, {3.5707367628775587`*^9, 
   3.5707367773991327`*^9}, 3.5707381841316*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"\[Epsilon]a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G1", "[", "r", "]"}], "+", 
      RowBox[{"G2", "[", "r", "]"}], "+", 
      RowBox[{
       RowBox[{"F", "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["W", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]]}]], "Output",
 CellChangeTimes->{{3.557134040643104*^9, 3.5571340919355183`*^9}, 
   3.557134260011104*^9, {3.55713455001586*^9, 3.557134554416583*^9}, {
   3.557137904229856*^9, 3.5571379325621233`*^9}, 3.557138027433858*^9, {
   3.557151409656394*^9, 3.5571514187193203`*^9}, {3.5707367628775587`*^9, 
   3.5707367773991327`*^9}, 3.570738184133906*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[Omega]", "2"], "-", 
  RowBox[{"VV", "[", "r", "]"}], "+", 
  RowBox[{"\[Epsilon]a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"V1", "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", 
        RowBox[{"VV", "[", "r", "]"}]}], ")"}], " ", 
      RowBox[{"W", "[", "r", "]"}]}], "-", 
     RowBox[{
      RowBox[{"F", "[", "r", "]"}], " ", 
      RowBox[{
       SuperscriptBox["G1", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.557134040643104*^9, 3.5571340919355183`*^9}, 
   3.557134260011104*^9, {3.55713455001586*^9, 3.557134554416583*^9}, {
   3.557137904229856*^9, 3.5571379325621233`*^9}, 3.557138027433858*^9, {
   3.557151409656394*^9, 3.5571514187193203`*^9}, {3.5707367628775587`*^9, 
   3.5707367773991327`*^9}, 3.570738184172188*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2t", "[", "r", "]"}], "+", 
  RowBox[{
   RowBox[{"F", "[", "r", "]"}], " ", 
   RowBox[{
    SuperscriptBox["S1t", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "-", 
  RowBox[{"\[Epsilon]a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"G2", "[", "r", "]"}], " ", 
      RowBox[{"S1t", "[", "r", "]"}]}], "-", 
     RowBox[{
      RowBox[{"S2t", "[", "r", "]"}], " ", 
      RowBox[{"W", "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"F", "[", "r", "]"}], " ", 
      RowBox[{"S1t", "[", "r", "]"}], " ", 
      RowBox[{
       SuperscriptBox["W", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.557134040643104*^9, 3.5571340919355183`*^9}, 
   3.557134260011104*^9, {3.55713455001586*^9, 3.557134554416583*^9}, {
   3.557137904229856*^9, 3.5571379325621233`*^9}, 3.557138027433858*^9, {
   3.557151409656394*^9, 3.5571514187193203`*^9}, {3.5707367628775587`*^9, 
   3.5707367773991327`*^9}, 3.57073818417404*^9}]
}, Open  ]],

Cell["\<\
Source terms: they are zero in the Q=0 case we are dealing with:\
\>", "Text",
 CellChangeTimes->{{3.5571391466628523`*^9, 3.557139148496488*^9}, {
  3.5707381904081*^9, 3.5707381981077633`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"St", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"n", "[", "r", "]"}], " ", 
        RowBox[{
         RowBox[{"Inverse", "[", "FF", "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"S1", ",", "S2"}], "}"}]}]}], "/.", "syst1"}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"fem", "''"}], "[", "r", "]"}], "\[Rule]", "femppn"}]}], 
     "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"St1", "=", 
   RowBox[{"St", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"St2", "=", 
   RowBox[{"St", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleS", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"S1t", "[", "r", "]"}], "\[Rule]", "St1"}], ",", 
     RowBox[{
      RowBox[{"S2t", "[", "r", "]"}], "\[Rule]", "St2"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.570736784553548*^9, 3.570736785835432*^9}, {
  3.570738201272455*^9, 3.570738202047333*^9}}],

Cell["Explicit form:", "Text",
 CellChangeTimes->{{3.557133811376659*^9, 3.5571338118168907`*^9}, {
  3.5571379900025663`*^9, 3.557137991751679*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleSingle", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"syst1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"VV", "[", "r", "]"}], "\[Rule]", "V"}], "}"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{"syst1", ",", "r"}], "]"}], ",", "ruleS", ",", 
     RowBox[{"D", "[", 
      RowBox[{"ruleS", ",", "r"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     FractionBox["M", "r"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ULM", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"uLM", "//.", "ruleSingle"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VLM", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"vLM", "//.", "ruleSingle"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SLM", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"sLM", "//.", "ruleSingle"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.556514826857605*^9, 3.556514886564025*^9}, {
   3.556514954745063*^9, 3.5565149635614557`*^9}, {3.5565149942827673`*^9, 
   3.5565152369207897`*^9}, {3.556515416074151*^9, 3.556515463602365*^9}, {
   3.556515536949499*^9, 3.556515554412099*^9}, {3.55651568673757*^9, 
   3.5565156878894453`*^9}, 3.5565158103197203`*^9, 3.556515984399267*^9, {
   3.556605428384809*^9, 3.556605429943903*^9}, {3.5571347282001953`*^9, 
   3.557134733617837*^9}, {3.557134924749784*^9, 3.557135009763853*^9}, {
   3.55713793960534*^9, 3.557137955136115*^9}, {3.557138353267124*^9, 
   3.557138367344541*^9}, {3.5571387043119497`*^9, 3.557138705246492*^9}, {
   3.5571389070031776`*^9, 3.5571389180867453`*^9}, {3.557139063482997*^9, 
   3.557139207380196*^9}, {3.55714430681304*^9, 3.557144307021903*^9}, {
   3.557151429141574*^9, 3.557151432731517*^9}, {3.570736792306196*^9, 
   3.5707367965036097`*^9}, 3.570738205327669*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQR", "=", 
   RowBox[{"SJ", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{"R", "''"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "'"}], "[", "r", "]"}], 
      RowBox[{"F", "[", "r", "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "ULM"}], ")"}], 
      RowBox[{
       RowBox[{"R", "'"}], "[", "r", "]"}]}], "+", 
     RowBox[{"VLM", " ", 
      RowBox[{"R", "[", "r", "]"}]}], "-", "SLM"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.556515813156748*^9, 3.556515859991054*^9}, 
   3.557138790826137*^9, {3.557138837228807*^9, 3.5571388419804497`*^9}}],

Cell["Definitions:", "Text",
 CellChangeTimes->{{3.570738221437338*^9, 3.5707382235513983`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"K0t", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"F11", "[", "r", "]"}], " ", 
       RowBox[{"R", "[", "r", "]"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"F12", "[", "r", "]"}], 
        RowBox[{"1", "+", 
         RowBox[{"\[Epsilon]a", " ", 
          RowBox[{"W", "[", "r", "]"}]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"R", "'"}], "[", "r", "]"}], 
          RowBox[{"F", "[", "r", "]"}]}], "-", 
         RowBox[{"\[Epsilon]a", " ", 
          RowBox[{"G1", "[", "r", "]"}], " ", 
          RowBox[{"R", "[", "r", "]"}]}], "-", "St1"}], ")"}]}]}], ")"}], "/.",
     "syst1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H10t", "=", 
   RowBox[{
    RowBox[{"\[Omega]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"F21", "[", "r", "]"}], " ", 
        RowBox[{"R", "[", "r", "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"F22", "[", "r", "]"}], 
         RowBox[{"1", "+", 
          RowBox[{"\[Epsilon]a", " ", 
           RowBox[{"W", "[", "r", "]"}]}]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"R", "'"}], "[", "r", "]"}], 
           RowBox[{"F", "[", "r", "]"}]}], "-", 
          RowBox[{"\[Epsilon]a", " ", 
           RowBox[{"G1", "[", "r", "]"}], " ", 
           RowBox[{"R", "[", "r", "]"}]}], "-", "St1"}], ")"}]}]}], ")"}]}], "/.",
     "syst1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQRb", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{"EQR", "/.", 
      RowBox[{
       RowBox[{"K0", "[", "r", "]"}], "\[Rule]", "K0t"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2F", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"EQRb", ",", 
     RowBox[{
      RowBox[{"R", "''"}], "[", "r", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ULMF", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"F", "[", "r", "]"}], "2"], 
       RowBox[{
        RowBox[{
         RowBox[{"F", "'"}], "[", "r", "]"}], 
        RowBox[{"F", "[", "r", "]"}]}]], 
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQRb", ",", 
         RowBox[{
          RowBox[{"R", "'"}], "[", "r", "]"}]}], "]"}], "c2F"]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VLMF", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQRb", ",", 
         RowBox[{"R", "[", "r", "]"}]}], "]"}], "c2F"]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SLMF", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"SJ", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"F", "[", "r", "]"}], "2"], 
         RowBox[{
          RowBox[{"R", "''"}], "[", "r", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"F", "'"}], "[", "r", "]"}], 
         RowBox[{"F", "[", "r", "]"}], "ULMF", " ", 
         RowBox[{
          RowBox[{"R", "'"}], "[", "r", "]"}]}], "+", 
        RowBox[{"VLMF", " ", 
         RowBox[{"R", "[", "r", "]"}]}]}], ")"}], "-", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], "2"], "c2F"], "EQRb"}]}], "]"}], 
    "]"}]}], ";"}]}], "Input"],

Cell["\<\
Again, we redefine the Zerilli function in order to have a nice \
Schroedinger-like equation:\
\>", "Text",
 CellChangeTimes->{{3.5707382370429783`*^9, 3.5707382541903763`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"R", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Z", "[", "r", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"\[Epsilon]a", " ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"2", " ", "J", " ", "m", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"48", " ", 
             SuperscriptBox["M", "3"]}], "-", 
            RowBox[{"24", " ", 
             SuperscriptBox["M", "2"], " ", "r"}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], "2"], " ", "M", " ", 
             SuperscriptBox["r", "2"]}], "+", 
            RowBox[{"12", " ", "M", " ", 
             SuperscriptBox["r", "4"], " ", 
             SuperscriptBox["\[Omega]", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "l", "+", 
               SuperscriptBox["l", "2"]}], ")"}], " ", 
             SuperscriptBox["r", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "l", "+", 
               SuperscriptBox["l", "2"], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}], 
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          SuperscriptBox["r", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "M"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], "2"], 
          " ", "\[Omega]"}]], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQZ", "=", "EQRb"}], ";"}]}], "Input",
 CellChangeTimes->{{3.570736884206222*^9, 3.570736903101431*^9}, {
  3.570736951420051*^9, 3.570736952236568*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"EQRb", ",", 
     RowBox[{
      RowBox[{"Z", "''"}], "[", "r", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"EQRb", ",", 
     RowBox[{
      RowBox[{"Z", "'"}], "[", "r", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c0", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"EQRb", ",", 
     RowBox[{"Z", "[", "r", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"c10", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", 
    RowBox[{
     FractionBox["c1", "c2"], 
     FractionBox[
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{
        RowBox[{"F", "'"}], "[", "r", "]"}], 
       RowBox[{"F", "[", "r", "]"}]}]]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Vp", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"SJ", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Omega]", "2"], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[Epsilon]a", " ", "m", " ", 
        RowBox[{"\[Zeta]", "[", "r", "]"}], " ", "\[Omega]"}], 
       SuperscriptBox["r", "2"]], "-", 
      RowBox[{
       FractionBox["c0", "c2"], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"F", "[", "r", "]"}], "2"], "1"]}]}], 
     RowBox[{"F", "[", "r", "]"}]], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", "****)"}]}]}], "Input",
 CellChangeTimes->{{3.556514981971801*^9, 3.5565149864122877`*^9}, {
  3.556517087481657*^9, 3.5565171767276297`*^9}, {3.570736834420813*^9, 
  3.570736877771597*^9}, {3.570736910074583*^9, 3.570737013720459*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.570736878035763*^9, 3.57073702365082*^9}, 
   3.5707382568085737`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"l", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "l"}], ")"}], " ", 
    SuperscriptBox["r", "7"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "M"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], "4"], " ", 
    "\[Omega]"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"l", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "l"}], ")"}], " ", 
     SuperscriptBox["r", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "M"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "l", "+", 
           SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], "2"], " ", 
     
     RowBox[{"(", 
      RowBox[{
       RowBox[{"72", " ", 
        SuperscriptBox["M", "3"]}], "+", 
       RowBox[{"36", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", 
        SuperscriptBox["M", "2"], " ", "r"}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "l", "+", 
           SuperscriptBox["l", "2"]}], ")"}], "2"], " ", "M", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "l", "+", 
           SuperscriptBox["l", "2"]}], ")"}], "2"], " ", 
        SuperscriptBox["r", "3"]}]}], ")"}], " ", "\[Omega]"}], "+", 
    RowBox[{"4", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"27648", " ", 
        SuperscriptBox["M", "6"]}], "+", 
       RowBox[{"2592", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "19"}], "+", 
          RowBox[{"6", " ", "l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox["M", "5"], " ", "r"}], "+", 
       RowBox[{"144", " ", 
        SuperscriptBox["M", "4"], " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"230", "+", 
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "148"}], "+", 
             RowBox[{"21", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "l", "+", 
           SuperscriptBox["l", "2"]}], ")"}], "2"], " ", 
        SuperscriptBox["M", "2"], " ", 
        SuperscriptBox["r", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "12"}], "+", 
             RowBox[{"5", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"28", " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", 
        SuperscriptBox["M", "3"], " ", 
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"374", "+", 
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "200"}], "+", 
             RowBox[{"29", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"72", " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "l", "+", 
           SuperscriptBox["l", "2"]}], ")"}], "3"], " ", 
        SuperscriptBox["r", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "l", "+", 
           SuperscriptBox["l", "2"]}], ")"}], "2"], " ", "M", " ", 
        SuperscriptBox["r", "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", "l", "+", 
             SuperscriptBox["l", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "38"}], "+", 
             RowBox[{"7", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"24", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"2", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.570736878035763*^9, 3.57073702365082*^9}, 
   3.570738259554305*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"SJ", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], "c2"], "EQZ"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"F", "[", "r", "]"}], "2"], 
       RowBox[{
        RowBox[{"Z", "''"}], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "'"}], "[", "r", "]"}], 
       RowBox[{"F", "[", "r", "]"}], 
       RowBox[{
        RowBox[{"Z", "'"}], "[", "r", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "-", 
         FractionBox[
          RowBox[{"2", " ", "\[Epsilon]a", " ", "m", " ", 
           RowBox[{"\[Zeta]", "[", "r", "]"}], " ", "\[Omega]"}], 
          SuperscriptBox["r", "2"]], "-", 
         RowBox[{
          RowBox[{"F", "[", "r", "]"}], "Vp"}]}], ")"}], 
       RowBox[{"Z", "[", "r", "]"}]}]}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5707370487116823`*^9, 3.570737064762897*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.570737060552351*^9, 3.570737065645993*^9}, 
   3.570738261837926*^9}]
}, Open  ]],

Cell["\<\
This is our final Zerilli equation to first order in the spin. The potential \
is more involved than in the axial case, but one can nevertheless show that \
the two eigenvalue problems (axial and polar) are isospectral.\
\>", "Text",
 CellChangeTimes->{{3.570738264770121*^9, 3.570738308060914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"l", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "l"}], ")"}], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", "M"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "l", "+", 
               SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], "4"], 
         " ", "\[Omega]"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          SuperscriptBox["r", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "M"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], " ", "r"}]}], ")"}], "2"], 
          " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"72", " ", 
             SuperscriptBox["M", "3"]}], "+", 
            RowBox[{"36", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "l", "+", 
               SuperscriptBox["l", "2"]}], ")"}], " ", 
             SuperscriptBox["M", "2"], " ", "r"}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], "2"], " ", "M", " ", 
             SuperscriptBox["r", "2"]}], "+", 
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], "2"], " ", 
             SuperscriptBox["r", "3"]}]}], ")"}], " ", "\[Omega]"}], "+", 
         RowBox[{"4", " ", "J", " ", "m", " ", "\[Epsilon]a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"27648", " ", 
             SuperscriptBox["M", "6"]}], "+", 
            RowBox[{"2592", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "19"}], "+", 
               RowBox[{"6", " ", "l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}], " ", 
             SuperscriptBox["M", "5"], " ", "r"}], "+", 
            RowBox[{"144", " ", 
             SuperscriptBox["M", "4"], " ", 
             SuperscriptBox["r", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"230", "+", 
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "148"}], "+", 
                  RowBox[{"21", " ", "l", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], "2"], " ", 
             SuperscriptBox["M", "2"], " ", 
             SuperscriptBox["r", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "+", 
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "12"}], "+", 
                  RowBox[{"5", " ", "l", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"28", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
            RowBox[{"12", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "l", "+", 
               SuperscriptBox["l", "2"]}], ")"}], " ", 
             SuperscriptBox["M", "3"], " ", 
             SuperscriptBox["r", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"374", "+", 
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "200"}], "+", 
                  RowBox[{"29", " ", "l", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"72", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], "3"], " ", 
             SuperscriptBox["r", "6"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "l", "+", 
                  SuperscriptBox["l", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", "l", "+", 
                  SuperscriptBox["l", "2"]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "+", "l", "+", 
                  SuperscriptBox["l", "2"]}], ")"}], " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "l", "+", 
                SuperscriptBox["l", "2"]}], ")"}], "2"], " ", "M", " ", 
             SuperscriptBox["r", "5"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "l", "+", 
                  SuperscriptBox["l", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", "l", "+", 
                  SuperscriptBox["l", "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "38"}], "+", 
                  RowBox[{"7", " ", "l", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"24", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", 
                  RowBox[{"2", " ", "l", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}], " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]a", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "\[Rule]", "\[ScriptL]"}], ",", 
     RowBox[{"J", "\[Rule]", 
      RowBox[{"at", " ", 
       SuperscriptBox["M", "2"]}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.570745020251853*^9, 3.5707450505371437`*^9}, {
   3.570745143650498*^9, 3.570745216486356*^9}, 3.5707452942367907`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"6", " ", "M"}], 
      SuperscriptBox["r", "3"]], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[ScriptL]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ScriptL]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["r", "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[ScriptL]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "\[ScriptL]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ScriptL]", "+", 
            SuperscriptBox["\[ScriptL]", "2"]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", "M"}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
               SuperscriptBox["\[ScriptL]", "2"]}], ")"}]}]}], ")"}], "2"]]}],
        ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["r", "7"], " ", "\[ScriptL]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ScriptL]"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "M"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
           SuperscriptBox["\[ScriptL]", "2"]}], ")"}]}]}], ")"}], "4"], " ", 
     "\[Omega]"}]], 
   RowBox[{"4", " ", "at", " ", "m", " ", 
    SuperscriptBox["M", "2"], " ", "\[Epsilon]a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"27648", " ", 
       SuperscriptBox["M", "6"]}], "+", 
      RowBox[{"2592", " ", 
       SuperscriptBox["M", "5"], " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "19"}], "+", 
         RowBox[{"6", " ", "\[ScriptL]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ScriptL]"}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"144", " ", 
       SuperscriptBox["M", "4"], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"230", "+", 
         RowBox[{"\[ScriptL]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ScriptL]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "148"}], "+", 
            RowBox[{"21", " ", "\[ScriptL]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "\[ScriptL]"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox["r", "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
          SuperscriptBox["\[ScriptL]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"\[ScriptL]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ScriptL]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "12"}], "+", 
            RowBox[{"5", " ", "\[ScriptL]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "\[ScriptL]"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"28", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["M", "3"], " ", 
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
         SuperscriptBox["\[ScriptL]", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"374", "+", 
         RowBox[{"\[ScriptL]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ScriptL]"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "200"}], "+", 
            RowBox[{"29", " ", "\[ScriptL]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "\[ScriptL]"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["r", "6"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
          SuperscriptBox["\[ScriptL]", "2"]}], ")"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
            SuperscriptBox["\[ScriptL]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "\[ScriptL]", "+", 
            SuperscriptBox["\[ScriptL]", "2"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", "\[ScriptL]", "+", 
            SuperscriptBox["\[ScriptL]", "2"]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
      RowBox[{"M", " ", 
       SuperscriptBox["r", "5"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
          SuperscriptBox["\[ScriptL]", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
            SuperscriptBox["\[ScriptL]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "\[ScriptL]", "+", 
            SuperscriptBox["\[ScriptL]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "38"}], "+", 
            RowBox[{"7", " ", "\[ScriptL]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "\[ScriptL]"}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"2", " ", "\[ScriptL]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "\[ScriptL]"}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.5707450265314693`*^9, 3.570745042641047*^9}, {
   3.5707451465848846`*^9, 3.570745217333021*^9}, 3.570745294754952*^9}]
}, Open  ]],

Cell["\<\
At zeroth order, we recover Zerilli:\
\>", "Text",
 CellChangeTimes->{{3.571253186562086*^9, 3.5712531933474083`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"6", " ", "M"}], 
        SuperscriptBox["r", "3"]], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[ScriptL]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ScriptL]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["r", "2"]], "+", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "\[ScriptL]"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "\[ScriptL]"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "\[ScriptL]", "+", 
              SuperscriptBox["\[ScriptL]", "2"]}], ")"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", "M"}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "\[ScriptL]", "+", 
                 SuperscriptBox["\[ScriptL]", "2"]}], ")"}]}]}], ")"}], 
            "2"]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox["\[Lambda]", "2"], 
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", "1"}], ")"}], 
        SuperscriptBox["r", "3"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["\[Lambda]", "2"], "M", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"18", " ", "\[Lambda]", " ", 
        SuperscriptBox["M", "2"], "r"}], "+", 
       RowBox[{"18", " ", 
        SuperscriptBox["M", "3"]}]}], 
      RowBox[{
       SuperscriptBox["r", "3"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Lambda]", " ", "r"}], "+", 
          RowBox[{"3", " ", "M"}]}], ")"}], "2"]}]], ")"}]}], "/.", 
   RowBox[{"\[Lambda]", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[ScriptL]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "\[ScriptL]"}], ")"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571253096570292*^9, 3.571253180710574*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.571253182885919*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1366, 725},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 379, 7, 66, "Subtitle"],
Cell[949, 31, 104, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[1078, 36, 10202, 234, 308, "Input"],
Cell[11283, 272, 3277, 74, 95, "Output"],
Cell[14563, 348, 2953, 67, 99, "Output"]
}, Open  ]],
Cell[17531, 418, 567, 15, 30, "Text"],
Cell[18101, 435, 1261, 32, 35, "Input"],
Cell[19365, 469, 116, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[19506, 474, 2692, 68, 138, "Input"],
Cell[22201, 544, 5283, 129, 108, "Output"],
Cell[27487, 675, 12348, 311, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39872, 991, 136, 1, 28, "Subsubsection"],
Cell[40011, 994, 2297, 58, 135, "Input"],
Cell[CellGroupData[{
Cell[42333, 1056, 2568, 61, 138, "Input"],
Cell[44904, 1119, 670, 11, 29, "Output"]
}, Open  ]],
Cell[45589, 1133, 1051, 28, 29, "Input"],
Cell[CellGroupData[{
Cell[46665, 1165, 1495, 40, 48, "Input"],
Cell[48163, 1207, 79, 1, 29, "Output"]
}, Open  ]],
Cell[48257, 1211, 1017, 27, 29, "Input"],
Cell[49277, 1240, 1052, 29, 55, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50378, 1275, 339, 4, 39, "Subtitle"],
Cell[50720, 1281, 2289, 43, 29, "Input"],
Cell[53012, 1326, 1647, 45, 192, "Input"],
Cell[54662, 1373, 119, 1, 28, "Text"],
Cell[54784, 1376, 452, 12, 48, "Input"],
Cell[CellGroupData[{
Cell[55261, 1392, 251, 5, 28, "Subsubsection"],
Cell[55515, 1399, 287, 7, 48, "Input"],
Cell[CellGroupData[{
Cell[55827, 1410, 5004, 99, 254, "Input"],
Cell[60834, 1511, 1220, 20, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62103, 1537, 119, 1, 71, "Section"],
Cell[62225, 1540, 556, 13, 66, "Input"],
Cell[CellGroupData[{
Cell[62806, 1557, 104, 1, 28, "Subsubsection"],
Cell[62913, 1560, 10636, 316, 277, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[73586, 1881, 177, 2, 22, "Subsubsection"],
Cell[73766, 1885, 654, 20, 143, "Input"],
Cell[74423, 1907, 648, 10, 62, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75108, 1922, 177, 4, 37, "Subsection"],
Cell[CellGroupData[{
Cell[75310, 1930, 105, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[75440, 1935, 1032, 26, 48, "Input"],
Cell[76475, 1963, 450, 6, 29, "Output"]
}, Open  ]],
Cell[76940, 1972, 334, 10, 35, "Input"],
Cell[CellGroupData[{
Cell[77299, 1986, 3975, 118, 279, "Input"],
Cell[81277, 2106, 579, 9, 29, "Output"],
Cell[81859, 2117, 579, 9, 29, "Output"],
Cell[82441, 2128, 576, 9, 29, "Output"]
}, Open  ]],
Cell[83032, 2140, 536, 13, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83605, 2158, 102, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[83732, 2163, 1080, 27, 48, "Input"],
Cell[84815, 2192, 446, 6, 29, "Output"]
}, Open  ]],
Cell[85276, 2201, 313, 10, 35, "Input"],
Cell[CellGroupData[{
Cell[85614, 2215, 4023, 118, 279, "Input"],
Cell[89640, 2335, 260, 4, 29, "Output"],
Cell[89903, 2341, 260, 4, 29, "Output"],
Cell[90166, 2347, 256, 4, 29, "Output"]
}, Open  ]],
Cell[90437, 2354, 361, 9, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90835, 2368, 153, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[91013, 2374, 1132, 27, 48, "Input"],
Cell[92148, 2403, 452, 6, 29, "Output"]
}, Open  ]],
Cell[92615, 2412, 311, 10, 35, "Input"],
Cell[CellGroupData[{
Cell[92951, 2426, 4071, 119, 279, "Input"],
Cell[97025, 2547, 239, 3, 29, "Output"],
Cell[97267, 2552, 239, 3, 29, "Output"],
Cell[97509, 2557, 236, 3, 29, "Output"]
}, Open  ]],
Cell[97760, 2563, 458, 10, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98255, 2578, 241, 3, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[98521, 2585, 1436, 34, 80, "Input"],
Cell[99960, 2621, 526, 7, 29, "Output"]
}, Open  ]],
Cell[100501, 2631, 313, 10, 35, "Input"],
Cell[CellGroupData[{
Cell[100839, 2645, 3077, 85, 178, "Input"],
Cell[103919, 2732, 290, 5, 29, "Output"],
Cell[104212, 2739, 290, 5, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104539, 2749, 1000, 31, 40, "Input"],
Cell[105542, 2782, 210, 3, 29, "Output"]
}, Open  ]],
Cell[105767, 2788, 528, 13, 102, "Input"],
Cell[106298, 2803, 472, 10, 29, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[106819, 2819, 228, 5, 37, "Subsection"],
Cell[107050, 2826, 13128, 381, 312, "Input"],
Cell[120181, 3209, 2124, 65, 42, "Input"],
Cell[CellGroupData[{
Cell[122330, 3278, 111, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[122466, 3283, 893, 24, 48, "Input"],
Cell[123362, 3309, 362, 5, 29, "Output"]
}, Open  ]],
Cell[123739, 3317, 436, 12, 35, "Input"],
Cell[CellGroupData[{
Cell[124200, 3333, 5932, 172, 386, "Input"],
Cell[130135, 3507, 358, 5, 29, "Output"],
Cell[130496, 3514, 358, 5, 29, "Output"],
Cell[130857, 3521, 355, 5, 29, "Output"]
}, Open  ]],
Cell[131227, 3529, 808, 21, 156, "Input"],
Cell[132038, 3552, 516, 11, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[132591, 3568, 110, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[132726, 3573, 976, 26, 48, "Input"],
Cell[133705, 3601, 340, 5, 29, "Output"]
}, Open  ]],
Cell[134060, 3609, 409, 12, 35, "Input"],
Cell[CellGroupData[{
Cell[134494, 3625, 6031, 173, 386, "Input"],
Cell[140528, 3800, 234, 3, 29, "Output"],
Cell[140765, 3805, 236, 3, 29, "Output"],
Cell[141004, 3810, 231, 3, 29, "Output"]
}, Open  ]],
Cell[141250, 3816, 1622, 39, 300, "Input"],
Cell[142875, 3857, 465, 10, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143377, 3872, 165, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[143567, 3878, 1099, 28, 79, "Input"],
Cell[144669, 3908, 431, 6, 29, "Output"]
}, Open  ]],
Cell[145115, 3917, 525, 14, 53, "Input"],
Cell[CellGroupData[{
Cell[145665, 3935, 6257, 176, 386, "Input"],
Cell[151925, 4113, 526, 7, 29, "Output"],
Cell[152454, 4122, 528, 7, 29, "Output"],
Cell[152985, 4131, 525, 7, 29, "Output"]
}, Open  ]],
Cell[153525, 4141, 940, 24, 156, "Input"],
Cell[154468, 4167, 608, 12, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155113, 4184, 166, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[155304, 4190, 1147, 29, 79, "Input"],
Cell[156454, 4221, 332, 5, 29, "Output"]
}, Open  ]],
Cell[156801, 4229, 435, 12, 35, "Input"],
Cell[CellGroupData[{
Cell[157261, 4245, 6080, 174, 386, "Input"],
Cell[163344, 4421, 211, 3, 29, "Output"],
Cell[163558, 4426, 211, 3, 29, "Output"],
Cell[163772, 4431, 207, 3, 29, "Output"]
}, Open  ]],
Cell[163994, 4437, 890, 24, 156, "Input"],
Cell[164887, 4463, 561, 12, 29, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[165497, 4481, 292, 6, 37, "Subsection"],
Cell[CellGroupData[{
Cell[165814, 4491, 121, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[165960, 4496, 898, 25, 48, "Input"],
Cell[166861, 4523, 206, 3, 29, "Output"]
}, Open  ]],
Cell[167082, 4529, 347, 11, 35, "Input"],
Cell[167432, 4542, 1576, 47, 152, "Input"],
Cell[169011, 4591, 1153, 34, 120, "Input"],
Cell[CellGroupData[{
Cell[170189, 4629, 810, 22, 48, "Input"],
Cell[171002, 4653, 291, 5, 29, "Output"],
Cell[171296, 4660, 293, 5, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171626, 4670, 1726, 50, 64, "Input"],
Cell[173355, 4722, 281, 4, 29, "Output"]
}, Open  ]],
Cell[173651, 4729, 640, 16, 138, "Input"],
Cell[174294, 4747, 458, 10, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174789, 4762, 120, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[174934, 4767, 1061, 28, 80, "Input"],
Cell[175998, 4797, 285, 5, 29, "Output"]
}, Open  ]],
Cell[176298, 4805, 347, 11, 35, "Input"],
Cell[CellGroupData[{
Cell[176670, 4820, 4980, 149, 314, "Input"],
Cell[181653, 4971, 97, 1, 29, "Output"],
Cell[181753, 4974, 97, 1, 29, "Output"],
Cell[181853, 4977, 94, 1, 29, "Output"]
}, Open  ]],
Cell[181962, 4981, 755, 20, 138, "Input"],
Cell[182720, 5003, 527, 11, 29, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[183308, 5021, 183, 4, 71, "Section"],
Cell[183494, 5027, 470, 7, 45, "Text"],
Cell[183967, 5036, 1939, 62, 222, "Input"],
Cell[185909, 5100, 979, 25, 210, "Input"],
Cell[186891, 5127, 90, 3, 29, "Input"],
Cell[186984, 5132, 6567, 207, 276, "Input"],
Cell[193554, 5341, 359, 9, 29, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193950, 5355, 347, 5, 71, "Section"],
Cell[194300, 5362, 997, 26, 84, "Input"],
Cell[195300, 5390, 112, 1, 28, "Text"],
Cell[195415, 5393, 829, 16, 56, "Input"],
Cell[196247, 5411, 151, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[196423, 5418, 2361, 66, 156, "Input"],
Cell[198787, 5486, 3087, 86, 79, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201911, 5577, 337, 6, 29, "Input"],
Cell[202251, 5585, 4080, 113, 101, "Output"]
}, Open  ]],
Cell[206346, 5701, 289, 6, 29, "Text"],
Cell[CellGroupData[{
Cell[206660, 5711, 1891, 55, 120, "Input"],
Cell[208554, 5768, 1719, 47, 58, "Output"],
Cell[210276, 5817, 318, 6, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210631, 5828, 99, 1, 29, "Input"],
Cell[210733, 5831, 3649, 107, 101, "Output"]
}, Open  ]],
Cell[214397, 5941, 306, 6, 45, "Text"],
Cell[214706, 5949, 615, 17, 78, "Input"],
Cell[CellGroupData[{
Cell[215346, 5970, 1813, 54, 183, "Input"],
Cell[217162, 6026, 294, 5, 29, "Output"],
Cell[217459, 6033, 862, 25, 53, "Output"]
}, Open  ]],
Cell[218336, 6061, 137, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[218498, 6068, 1897, 55, 62, "Input"],
Cell[220398, 6125, 143, 2, 29, "Output"]
}, Open  ]],
Cell[220556, 6130, 254, 5, 28, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220847, 6140, 294, 4, 71, "Section"],
Cell[221144, 6146, 262, 6, 28, "Text"],
Cell[221409, 6154, 1249, 31, 120, "Input"],
Cell[222661, 6187, 206, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[222892, 6194, 465, 12, 29, "Input"],
Cell[223360, 6208, 837, 27, 56, "Output"]
}, Open  ]],
Cell[224212, 6238, 188, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[224425, 6246, 1695, 44, 84, "Input"],
Cell[226123, 6292, 3469, 89, 78, "Output"],
Cell[229595, 6383, 6312, 161, 101, "Output"],
Cell[235910, 6546, 2600, 72, 56, "Output"]
}, Open  ]],
Cell[238525, 6621, 497, 8, 47, "Text"],
Cell[239025, 6631, 1701, 53, 84, "Input"],
Cell[240729, 6686, 410, 7, 29, "Text"],
Cell[241142, 6695, 2144, 65, 102, "Input"],
Cell[243289, 6762, 104, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[243418, 6767, 1865, 47, 84, "Input"],
Cell[245286, 6816, 7826, 203, 149, "Output"]
}, Open  ]],
Cell[253127, 7022, 187, 4, 28, "Text"],
Cell[253317, 7028, 1232, 26, 48, "Input"],
Cell[254552, 7056, 598, 10, 47, "Text"],
Cell[255153, 7068, 1806, 53, 104, "Input"],
Cell[256962, 7123, 253, 5, 29, "Text"],
Cell[257218, 7130, 1271, 38, 66, "Input"],
Cell[CellGroupData[{
Cell[258514, 7172, 215, 3, 28, "Subsubsection"],
Cell[258732, 7177, 365, 6, 28, "Text"],
Cell[259100, 7185, 376, 13, 48, "Input"],
Cell[259479, 7200, 1562, 44, 120, "Input"],
Cell[CellGroupData[{
Cell[261066, 7248, 3279, 91, 168, "Input"],
Cell[264348, 7341, 91, 1, 29, "Output"],
Cell[264442, 7344, 93, 1, 29, "Output"]
}, Open  ]],
Cell[264550, 7348, 171, 4, 28, "Text"],
Cell[CellGroupData[{
Cell[264746, 7356, 7623, 219, 473, "Input"],
Cell[272372, 7577, 1540, 36, 35, "Output"]
}, Open  ]],
Cell[273927, 7616, 141, 1, 28, "Text"],
Cell[274071, 7619, 460, 12, 29, "Input"],
Cell[274534, 7633, 132, 1, 28, "Text"],
Cell[274669, 7636, 1406, 38, 29, "Input"],
Cell[276078, 7676, 112, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[276215, 7681, 158, 3, 29, "Input"],
Cell[276376, 7686, 501, 12, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[276926, 7704, 294, 5, 28, "Subsubsection"],
Cell[277223, 7711, 166, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[277414, 7717, 4976, 146, 294, "Input"],
Cell[282393, 7865, 827, 20, 51, "Output"],
Cell[283223, 7887, 824, 20, 51, "Output"],
Cell[284050, 7909, 952, 24, 35, "Output"],
Cell[285005, 7935, 1056, 27, 29, "Output"]
}, Open  ]],
Cell[286076, 7965, 205, 4, 28, "Text"],
Cell[286284, 7971, 1121, 35, 84, "Input"],
Cell[287408, 8008, 149, 2, 28, "Text"],
Cell[287560, 8012, 1976, 46, 150, "Input"],
Cell[289539, 8060, 714, 21, 35, "Input"],
Cell[290256, 8083, 96, 1, 28, "Text"],
Cell[290355, 8086, 3658, 119, 295, "Input"],
Cell[294016, 8207, 187, 4, 28, "Text"],
Cell[294206, 8213, 2179, 59, 87, "Input"],
Cell[CellGroupData[{
Cell[296410, 8276, 1749, 53, 206, "Input"],
Cell[298162, 8331, 121, 2, 29, "Output"],
Cell[298286, 8335, 6589, 192, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304912, 8532, 1071, 32, 60, "Input"],
Cell[305986, 8566, 120, 2, 29, "Output"]
}, Open  ]],
Cell[306121, 8571, 309, 5, 28, "Text"],
Cell[CellGroupData[{
Cell[306455, 8580, 8000, 205, 246, "Input"],
Cell[314458, 8787, 6776, 189, 153, "Output"]
}, Open  ]],
Cell[321249, 8979, 128, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[321402, 8986, 2397, 71, 65, "Input"],
Cell[323802, 9059, 70, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
